@@ -22,12 +22,12 @@
 #ifndef __GNOME_CMD_DIALOG_H__
 #define __GNOME_CMD_DIALOG_H__
 
-#define GNOME_CMD_DIALOG(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_dialog_get_type (), GnomeCmdDialog)
-#define GNOME_CMD_DIALOG_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_dialog_get_type (), GnomeCmdDialogClass)
-#define GNOME_CMD_IS_DIALOG(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_dialog_get_type ())
+#define GNOME_CMD_TYPE_DIALOG              (gnome_cmd_dialog_get_type ())
+#define GNOME_CMD_DIALOG(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_DIALOG, GnomeCmdDialog))
+#define GNOME_CMD_DIALOG_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_DIALOG, GnomeCmdDialogClass))
+#define GNOME_CMD_IS_DIALOG(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_DIALOG))
+#define GNOME_CMD_IS_DIALOG_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_DIALOG))
+#define GNOME_CMD_DIALOG_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_DIALOG, GnomeCmdDialogClass))
 
 
 typedef struct _GnomeCmdDialog GnomeCmdDialog;
@@ -54,8 +54,6 @@ struct _GnomeCmdDialogClass
 
 GtkWidget *gnome_cmd_dialog_new (const gchar *title);
 
-void gnome_cmd_dialog_setup (GnomeCmdDialog *dialog, const gchar *title);
-
 GtkType gnome_cmd_dialog_get_type ();
 
 GtkWidget *gnome_cmd_dialog_add_button (GnomeCmdDialog *dialog, const gchar *stock_id, GtkSignalFunc on_click, gpointer data);
@@ -64,14 +62,6 @@ void gnome_cmd_dialog_add_category (GnomeCmdDialog *dialog, GtkWidget *category)
 
 void gnome_cmd_dialog_add_expanding_category (GnomeCmdDialog *dialog, GtkWidget *category);
 
-void gnome_cmd_dialog_editable_enters (GnomeCmdDialog *dialog, GtkEditable *editable);
-
-void gnome_cmd_dialog_set_transient_for (GnomeCmdDialog *dialog, GtkWindow *win);
-
-void gnome_cmd_dialog_set_modal (GnomeCmdDialog *dialog);
-
-void gnome_cmd_dialog_set_resizable (GnomeCmdDialog *dialog, gboolean value);
-
 #endif //__GNOME_CMD_DIALOG_H__
 
 
