@@ -22,30 +22,36 @@
 #ifndef __GNOME_CMD_FILE_INFO_H__
 #define __GNOME_CMD_FILE_INFO_H__
 
-#define GNOME_CMD_FILE_INFO(obj)          GTK_CHECK_CAST (obj, gnome_cmd_file_info_get_type (), GnomeCmdFileInfo)
-#define GNOME_CMD_FILE_INFO_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gnome_cmd_file_info_get_type (), GnomeCmdFileInfoClass)
-#define GNOME_CMD_IS_FILE_INFO(obj)       GTK_CHECK_TYPE (obj, gnome_cmd_file_info_get_type ())
+#define GNOME_CMD_TYPE_FILE_INFO              (gnome_cmd_file_info_get_type ())
+#define GNOME_CMD_FILE_INFO(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_FILE_INFO, GnomeCmdFileInfo))
+#define GNOME_CMD_FILE_INFO_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_FILE_INFO, GnomeCmdFileInfoClass))
+#define GNOME_CMD_IS_FILE_INFO(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_FILE_INFO))
+#define GNOME_CMD_IS_FILE_INFO_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_FILE_INFO))
+#define GNOME_CMD_FILE_INFO_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_FILE_INFO, GnomeCmdFileInfoClass))
 
 
-typedef struct _GnomeCmdFileInfo        GnomeCmdFileInfo;
-typedef struct _GnomeCmdFileInfoClass   GnomeCmdFileInfoClass;
+GType gnome_cmd_file_info_get_type ();
 
-struct _GnomeCmdFileInfo
+
+struct GnomeCmdFileInfo
 {
-    GtkObject parent;
+    GObject parent;
 
     GnomeVFSURI *uri;
     GnomeVFSFileInfo *info;
+    
+    void setup(GnomeVFSURI *uri, GnomeVFSFileInfo *info);
 };
 
-struct _GnomeCmdFileInfoClass
+struct GnomeCmdFileInfoClass
 {
-    GtkObjectClass parent_class;
+    GObjectClass parent_class;
 };
 
-
-GtkType gnome_cmd_file_info_get_type ();
-
-void gnome_cmd_file_info_setup (GnomeCmdFileInfo *f, GnomeVFSURI *uri, GnomeVFSFileInfo *info);
+inline void GnomeCmdFileInfo::setup(GnomeVFSURI *uri, GnomeVFSFileInfo *info)
+{
+    this->info = info;
+    this->uri = uri;
+}
 
 #endif //__GNOME_CMD_FILE_INFO_H__
