@@ -34,8 +34,7 @@ static GtkObjectClass *parent_class = NULL;
  * Gtk class implementation
  *******************************/
 
-static void
-destroy (GtkObject *object)
+static void destroy (GtkObject *object)
 {
     //GnomeCmdPlugin *plugin = GNOME_CMD_PLUGIN (object);
 
@@ -44,8 +43,7 @@ destroy (GtkObject *object)
 }
 
 
-static void
-class_init (GnomeCmdPluginClass *klass)
+static void class_init (GnomeCmdPluginClass *klass)
 {
     GtkObjectClass *object_class;
     GnomeCmdPluginClass *plugin_class;
@@ -63,8 +61,7 @@ class_init (GnomeCmdPluginClass *klass)
 }
 
 
-static void
-init (GnomeCmdPlugin *plugin)
+static void init (GnomeCmdPlugin *plugin)
 {
 }
 
@@ -74,8 +71,7 @@ init (GnomeCmdPlugin *plugin)
  * Public functions
  ***********************************/
 
-GtkType
-gnome_cmd_plugin_get_type ()
+GtkType gnome_cmd_plugin_get_type ()
 {
     static GtkType type = 0;
 
@@ -99,8 +95,7 @@ gnome_cmd_plugin_get_type ()
 }
 
 
-GtkWidget *
-gnome_cmd_plugin_create_main_menu (GnomeCmdPlugin *plugin, GnomeCmdState *state)
+GtkWidget *gnome_cmd_plugin_create_main_menu (GnomeCmdPlugin *plugin, GnomeCmdState *state)
 {
     GnomeCmdPluginClass *klass;
 
@@ -112,8 +107,7 @@ gnome_cmd_plugin_create_main_menu (GnomeCmdPlugin *plugin, GnomeCmdState *state)
 }
 
 
-GList *
-gnome_cmd_plugin_create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *state)
+GList *gnome_cmd_plugin_create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState *state)
 {
     GnomeCmdPluginClass *klass;
 
@@ -125,8 +119,7 @@ gnome_cmd_plugin_create_popup_menu_items (GnomeCmdPlugin *plugin, GnomeCmdState
 }
 
 
-void
-gnome_cmd_plugin_update_main_menu_state (GnomeCmdPlugin *plugin, GnomeCmdState *state)
+void gnome_cmd_plugin_update_main_menu_state (GnomeCmdPlugin *plugin, GnomeCmdState *state)
 {
     GnomeCmdPluginClass *klass;
 
@@ -138,8 +131,7 @@ gnome_cmd_plugin_update_main_menu_state (GnomeCmdPlugin *plugin, GnomeCmdState *
 }
 
 
-void
-gnome_cmd_plugin_configure (GnomeCmdPlugin *plugin)
+void gnome_cmd_plugin_configure (GnomeCmdPlugin *plugin)
 {
     GnomeCmdPluginClass *klass;
 
@@ -149,4 +141,3 @@ gnome_cmd_plugin_configure (GnomeCmdPlugin *plugin)
 
     klass->configure (plugin);
 }
-
