@@ -22,13 +22,12 @@
 #ifndef __GNOME_CMD_PLUGIN_H__
 #define __GNOME_CMD_PLUGIN_H__
 
-#define GNOME_CMD_PLUGIN(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_plugin_get_type (), GnomeCmdPlugin)
-#define GNOME_CMD_PLUGIN_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_plugin_get_type (), GnomeCmdPluginClass)
-#define GNOME_CMD_IS_PLUGIN(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_plugin_get_type ())
-#define GNOME_CMD_PLUGIN_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_CMD_PLUGIN, GnomeCmdPluginClass))
+#define GNOME_CMD_TYPE_PLUGIN              (gnome_cmd_plugin_get_type ())
+#define GNOME_CMD_PLUGIN(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_PLUGIN, GnomeCmdPlugin))
+#define GNOME_CMD_PLUGIN_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_PLUGIN, GnomeCmdPluginClass))
+#define GNOME_CMD_IS_PLUGIN(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_PLUGIN))
+#define GNOME_CMD_IS_PLUGIN_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_PLUGIN))
+#define GNOME_CMD_PLUGIN_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_PLUGIN, GnomeCmdPluginClass))
 
 
 typedef struct _GnomeCmdPlugin GnomeCmdPlugin;
