@@ -25,7 +25,7 @@
 #include "libgcmd-utils.h"
 
 
-static gchar *get_trashed_string (const gchar *in)
+inline gchar *get_trashed_string (const gchar *in)
 {
     gchar *out = g_strdup (in);
     gchar *end;
@@ -55,21 +55,3 @@ gchar *get_utf8 (const gchar *unknown)
 
     return out;
 }
-
-
-gchar *get_bold_text (const gchar *in)
-{
-    return g_strdup_printf ("<span weight=\"bold\">%s</span>", in);
-}
-
-
-gchar *get_mono_text (const gchar *in)
-{
-    return g_strdup_printf ("<span font_family=\"monospace\">%s</span>", in);
-}
-
-
-gchar *get_bold_mono_text (const gchar *in)
-{
-    return g_strdup_printf ("<span font_family=\"monospace\" weight=\"bold\">%s</span>", in);
-}
