@@ -32,18 +32,19 @@
 /* This struct must never ever be changed
  * since it is needed to determinate the version of a plugin
  */
-typedef struct {
+struct PluginInfo 
+{
     gint plugin_system_version;
 
-    gchar *name;
-    gchar *version;
-    gchar *copyright;
-    gchar *comments;
+    const gchar *name;
+    const gchar *version;
+    const gchar *copyright;
+    const gchar *comments;
     gchar **authors;
     gchar **documenters;
-    gchar *translator;
-    gchar *webpage;
-} PluginInfo;
+    const gchar *translator;
+    const gchar *webpage;
+};
 
 
 /* This function prototype must never ever be changed
