@@ -28,14 +28,9 @@ except ImportError:
     import gnome.vfs as gnomevfs
 
 import os
-import sys
 import string
-if sys.version_info[0] == 2 and sys.version_info[1] < 6:
-    import md5
-    md5_new = md5.new
-else:
-    from hashlib import md5
-    md5_new = md5
+import hashlib
+
 
 def main(main_wnd_xid, active_cwd, inactive_cwd, selected_files):
     parent_dir = string.split(active_cwd, os.sep)[-1]
@@ -47,7 +42,7 @@ def main(main_wnd_xid, active_cwd, inactive_cwd, selected_files):
             f = file(active_cwd+os.sep+uri.short_name, 'rb')
             file_content = f.read()
             f.close()
-            md5sum = md5_new(file_content).hexdigest()
+            md5sum = hashlib.md5(file_content).hexdigest()
             f_md5sum.write('%s  %s\n' % (md5sum, uri.short_name))
     f_md5sum.close()
     return True
