@@ -20,7 +20,8 @@
 */
 
 #include <config.h>
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <libgnomeui/gnome-dialog-util.h>
 #include <libgcmd/libgcmd.h>
 #include "test-plugin.h"
 #include "test-plugin.xpm"
@@ -87,10 +88,10 @@ static GtkWidget *create_menu_item (const gchar *name, gboolean show_pixmap, Gtk
     gtk_container_add (GTK_CONTAINER (item), label);
 
     // Connect to the signal and set user data
-    gtk_object_set_data (GTK_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, data);
+    g_object_set_data (G_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, data);
 
     if (callback)
-        gtk_signal_connect (GTK_OBJECT (item), "activate", callback, data);
+        g_signal_connect (item, "activate", G_CALLBACK (callback), data);
 
     return item;
 }
@@ -154,7 +155,7 @@ static void class_init (TestPluginClass *klass)
 
     object_class = GTK_OBJECT_CLASS (klass);
     plugin_class = GNOME_CMD_PLUGIN_CLASS (klass);
-    parent_class = (GnomeCmdPluginClass *) gtk_type_class (gnome_cmd_plugin_get_type ());
+    parent_class = (GnomeCmdPluginClass *) gtk_type_class (GNOME_CMD_TYPE_PLUGIN);
 
     object_class->destroy = destroy;
 
@@ -194,7 +195,7 @@ GtkType test_plugin_get_type ()
             (GtkClassInitFunc) NULL
         };
 
-        type = gtk_type_unique (gnome_cmd_plugin_get_type (), &info);
+        type = gtk_type_unique (GNOME_CMD_TYPE_PLUGIN, &info);
     }
     return type;
 }
@@ -202,7 +203,7 @@ GtkType test_plugin_get_type ()
 
 GnomeCmdPlugin *test_plugin_new ()
 {
-    TestPlugin *plugin = (TestPlugin *) gtk_type_new (test_plugin_get_type ());
+    TestPlugin *plugin = (TestPlugin *) g_object_new (test_plugin_get_type (), NULL);
 
     return GNOME_CMD_PLUGIN (plugin);
 }
