@@ -28,7 +28,7 @@
 #define NAME_MAX (FILENAME_MAX)
 #endif
 
-void gnome_cmd_advrename_reset_counter(long start=1, int precision=-1, int step=1);
+void gnome_cmd_advrename_reset_counter(int n, long start=1, int precision=-1, int step=1);
 void gnome_cmd_advrename_parse_template(const char *template_string, gboolean &has_counters);
 char *gnome_cmd_advrename_gen_fname(GnomeCmdFile *f, size_t new_fname_size=NAME_MAX);
 
