@@ -56,8 +56,8 @@ static void on_perms_changed (GnomeCmdChmodComponent *comp)
 
     GnomeVFSFilePermissions perms = gnome_cmd_chmod_component_get_perms (comp);
 
-    perm2textstring (perms, text_view, 10);
-    perm2numstring (perms, number_view, 4);
+    perm2textstring (perms, text_view, sizeof(text_view));
+    perm2numstring (perms, number_view, sizeof(number_view));
     gtk_label_set_text (GTK_LABEL (comp->priv->textview_label), text_view);
     gtk_label_set_text (GTK_LABEL (comp->priv->numberview_label), number_view);
 }
@@ -138,8 +138,7 @@ static void init (GnomeCmdChmodComponent *comp)
         for (gint x=0; x<3; x++)
         {
             comp->priv->check_boxes[y][x] = create_check (GTK_WIDGET (comp), check_text[x], "check");
-            gtk_signal_connect (GTK_OBJECT (comp->priv->check_boxes[y][x]), "toggled",
-                                GTK_SIGNAL_FUNC (on_check_toggled), comp);
+            g_signal_connect (comp->priv->check_boxes[y][x], "toggled", G_CALLBACK (on_check_toggled), comp);
             table_add (GTK_WIDGET (table), comp->priv->check_boxes[y][x], x+1, y, GTK_FILL);
         }
     }
@@ -172,7 +171,7 @@ static void init (GnomeCmdChmodComponent *comp)
 
 GtkWidget *gnome_cmd_chmod_component_new (GnomeVFSFilePermissions perms)
 {
-    GnomeCmdChmodComponent *comp = (GnomeCmdChmodComponent *) gtk_type_new (gnome_cmd_chmod_component_get_type ());
+    GnomeCmdChmodComponent *comp = (GnomeCmdChmodComponent *) g_object_new (GNOME_CMD_TYPE_CHMOD_COMPONENT, NULL);
 
     gnome_cmd_chmod_component_set_perms (comp, perms);
 
