@@ -21,15 +21,12 @@
 #ifndef __GNOME_CMD_CLIST_H__
 #define __GNOME_CMD_CLIST_H__
 
-#define GNOME_CMD_CLIST(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_clist_get_type (), GnomeCmdCList)
-#define GNOME_CMD_CLIST_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_clist_get_type (), GnomeCmdCListClass)
-#define GNOME_CMD_IS_CLIST(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_clist_get_type ())
-
-
-struct GnomeCmdCListPrivate;
+#define GNOME_CMD_TYPE_CLIST              (gnome_cmd_clist_get_type ())
+#define GNOME_CMD_CLIST(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_CLIST, GnomeCmdCList))
+#define GNOME_CMD_CLIST_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_CLIST, GnomeCmdCListClass))
+#define GNOME_CMD_IS_CLIST(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_CLIST))
+#define GNOME_CMD_IS_CLIST_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_CLIST))
+#define GNOME_CMD_CLIST_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_CLIST, GnomeCmdCListClass))
 
 
 struct GnomeCmdCList
@@ -37,8 +34,6 @@ struct GnomeCmdCList
     GtkCList parent;
 
     gint drag_motion_row;
-
-    GnomeCmdCListPrivate *priv;
 };
 
 
@@ -58,7 +53,7 @@ inline GtkWidget *gnome_cmd_clist_new (gint columns)
     return gnome_cmd_clist_new_with_titles (columns, NULL);
 }
 
-void gnome_cmd_clist_update_style        (GnomeCmdCList *clist);
+void gnome_cmd_clist_update_style (GnomeCmdCList *clist);
 
 gint gnome_cmd_clist_get_voffset (GnomeCmdCList *clist);
 void gnome_cmd_clist_set_voffset (GnomeCmdCList *clist, gint voffset);
