@@ -37,7 +37,7 @@ static GtkHBoxClass *parent_class = NULL;
 
 struct GnomeCmdCmdlinePrivate
 {
-    GtkWidget *combo;
+    GnomeCmdCombo *combo;
     GtkWidget *cwd;
 
     GList *history;
@@ -46,20 +46,20 @@ struct GnomeCmdCmdlinePrivate
 
 inline void update_history_combo (GnomeCmdCmdline *cmdline)
 {
-    gnome_cmd_combo_clear (GNOME_CMD_COMBO (cmdline->priv->combo));
+    cmdline->priv->combo->clear();
 
     gchar *text[2];
 
     text[1] = NULL;
 
-    for (GList *tmp = cmdline->priv->history; tmp; tmp = tmp->next)
+    for (GList *i = cmdline->priv->history; i; i = i->next)
     {
-        gchar *command = text[0] = (gchar *) tmp->data;
+        gchar *command = text[0] = (gchar *) i->data;
 
-        gnome_cmd_combo_append (GNOME_CMD_COMBO (cmdline->priv->combo), text, command);
+        cmdline->priv->combo->append(text, command);
     }
 
-    gtk_clist_select_row (GTK_CLIST (GNOME_CMD_COMBO (cmdline->priv->combo)->list), 0, 0);
+    gtk_clist_select_row (GTK_CLIST (cmdline->priv->combo->list), 0, 0);
 }
 
 
@@ -75,10 +75,10 @@ static void on_exec (GnomeCmdCmdline *cmdline, gboolean term)
 {
     const gchar *cmdline_text;
 
-    cmdline_text = gtk_entry_get_text (GTK_ENTRY (GNOME_CMD_COMBO (cmdline->priv->combo)->entry));
+    cmdline_text = gtk_entry_get_text (GTK_ENTRY (cmdline->priv->combo->entry));
     cmdline_text = g_strstrip (g_strdup (cmdline_text));
 
-    GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
+    GnomeCmdFileSelector *fs = main_win->fs(ACTIVE);
 
     if (g_str_has_prefix (cmdline_text, "cd "))   // if cmdline_text starts with "cd " then it MUST have at least 4 chars (as it's been previously g_strstrip'ed)
     {
@@ -104,7 +104,7 @@ static void on_exec (GnomeCmdCmdline *cmdline, gboolean term)
         else
             if (fs->is_local())
             {
-                gchar *fpath = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (fs->get_directory()));
+                gchar *fpath = GNOME_CMD_FILE (fs->get_directory())->get_real_path ();
 
                 run_command_indir (cmdline_text, fpath, term);
                 g_free (fpath);
@@ -132,7 +132,7 @@ static gboolean on_key_pressed (GtkWidget *entry, GdkEventKey *event, GnomeCmdCm
             break;
     }
 
-    return gnome_cmd_cmdline_keypressed (cmdline, event) || gnome_cmd_main_win_keypressed (main_win, event);
+    return gnome_cmd_cmdline_keypressed (cmdline, event) || main_win->key_pressed(event);
 }
 
 
@@ -150,7 +150,6 @@ static void on_combo_item_selected (GnomeCmdCombo *combo, const gchar *command,
 static void on_combo_popwin_hidden (GnomeCmdCombo *combo, GnomeCmdCmdline *cmdline)
 {
     g_return_if_fail (GNOME_CMD_IS_COMBO (combo));
-    g_return_if_fail (GNOME_CMD_IS_CMDLINE (cmdline));
 
     gtk_widget_grab_focus (combo->entry);
 }
@@ -174,7 +173,7 @@ static void on_fs_changed_dir (GnomeCmdFileSelector *fs, GnomeCmdDir *dir, Gnome
     g_return_if_fail (dir != NULL);
     g_return_if_fail (GNOME_CMD_IS_CMDLINE (cmdline));
 
-    if (fs != gnome_cmd_main_win_get_fs (main_win, ACTIVE))
+    if (fs != main_win->fs(ACTIVE))
         return;
 
     gchar *dpath = gnome_cmd_dir_get_display_path (dir);
@@ -189,11 +188,9 @@ static void on_fs_changed_dir (GnomeCmdFileSelector *fs, GnomeCmdDir *dir, Gnome
 
 static void destroy (GtkObject *object)
 {
-    gtk_signal_disconnect_by_func (GTK_OBJECT (main_win), GTK_SIGNAL_FUNC (on_switch_fs), object);
-    gtk_signal_disconnect_by_func (GTK_OBJECT (gnome_cmd_main_win_get_fs (main_win, LEFT)),
-                                   GTK_SIGNAL_FUNC (on_fs_changed_dir), object);
-    gtk_signal_disconnect_by_func (GTK_OBJECT (gnome_cmd_main_win_get_fs (main_win, RIGHT)),
-                                   GTK_SIGNAL_FUNC (on_fs_changed_dir), object);
+    g_signal_handlers_disconnect_by_func (main_win, (gpointer) on_switch_fs, object);
+    g_signal_handlers_disconnect_by_func (main_win->fs(LEFT), (gpointer) on_fs_changed_dir, object);
+    g_signal_handlers_disconnect_by_func (main_win->fs(RIGHT), (gpointer) on_fs_changed_dir, object);
 
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
@@ -228,46 +225,35 @@ static void init (GnomeCmdCmdline *cmdline)
     // cmdline->priv->history = NULL;
 
     cmdline->priv->cwd = gtk_label_new ("cwd");
-    gtk_widget_ref (cmdline->priv->cwd);
-    gtk_object_set_data_full (GTK_OBJECT (cmdline), "cwdlabel", cmdline->priv->cwd,
-                              (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (cmdline->priv->cwd);
+    g_object_set_data_full (G_OBJECT (cmdline), "cwdlabel", cmdline->priv->cwd, g_object_unref);
     gtk_widget_show (cmdline->priv->cwd);
     gtk_box_pack_start (GTK_BOX (cmdline), cmdline->priv->cwd,
                         FALSE, TRUE, 2);
     gtk_label_set_selectable (GTK_LABEL (cmdline->priv->cwd), TRUE);
 
     label = gtk_label_new ("#");
-    gtk_widget_ref (label);
-    gtk_object_set_data_full (GTK_OBJECT (cmdline), "label", label,
-                              (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (label);
+    g_object_set_data_full (G_OBJECT (cmdline), "label", label, g_object_unref);
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (cmdline), label, FALSE, FALSE, 0);
 
-    cmdline->priv->combo = gnome_cmd_combo_new (1, 0, NULL);
-    gtk_widget_ref (cmdline->priv->combo);
-    gtk_object_set_data_full (GTK_OBJECT (cmdline), "combo", cmdline->priv->combo,
-                              (GtkDestroyNotify) gtk_widget_unref);
-    gtk_clist_set_column_width (
-        GTK_CLIST (GNOME_CMD_COMBO (cmdline->priv->combo)->list), 0, 500);
-    gtk_box_pack_start (GTK_BOX (cmdline), cmdline->priv->combo, TRUE, TRUE, 2);
-    gtk_widget_show (cmdline->priv->combo);
-    gtk_entry_set_editable (GTK_ENTRY (GNOME_CMD_COMBO (cmdline->priv->combo)->entry), TRUE);
-    GTK_WIDGET_UNSET_FLAGS (GNOME_CMD_COMBO (cmdline->priv->combo)->button, GTK_CAN_FOCUS);
-    GTK_WIDGET_SET_FLAGS (GNOME_CMD_COMBO (cmdline->priv->combo)->entry, GTK_CAN_FOCUS);
+    cmdline->priv->combo = new GnomeCmdCombo(1, 0);
+    g_object_ref (cmdline->priv->combo);
+    g_object_set_data_full (G_OBJECT (cmdline), "combo", cmdline->priv->combo, g_object_unref);
+    gtk_clist_set_column_width (GTK_CLIST (cmdline->priv->combo->list), 0, 500);
+    gtk_box_pack_start (GTK_BOX (cmdline), *cmdline->priv->combo, TRUE, TRUE, 2);
+    gtk_widget_show (*cmdline->priv->combo);
+    gtk_entry_set_editable (GTK_ENTRY (cmdline->priv->combo->entry), TRUE);
+    GTK_WIDGET_UNSET_FLAGS (cmdline->priv->combo->button, GTK_CAN_FOCUS);
+    GTK_WIDGET_SET_FLAGS (cmdline->priv->combo->entry, GTK_CAN_FOCUS);
 
-    gtk_signal_connect (GTK_OBJECT (GNOME_CMD_COMBO (cmdline->priv->combo)->entry),
-                        "key-press-event",
-                        GTK_SIGNAL_FUNC (on_key_pressed), cmdline);
-    gtk_signal_connect (GTK_OBJECT (cmdline->priv->combo), "item-selected",
-                        GTK_SIGNAL_FUNC (on_combo_item_selected), cmdline);
-    gtk_signal_connect (GTK_OBJECT (cmdline->priv->combo), "popwin-hidden",
-                        GTK_SIGNAL_FUNC (on_combo_popwin_hidden), cmdline);
-    gtk_signal_connect_after (GTK_OBJECT (main_win), "switch-fs",
-                        GTK_SIGNAL_FUNC (on_switch_fs), cmdline);
-    gtk_signal_connect (GTK_OBJECT (gnome_cmd_main_win_get_fs (main_win, LEFT)),
-                        "changed-dir", GTK_SIGNAL_FUNC (on_fs_changed_dir), cmdline);
-    gtk_signal_connect (GTK_OBJECT (gnome_cmd_main_win_get_fs (main_win, RIGHT)),
-                        "changed-dir", GTK_SIGNAL_FUNC (on_fs_changed_dir), cmdline);
+    g_signal_connect (cmdline->priv->combo->entry, "key-press-event", G_CALLBACK (on_key_pressed), cmdline);
+    g_signal_connect (cmdline->priv->combo, "item-selected", G_CALLBACK (on_combo_item_selected), cmdline);
+    g_signal_connect (cmdline->priv->combo, "popwin-hidden", G_CALLBACK (on_combo_popwin_hidden), cmdline);
+    g_signal_connect_after (main_win, "switch-fs", G_CALLBACK (on_switch_fs), cmdline);
+    g_signal_connect (main_win->fs(LEFT), "dir-changed", G_CALLBACK (on_fs_changed_dir), cmdline);
+    g_signal_connect (main_win->fs(RIGHT), "dir-changed", G_CALLBACK (on_fs_changed_dir), cmdline);
 
     gnome_cmd_cmdline_update_style (cmdline);
 }
@@ -279,7 +265,7 @@ static void init (GnomeCmdCmdline *cmdline)
 
 GtkWidget *gnome_cmd_cmdline_new ()
 {
-    GnomeCmdCmdline *cmdline = (GnomeCmdCmdline *) gtk_type_new (gnome_cmd_cmdline_get_type ());
+    GnomeCmdCmdline *cmdline = (GnomeCmdCmdline *) g_object_new (GNOME_CMD_TYPE_CMDLINE, NULL);
 
     gnome_cmd_cmdline_set_history (cmdline, gnome_cmd_data.cmdline_history);
     update_history_combo (cmdline);
@@ -330,7 +316,7 @@ void gnome_cmd_cmdline_append_text (GnomeCmdCmdline *cmdline, const gchar *text)
     g_return_if_fail (cmdline->priv != NULL);
     g_return_if_fail (cmdline->priv->combo != NULL);
 
-    GtkEntry *entry = GTK_ENTRY (GNOME_CMD_COMBO (cmdline->priv->combo)->entry);
+    GtkEntry *entry = GTK_ENTRY (cmdline->priv->combo->entry);
     const gchar *curtext = gtk_entry_get_text (entry);
 
     if (curtext[strlen(curtext)-1] != ' ' && strlen(curtext) > 0)
@@ -348,7 +334,7 @@ void gnome_cmd_cmdline_insert_text (GnomeCmdCmdline *cmdline, const gchar *text)
     g_return_if_fail (cmdline->priv != NULL);
     g_return_if_fail (cmdline->priv->combo != NULL);
 
-    GtkEntry *entry = GTK_ENTRY (GNOME_CMD_COMBO (cmdline->priv->combo)->entry);
+    GtkEntry *entry = GTK_ENTRY (cmdline->priv->combo->entry);
     gint curpos = gtk_editable_get_position (GTK_EDITABLE (entry));
     gint tmp = curpos;
     gtk_editable_insert_text (GTK_EDITABLE (entry), text, strlen (text), &tmp);
@@ -362,13 +348,13 @@ void gnome_cmd_cmdline_set_text (GnomeCmdCmdline *cmdline, const gchar *text)
     g_return_if_fail (cmdline->priv != NULL);
     g_return_if_fail (cmdline->priv->combo != NULL);
 
-    gtk_entry_set_text (GTK_ENTRY (GNOME_CMD_COMBO (cmdline->priv->combo)->entry), text);
+    gtk_entry_set_text (GTK_ENTRY (cmdline->priv->combo->entry), text);
 }
 
 
 gboolean gnome_cmd_cmdline_is_empty (GnomeCmdCmdline *cmdline)
 {
-    const gchar *text = gtk_entry_get_text (GTK_ENTRY (GNOME_CMD_COMBO (cmdline->priv->combo)->entry));
+    const gchar *text = gtk_entry_get_text (GTK_ENTRY (cmdline->priv->combo->entry));
 
     if (text == NULL || strcmp (text, ""))
         return TRUE;
@@ -388,8 +374,8 @@ void gnome_cmd_cmdline_focus (GnomeCmdCmdline *cmdline)
     g_return_if_fail (GNOME_CMD_IS_CMDLINE (cmdline));
     g_return_if_fail (cmdline->priv->combo != NULL);
 
-    gtk_widget_grab_focus (GTK_WIDGET (GNOME_CMD_COMBO (cmdline->priv->combo)->entry));
-    gtk_editable_set_position (GTK_EDITABLE (GNOME_CMD_COMBO (cmdline->priv->combo)->entry), -1);
+    gtk_widget_grab_focus (GTK_WIDGET (cmdline->priv->combo->entry));
+    gtk_editable_set_position (GTK_EDITABLE (cmdline->priv->combo->entry), -1);
 }
 
 
@@ -397,7 +383,7 @@ void gnome_cmd_cmdline_update_style (GnomeCmdCmdline *cmdline)
 {
     g_return_if_fail (GNOME_CMD_IS_CMDLINE (cmdline));
 
-    gnome_cmd_combo_update_style (GNOME_CMD_COMBO (cmdline->priv->combo));
+    cmdline->priv->combo->update_style();
 }
 
 
@@ -405,7 +391,7 @@ void gnome_cmd_cmdline_show_history (GnomeCmdCmdline *cmdline)
 {
     g_return_if_fail (GNOME_CMD_IS_CMDLINE (cmdline));
 
-    gnome_cmd_combo_popup_list (GNOME_CMD_COMBO (cmdline->priv->combo));
+    cmdline->priv->combo->popup_list();
 }
 
 
@@ -423,8 +409,8 @@ void gnome_cmd_cmdline_set_history (GnomeCmdCmdline *cmdline, GList *history)
 
     // free the old history
 
-    for (GList *tmp = cmdline->priv->history; tmp; tmp = tmp->next)
-        g_free (tmp->data);
+    for (GList *i = cmdline->priv->history; i; i = i->next)
+        g_free (i->data);
 
     cmdline->priv->history = history;
 }
@@ -434,7 +420,7 @@ GtkWidget *gnome_cmd_cmdline_get_entry (GnomeCmdCmdline *cmdline)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CMDLINE (cmdline), NULL);
 
-    return GNOME_CMD_COMBO (cmdline->priv->combo)->entry;
+    return cmdline->priv->combo->entry;
 }
 
 
@@ -482,7 +468,7 @@ gboolean gnome_cmd_cmdline_keypressed (GnomeCmdCmdline *cmdline, GdkEventKey *ev
 
                     case GDK_Escape:
                         gnome_cmd_cmdline_set_text (cmdline, "");
-                        gnome_cmd_main_win_focus_file_lists (main_win);
+                        main_win->focus_file_lists();
                         return TRUE;
 
                     case GDK_Up:
@@ -490,8 +476,8 @@ gboolean gnome_cmd_cmdline_keypressed (GnomeCmdCmdline *cmdline, GdkEventKey *ev
                         {
                             gboolean ret;
                             GdkEventKey event2 = *event;
-                            GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
-                            GtkWidget *file_list = fs->list_widget;
+                            GnomeCmdFileSelector *fs = main_win->fs(ACTIVE);
+                            GtkWidget *file_list = *fs->file_list();
 
                             gtk_widget_grab_focus (file_list);
                             fs->set_active(TRUE);
