@@ -20,9 +20,9 @@
 */
 
 #include <config.h>
+#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-volume.h>
 
 #include "gnome-cmd-includes.h"
@@ -115,7 +115,7 @@ static void do_mount_thread_func (GnomeCmdCon *con)
         DEBUG ('m', "mount returned %d and had the exitstatus %d\n", ret, estatus);
 
         if (ret == -1)
-            emsg = g_strdup_printf (_("Failed to execute the mount command"));
+            emsg = g_strdup (_("Failed to execute the mount command"));
         else
             switch (estatus)
             {
@@ -123,22 +123,20 @@ static void do_mount_thread_func (GnomeCmdCon *con)
                     emsg = NULL;
                     break;
                 case 1:
-                    emsg = g_strdup (_("Mount failed: Permission denied"));
+                    emsg = g_strdup (_("Mount failed: permission denied"));
                     break;
                 case 32:
-                    emsg = g_strdup (_("Mount failed: No medium found"));
+                    emsg = g_strdup (_("Mount failed: no medium found"));
                     break;
                 default:
-                    emsg = g_strdup_printf (
-                        _("Mount failed: mount exited with existatus %d"),
-                        estatus);
+                    emsg = g_strdup_printf (_("Mount failed: mount exited with existatus %d"), estatus);
                     break;
             }
 
         if (emsg != NULL)
         {
-            con->open_result = CON_OPEN_FAILED;
-            con->state = CON_STATE_CLOSED;
+            con->open_result = GnomeCmdCon::OPEN_FAILED;
+            con->state = GnomeCmdCon::STATE_CLOSED;
             con->open_failed_msg = emsg;
             return;
         }
@@ -159,16 +157,16 @@ static void do_mount_thread_func (GnomeCmdCon *con)
 
     if (result == GNOME_VFS_OK)
     {
-        con->state = CON_STATE_OPEN;
-        con->open_result = CON_OPEN_OK;
+        con->state = GnomeCmdCon::STATE_OPEN;
+        con->open_result = GnomeCmdCon::OPEN_OK;
     }
     else
     {
         gnome_vfs_file_info_unref (con->base_info);
         con->base_info = NULL;
         con->open_failed_reason = result;
-        con->open_result = CON_OPEN_FAILED;
-        con->state = CON_STATE_CLOSED;
+        con->open_result = GnomeCmdCon::OPEN_FAILED;
+        con->state = GnomeCmdCon::STATE_CLOSED;
     }
 }
 
@@ -180,13 +178,10 @@ static void dev_open (GnomeCmdCon *con)
     DEBUG ('m', "Mounting device\n");
 
     if (!con->base_path)
-    {
-        con->base_path = gnome_cmd_plain_path_new (G_DIR_SEPARATOR_S);
-        gtk_object_ref (GTK_OBJECT (con->base_path));
-    }
+        con->base_path = new GnomeCmdPlainPath(G_DIR_SEPARATOR_S);
 
-    con->state = CON_STATE_OPENING;
-    con->open_result = CON_OPEN_IN_PROGRESS;
+    con->state = GnomeCmdCon::STATE_OPENING;
+    con->open_result = GnomeCmdCon::OPEN_IN_PROGRESS;
 
     g_thread_create ((GThreadFunc) do_mount_thread_func, con, FALSE, NULL);
 }
@@ -196,28 +191,25 @@ static void dev_vfs_umount_callback (gboolean succeeded, char *error, char *deta
 {
     GtkWidget *msgbox;
 
-    DEBUG('m', "VFS Umount Callback: %s %s %s\n", succeeded ? "Succeeded" : "Failed",
+    DEBUG('m', "VFS umount callback: %s %s %s\n", succeeded ? "succeeded" : "failed",
                error ? error : "",
                detailed_error ? detailed_error : "");
 
     if (succeeded)
-    {
-            msgbox = gtk_message_dialog_new (GTK_WINDOW (main_win),
-                            GTK_DIALOG_MODAL,
-                            GTK_MESSAGE_INFO,
-                            GTK_BUTTONS_OK,
-                            _("Device is now safe to remove"));
-    }
+        msgbox = gtk_message_dialog_new (*main_win,
+                                         GTK_DIALOG_MODAL,
+                                         GTK_MESSAGE_INFO,
+                                         GTK_BUTTONS_OK,
+                                         _("Device is now safe to remove"));
     else
-    {
-            msgbox = gtk_message_dialog_new (GTK_WINDOW (main_win),
-                            GTK_DIALOG_MODAL,
-                            GTK_MESSAGE_ERROR,
-                            GTK_BUTTONS_OK,
-                            _("Cannot unmount the volume:\n%s %s"),
-                            error ? error : _("Unknown error"),
-                            detailed_error ? detailed_error: "");
-    }
+        msgbox = gtk_message_dialog_new (*main_win,
+                                         GTK_DIALOG_MODAL,
+                                         GTK_MESSAGE_ERROR,
+                                         GTK_BUTTONS_OK,
+                                         _("Cannot unmount the volume:\n%s %s"),
+                                         error ? error : _("Unknown error"),
+                                         detailed_error ? detailed_error: "");
+
     gtk_dialog_run (GTK_DIALOG (msgbox));
     gtk_widget_destroy (msgbox);
 }
@@ -232,7 +224,6 @@ static gboolean dev_close (GnomeCmdCon *con)
     GnomeCmdConDevice *dev_con = GNOME_CMD_CON_DEVICE (con);
 
     gnome_cmd_con_set_default_dir (con, NULL);
-    gnome_cmd_con_set_cwd (con, NULL);
 
     chdir (g_get_home_dir ());
 
@@ -245,7 +236,7 @@ static gboolean dev_close (GnomeCmdCon *con)
             DEBUG ('m', "umounting VFS volume \"%s\"\n", name);
             g_free (name);
 
-            gnome_vfs_volume_unmount(dev_con->priv->vfsvol, dev_vfs_umount_callback, NULL);
+            gnome_vfs_volume_unmount (dev_con->priv->vfsvol, dev_vfs_umount_callback, NULL);
         }
     }
     else
@@ -258,7 +249,7 @@ static gboolean dev_close (GnomeCmdCon *con)
     }
 
     if (ret == 0)
-        con->state = CON_STATE_CLOSED;
+        con->state = GnomeCmdCon::STATE_CLOSED;
 
     return ret == 0;
 }
@@ -281,12 +272,11 @@ static gboolean dev_open_is_needed (GnomeCmdCon *con)
 static GnomeVFSURI *dev_create_uri (GnomeCmdCon *con, GnomeCmdPath *path)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CON_DEVICE (con), NULL);
-    g_return_val_if_fail (GNOME_CMD_IS_PATH (path), NULL);
+    g_return_val_if_fail (path!=NULL, NULL);
 
     GnomeCmdConDevice *dev_con = GNOME_CMD_CON_DEVICE (con);
 
-    const gchar *path_str = gnome_cmd_path_get_path (path);
-    gchar *p = g_build_path (G_DIR_SEPARATOR_S, dev_con->priv->mountp, path_str, NULL);
+    gchar *p = g_build_filename (dev_con->priv->mountp, path->get_path(), NULL);
     GnomeVFSURI *u1 = gnome_vfs_uri_new ("file:");
     GnomeVFSURI *u2 = gnome_vfs_uri_append_path (u1, p);
     gnome_vfs_uri_unref (u1);
@@ -300,7 +290,7 @@ static GnomeCmdPath *dev_create_path (GnomeCmdCon *con, const gchar *path_str)
     g_return_val_if_fail (GNOME_CMD_IS_CON_DEVICE (con), NULL);
     g_return_val_if_fail (path_str != NULL, NULL);
 
-    return gnome_cmd_plain_path_new (path_str);
+    return new GnomeCmdPlainPath(path_str);
 }
 
 
@@ -314,7 +304,7 @@ static void destroy (GtkObject *object)
 
     if (con->priv->vfsvol)
     {
-        gnome_vfs_volume_unref(con->priv->vfsvol);
+        gnome_vfs_volume_unref (con->priv->vfsvol);
         con->priv->vfsvol = NULL;
     }
 
@@ -332,7 +322,7 @@ static void class_init (GnomeCmdConDeviceClass *klass)
 
     object_class = GTK_OBJECT_CLASS (klass);
     con_class = GNOME_CMD_CON_CLASS (klass);
-    parent_class = (GnomeCmdConClass *) gtk_type_class (gnome_cmd_con_get_type ());
+    parent_class = (GnomeCmdConClass *) gtk_type_class (GNOME_CMD_TYPE_CON);
 
     object_class->destroy = destroy;
 
@@ -386,7 +376,7 @@ GtkType gnome_cmd_con_device_get_type ()
             (GtkClassInitFunc) NULL
         };
 
-        type = gtk_type_unique (gnome_cmd_con_get_type (), &info);
+        type = gtk_type_unique (GNOME_CMD_TYPE_CON, &info);
     }
     return type;
 }
@@ -394,7 +384,8 @@ GtkType gnome_cmd_con_device_get_type ()
 
 GnomeCmdConDevice *gnome_cmd_con_device_new (const gchar *alias, const gchar *device_fn, const gchar *mountp, const gchar *icon_path)
 {
-    GnomeCmdConDevice *dev = (GnomeCmdConDevice *) gtk_type_new (gnome_cmd_con_device_get_type ());
+    GnomeCmdConDevice *dev = (GnomeCmdConDevice *) g_object_new (GNOME_CMD_TYPE_CON_DEVICE, NULL);
+    GnomeCmdCon *con = GNOME_CMD_CON (dev);
 
     gnome_cmd_con_device_set_device_fn (dev, device_fn);
     gnome_cmd_con_device_set_mountp (dev, mountp);
@@ -403,7 +394,9 @@ GnomeCmdConDevice *gnome_cmd_con_device_new (const gchar *alias, const gchar *de
     gnome_cmd_con_device_set_vfs_volume(dev, NULL);
     gnome_cmd_con_device_set_alias (dev, alias);
 
-    GNOME_CMD_CON (dev)->open_msg = g_strdup_printf (_("Mounting %s"), alias);
+    gnome_cmd_con_set_root_path (con, mountp);
+
+    con->open_msg = g_strdup_printf (_("Mounting %s"), alias);
 
     return dev;
 }
@@ -432,10 +425,7 @@ void gnome_cmd_con_device_set_device_fn (GnomeCmdConDevice *dev, const gchar *de
 
     g_free (dev->priv->device_fn);
 
-    if (!device_fn)
-        dev->priv->device_fn = NULL;
-    else
-        dev->priv->device_fn = g_strdup (device_fn);
+    dev->priv->device_fn = g_strdup (device_fn);
 }
 
 
@@ -517,8 +507,9 @@ void gnome_cmd_con_device_set_vfs_volume (GnomeCmdConDevice *dev, GnomeVFSVolume
     g_return_if_fail (dev != NULL);
     g_return_if_fail (dev->priv != NULL);
 
-    if (dev->priv->vfsvol) {
-        gnome_vfs_volume_unref(dev->priv->vfsvol);
+    if (dev->priv->vfsvol)
+    {
+        gnome_vfs_volume_unref (dev->priv->vfsvol);
         dev->priv->vfsvol = NULL;
     }
 
