@@ -59,7 +59,7 @@ static gboolean home_open_is_needed (GnomeCmdCon *con)
 static GnomeVFSURI *home_create_uri (GnomeCmdCon *con, GnomeCmdPath *path)
 {
     GnomeVFSURI *u1 = gnome_vfs_uri_new ("file:");
-    GnomeVFSURI *u2 = gnome_vfs_uri_append_path (u1, gnome_cmd_path_get_path (path));
+    GnomeVFSURI *u2 = gnome_vfs_uri_append_path (u1, path->get_path());
     gnome_vfs_uri_unref (u1);
 
     return u2;
@@ -68,7 +68,7 @@ static GnomeVFSURI *home_create_uri (GnomeCmdCon *con, GnomeCmdPath *path)
 
 static GnomeCmdPath *home_create_path (GnomeCmdCon *con, const gchar *path_str)
 {
-    return gnome_cmd_plain_path_new (path_str);
+    return new GnomeCmdPlainPath(path_str);
 }
 
 
@@ -79,8 +79,6 @@ static GnomeCmdPath *home_create_path (GnomeCmdCon *con, const gchar *path_str)
 
 static void destroy (GtkObject *object)
 {
-    GnomeCmdConHome *con = GNOME_CMD_CON_HOME (object);
-
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
@@ -91,7 +89,7 @@ static void class_init (GnomeCmdConHomeClass *klass)
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GnomeCmdConClass *con_class = GNOME_CMD_CON_CLASS (klass);
 
-    parent_class = (GnomeCmdConClass *) gtk_type_class (gnome_cmd_con_get_type ());
+    parent_class = (GnomeCmdConClass *) gtk_type_class (GNOME_CMD_TYPE_CON);
 
     object_class->destroy = destroy;
 
@@ -110,11 +108,11 @@ static void init (GnomeCmdConHome *home_con)
 
     GnomeCmdCon *con = GNOME_CMD_CON (home_con);
 
-    con->state = CON_STATE_OPEN;
+    con->state = GnomeCmdCon::STATE_OPEN;
     con->alias = g_strdup (_("Home"));
     con->method = CON_LOCAL;
     con->open_msg = g_strdup ("This should not be visible anywhere");
-    con->should_remember_dir = FALSE;
+    con->should_remember_dir = TRUE;
     con->needs_open_visprog = FALSE;
     con->needs_list_visprog = FALSE;
     con->can_show_free_space = TRUE;
@@ -125,11 +123,9 @@ static void init (GnomeCmdConHome *home_con)
     con->open_pixmap = gnome_cmd_pixmap_new_from_icon ("gnome-fs-home", dev_icon_size);
     con->close_pixmap = gnome_cmd_pixmap_new_from_icon ("gnome-fs-home", dev_icon_size);
 
-    GnomeCmdPath *path = gnome_cmd_plain_path_new (g_get_home_dir ());
-    GnomeCmdDir *dir = gnome_cmd_dir_new (con, path);
+    GnomeCmdDir *dir = gnome_cmd_dir_new (con, new GnomeCmdPlainPath(g_get_home_dir ()));
 
     gnome_cmd_con_set_default_dir (con, dir);
-    gnome_cmd_con_set_cwd (con, dir);
 }
 
 
@@ -156,7 +152,7 @@ GtkType gnome_cmd_con_home_get_type ()
             (GtkClassInitFunc) NULL
         };
 
-        type = gtk_type_unique (gnome_cmd_con_get_type (), &info);
+        type = gtk_type_unique (GNOME_CMD_TYPE_CON, &info);
     }
     return type;
 }
@@ -164,7 +160,7 @@ GtkType gnome_cmd_con_home_get_type ()
 
 GnomeCmdCon *gnome_cmd_con_home_new ()
 {
-    GnomeCmdConHome *con = (GnomeCmdConHome *) gtk_type_new (gnome_cmd_con_home_get_type ());
+    GnomeCmdConHome *con = (GnomeCmdConHome *) g_object_new (GNOME_CMD_TYPE_CON_HOME, NULL);
 
     return GNOME_CMD_CON (con);
 }
