@@ -31,6 +31,12 @@
 using namespace std;
 
 
+struct GnomeCmdConSmbClass
+{
+    GnomeCmdConClass parent_class;
+};
+
+
 static GnomeCmdConClass *parent_class = NULL;
 
 
@@ -41,39 +47,37 @@ get_file_info_callback (GnomeVFSAsyncHandle *handle,
 {
     g_return_if_fail (results != NULL);
 
-    GnomeCmdConSmb *smb_con = GNOME_CMD_CON_SMB (con);
-
-    if (con->state == CON_STATE_OPENING)
+    if (con->state == GnomeCmdCon::STATE_OPENING)
     {
         GnomeVFSGetFileInfoResult *r = (GnomeVFSGetFileInfoResult *) results->data;
 
         if (r && r->result == GNOME_VFS_OK)
         {
             gnome_vfs_file_info_ref (r->file_info);
-            con->state = CON_STATE_OPEN;
+            con->state = GnomeCmdCon::STATE_OPEN;
             con->base_info = r->file_info;
-            con->open_result = CON_OPEN_OK;
+            con->open_result = GnomeCmdCon::OPEN_OK;
         }
         else if (r)
         {
-            con->state = CON_STATE_CLOSED;
-            con->open_result = CON_OPEN_FAILED;
+            con->state = GnomeCmdCon::STATE_CLOSED;
+            con->open_result = GnomeCmdCon::OPEN_FAILED;
             con->open_failed_reason = r->result;
         }
         else
         {
             g_warning ("No result at all");
-            con->state = CON_STATE_CLOSED;
-            con->open_result = CON_OPEN_FAILED;
+            con->state = GnomeCmdCon::STATE_CLOSED;
+            con->open_result = GnomeCmdCon::OPEN_FAILED;
         }
     }
     else
     {
-        if (con->state == CON_STATE_CANCELLING)
+        if (con->state == GnomeCmdCon::STATE_CANCELLING)
             DEBUG('m', "The open operation was cancelled, doing nothing\n");
         else
             DEBUG('m', "Strange ConState %d\n", con->state);
-        con->state = CON_STATE_CLOSED;
+        con->state = GnomeCmdCon::STATE_CLOSED;
     }
 }
 
@@ -81,17 +85,14 @@ get_file_info_callback (GnomeVFSAsyncHandle *handle,
 static void smb_open (GnomeCmdCon *con)
 {
     if (!con->base_path)
-    {
-        con->base_path = gnome_cmd_smb_path_new (NULL, NULL, NULL);
-        gtk_object_ref (GTK_OBJECT (con->base_path));
-    }
+        con->base_path = new GnomeCmdSmbPath(NULL, NULL, NULL);
 
     GnomeVFSURI *uri = gnome_cmd_con_create_uri (con, con->base_path);
     if (!uri)
     {
         DEBUG('m', "gnome_cmd_con_create_uri returned NULL\n");
-        con->state = CON_STATE_CLOSED;
-        con->open_result = CON_OPEN_FAILED;
+        con->state = GnomeCmdCon::STATE_CLOSED;
+        con->open_result = GnomeCmdCon::OPEN_FAILED;
         con->open_failed_msg = g_strdup (_("Failed to browse the network. Is the SMB module installed?"));
         return;
     }
@@ -99,8 +100,8 @@ static void smb_open (GnomeCmdCon *con)
     DEBUG('l', "Connecting to %s\n", gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE));
     GList *uri_list = g_list_append (NULL, uri);
 
-    con->state = CON_STATE_OPENING;
-    con->open_result = CON_OPEN_IN_PROGRESS;
+    con->state = GnomeCmdCon::STATE_OPENING;
+    con->open_result = GnomeCmdCon::OPEN_IN_PROGRESS;
 
     GnomeVFSAsyncHandle *handle;
     GnomeVFSFileInfoOptions infoOpts = (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_FOLLOW_LINKS |
@@ -125,7 +126,7 @@ static gboolean smb_close (GnomeCmdCon *con)
 
 static void smb_cancel_open (GnomeCmdCon *con)
 {
-    con->state = CON_STATE_CANCELLING;
+    con->state = GnomeCmdCon::STATE_CANCELLING;
 }
 
 
@@ -142,7 +143,7 @@ static GnomeVFSURI *smb_create_uri (GnomeCmdCon *con, GnomeCmdPath *path)
     u1 = gnome_vfs_uri_new ("smb:");
     if (!u1) return NULL;
 
-    u2 = gnome_vfs_uri_append_path (u1, gnome_cmd_path_get_path (path));
+    u2 = gnome_vfs_uri_append_path (u1, path->get_path());
     gnome_vfs_uri_unref (u1);
     if (!u2) return NULL;
 
@@ -158,7 +159,7 @@ static GnomeVFSURI *smb_create_uri (GnomeCmdCon *con, GnomeCmdPath *path)
 
 static GnomeCmdPath *smb_create_path (GnomeCmdCon *con, const gchar *path_str)
 {
-    return gnome_cmd_smb_path_new_from_str (path_str);
+    return new GnomeCmdSmbPath(path_str);
 }
 
 
@@ -169,8 +170,6 @@ static GnomeCmdPath *smb_create_path (GnomeCmdCon *con, const gchar *path_str)
 
 static void destroy (GtkObject *object)
 {
-    GnomeCmdConSmb *con = GNOME_CMD_CON_SMB (object);
-
     if (GTK_OBJECT_CLASS (parent_class)->destroy)
         (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
@@ -181,7 +180,7 @@ static void class_init (GnomeCmdConSmbClass *klass)
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GnomeCmdConClass *con_class = GNOME_CMD_CON_CLASS (klass);
 
-    parent_class = (GnomeCmdConClass *) gtk_type_class (gnome_cmd_con_get_type ());
+    parent_class = (GnomeCmdConClass *) gtk_type_class (GNOME_CMD_TYPE_CON);
 
     object_class->destroy = destroy;
 
@@ -239,13 +238,7 @@ GtkType gnome_cmd_con_smb_get_type ()
             (GtkClassInitFunc) NULL
         };
 
-        type = gtk_type_unique (gnome_cmd_con_get_type (), &info);
+        type = gtk_type_unique (GNOME_CMD_TYPE_CON, &info);
     }
     return type;
 }
-
-
-GnomeCmdCon *gnome_cmd_con_smb_new ()
-{
-    return GNOME_CMD_CON (gtk_type_new (gnome_cmd_con_smb_get_type ()));
-}
