@@ -23,12 +23,12 @@
 
 #include "gnome-cmd-con.h"
 
-#define GNOME_CMD_CON_SMB(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_con_smb_get_type (), GnomeCmdConSmb)
-#define GNOME_CMD_CON_SMB_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_con_smb_get_type (), GnomeCmdConSmbClass)
-#define GNOME_CMD_IS_CON_SMB(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_con_smb_get_type ())
+#define GNOME_CMD_TYPE_CON_SMB              (gnome_cmd_con_smb_get_type ())
+#define GNOME_CMD_CON_SMB(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_CON_SMB, GnomeCmdConSmb))
+#define GNOME_CMD_CON_SMB_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_CON_SMB, GnomeCmdConSmbClass))
+#define GNOME_CMD_IS_CON_SMB(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_CON_SMB))
+#define GNOME_CMD_IS_CON_SMB_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_CON_SMB))
+#define GNOME_CMD_CON_SMB_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_CON_SMB, GnomeCmdConSmbClass))
 
 
 struct GnomeCmdConSmb
@@ -36,14 +36,11 @@ struct GnomeCmdConSmb
     GnomeCmdCon parent;
 };
 
-struct GnomeCmdConSmbClass
-{
-    GnomeCmdConClass parent_class;
-};
-
-
 GtkType gnome_cmd_con_smb_get_type ();
 
-GnomeCmdCon *gnome_cmd_con_smb_new ();
+inline GnomeCmdCon *gnome_cmd_con_smb_new ()
+{
+    return GNOME_CMD_CON (g_object_new (GNOME_CMD_TYPE_CON_SMB, NULL));
+}
 
 #endif // __GNOME_CMD_CON_SMB_H__
