@@ -22,16 +22,17 @@
 #ifndef __GNOME_CMD_CON_H__
 #define __GNOME_CMD_CON_H__
 
-#define GNOME_CMD_CON(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_con_get_type (), GnomeCmdCon)
-#define GNOME_CMD_CON_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_con_get_type (), GnomeCmdConClass)
-#define GNOME_CMD_IS_CON(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_con_get_type ())
-#define GNOME_CMD_CON_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_CMD_CON, GnomeCmdConClass))
+#define GNOME_CMD_TYPE_CON              (gnome_cmd_con_get_type ())
+#define GNOME_CMD_CON(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_CON, GnomeCmdCon))
+#define GNOME_CMD_CON_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_CON, GnomeCmdConClass))
+#define GNOME_CMD_IS_CON(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_CON))
+#define GNOME_CMD_IS_CON_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_CON))
+#define GNOME_CMD_CON_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_CON, GnomeCmdConClass))
 
 struct GnomeCmdConPrivate;
 
+#include <gnome-keyring.h>
+
 #include <string>
 
 #include "gnome-cmd-path.h"
@@ -41,24 +42,7 @@ struct GnomeCmdConPrivate;
 #include "history.h"
 #include "utils.h"
 
-typedef enum
-{
-    CON_STATE_CLOSED,
-    CON_STATE_OPEN,
-    CON_STATE_OPENING,
-    CON_STATE_CANCELLING
-} ConState;
-
-typedef enum
-{
-    CON_OPEN_OK,
-    CON_OPEN_FAILED,
-    CON_OPEN_CANCELLED,
-    CON_OPEN_IN_PROGRESS,
-    CON_OPEN_NOT_STARTED
-} ConOpenResult;
-
-typedef enum        // Keep this order in sync with strings in gnome-cmd-con-dialog.cc and gnome-cmd-con.cc
+enum ConnectionMethodID        // Keep this order in sync with strings in gnome-cmd-con-dialog.cc and gnome-cmd-con.cc
 {
     CON_SSH,
     CON_SFTP = CON_SSH,
@@ -69,25 +53,51 @@ typedef enum        // Keep this order in sync with strings in gnome-cmd-con-dia
     CON_DAVS,
     CON_URI,
     CON_LOCAL      // CON_FILE ???
-} ConnectionMethodID;
+};
 
 struct GnomeCmdCon
 {
     GtkObject parent;
 
+    enum State
+    {
+        STATE_CLOSED,
+        STATE_OPEN,
+        STATE_OPENING,
+        STATE_CANCELLING
+    };
+
+    enum OpenResult
+    {
+        OPEN_OK,
+        OPEN_FAILED,
+        OPEN_CANCELLED,
+        OPEN_IN_PROGRESS,
+        OPEN_NOT_STARTED
+    };
+
+    enum Authentication
+    {
+        SAVE_NEVER,
+        SAVE_FOR_SESSION,
+        SAVE_PERMANENTLY,
+        NOT_REQUIRED
+    };
+
     gchar               *alias;                 // coded as UTF-8
     gchar               *uri;
     ConnectionMethodID  method;
-    gboolean            gnome_auth;
+    Authentication      auth;
 
     gchar               *open_msg;
     GnomeCmdPath        *base_path;
     GnomeVFSFileInfo    *base_info;
+    GString             *root_path;             // root path of the connection, used for calculation of relative paths
     gboolean            should_remember_dir;
     gboolean            needs_open_visprog;
     gboolean            needs_list_visprog;
     gboolean            can_show_free_space;
-    ConState            state;
+    State               state;
     gboolean            is_local;
     gboolean            is_closeable;
     gchar               *go_text;
@@ -100,11 +110,15 @@ struct GnomeCmdCon
     gchar               *close_tooltip;
     GnomeCmdPixmap      *close_pixmap;
 
-    ConOpenResult    open_result;
-    GnomeVFSResult   open_failed_reason;
-    gchar            *open_failed_msg;
+    OpenResult          open_result;
+    GnomeVFSResult      open_failed_reason;
+    gchar               *open_failed_msg;
 
-    GnomeCmdConPrivate *priv;
+    GnomeCmdConPrivate  *priv;
+
+    GnomeKeyringAttributeList *create_keyring_attributes();
+
+    friend XML::xstream &operator << (XML::xstream &xml, GnomeCmdCon &con);
 };
 
 struct GnomeCmdConClass
@@ -134,7 +148,7 @@ void gnome_cmd_con_open (GnomeCmdCon *con);
 inline gboolean gnome_cmd_con_is_open (GnomeCmdCon *con)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), FALSE);
-    return con->state == CON_STATE_OPEN;
+    return con->state == GnomeCmdCon::STATE_OPEN;
 }
 
 void gnome_cmd_con_cancel_open (GnomeCmdCon *con);
@@ -158,12 +172,14 @@ inline void gnome_cmd_con_set_uri (GnomeCmdCon *con, const gchar *uri=NULL)
 {
     g_return_if_fail (GNOME_CMD_IS_CON (con));
     g_free (con->uri);
-    con->uri = g_strdup (uri);
+    con->uri = (gchar *) uri;
 }
 
 inline void gnome_cmd_con_set_uri (GnomeCmdCon *con, const std::string &uri)
 {
-    gnome_cmd_con_set_uri (con, uri.empty() ? NULL : uri.c_str());
+    g_return_if_fail (GNOME_CMD_IS_CON (con));
+    g_free (con->uri);
+    con->uri = uri.empty() ? NULL : g_strdup (uri.c_str());
 }
 
 GnomeVFSURI *gnome_cmd_con_create_uri (GnomeCmdCon *con, GnomeCmdPath *path);
@@ -208,16 +224,20 @@ inline void gnome_cmd_con_set_host_name (GnomeCmdCon *con, const std::string &ho
     gnome_cmd_con_set_host_name (con, host.empty() ? NULL : host.c_str());
 }
 
-void gnome_cmd_con_set_cwd (GnomeCmdCon *con, GnomeCmdDir *dir);
-
-GnomeCmdDir *gnome_cmd_con_get_cwd (GnomeCmdCon *con);
-
 GnomeCmdDir *gnome_cmd_con_get_default_dir (GnomeCmdCon *con);
-
 void gnome_cmd_con_set_default_dir (GnomeCmdCon *con, GnomeCmdDir *dir);
 
-GnomeCmdDir *gnome_cmd_con_get_root_dir (GnomeCmdCon *con);
-void gnome_cmd_con_set_root_dir (GnomeCmdCon *con, GnomeCmdDir *dir);
+inline gchar *gnome_cmd_con_get_root_path (GnomeCmdCon *con)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
+    return con->root_path->str;
+}
+
+inline void gnome_cmd_con_set_root_path (GnomeCmdCon *con, const gchar *path=NULL)
+{
+    g_return_if_fail (GNOME_CMD_IS_CON (con));
+    g_string_assign (con->root_path, path);
+}
 
 inline gboolean gnome_cmd_con_should_remember_dir (GnomeCmdCon *con)
 {
@@ -316,6 +336,16 @@ GnomeCmdBookmarkGroup *gnome_cmd_con_get_bookmarks (GnomeCmdCon *con);
 
 void gnome_cmd_con_set_bookmarks (GnomeCmdCon *con, GnomeCmdBookmarkGroup *bookmarks);
 
+inline void gnome_cmd_con_add_bookmark (GnomeCmdCon *con, gchar *name, gchar *path)
+{
+    GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
+    GnomeCmdBookmark *bookmark = g_new (GnomeCmdBookmark, 1);
+    bookmark->name = name;
+    bookmark->path = path;
+    bookmark->group = group;
+    group->bookmarks = g_list_append (group->bookmarks, bookmark);
+}
+
 void gnome_cmd_con_updated (GnomeCmdCon *con);
 
 GnomeVFSResult gnome_cmd_con_get_path_target_type (GnomeCmdCon *con, const gchar *path, GnomeVFSFileType *type);
@@ -338,6 +368,39 @@ inline const gchar *gnome_cmd_con_get_icon_name (GnomeCmdCon *con)
     return gnome_cmd_con_get_icon_name (con->method);
 }
 
+inline gchar *gnome_cmd_con_get_free_space (GnomeCmdCon *con, GnomeCmdDir *dir, const gchar *fmt)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
+    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
+
+    if (!gnome_cmd_con_can_show_free_space (con))
+        return NULL;
+
+    gchar *free_space = gnome_cmd_dir_get_free_space (dir);
+
+    if (!free_space)
+        return _("Unknown disk usage");
+
+    gchar *retval = g_strdup_printf (fmt, free_space);
+    g_free (free_space);
+
+    return retval;
+}
+
+inline ConnectionMethodID gnome_cmd_con_get_scheme (GnomeVFSURI *uri)
+{
+    const gchar *scheme = gnome_vfs_uri_get_scheme (uri);       // do not g_free
+    const gchar *user = gnome_vfs_uri_get_user_name (uri);      // do not g_free
+
+    return gnome_vfs_uri_is_local (uri) ? CON_LOCAL :
+           g_str_equal (scheme, "ftp")  ? (user && g_str_equal (user, "anonymous") ? CON_ANON_FTP : CON_FTP) :
+           g_str_equal (scheme, "sftp") ? CON_SSH :
+           g_str_equal (scheme, "dav")  ? CON_DAV :
+           g_str_equal (scheme, "davs") ? CON_DAVS :
+           g_str_equal (scheme, "smb")  ? CON_SMB :
+                                          CON_URI;
+}
+
 std::string &__gnome_cmd_con_make_uri (std::string &s, const gchar *method, gboolean use_auth, std::string &server, std::string &port, std::string &folder, std::string &user, std::string &password);
 
 inline std::string &gnome_cmd_con_make_custom_uri (std::string &s, const std::string &uri)
@@ -429,4 +492,11 @@ inline std::string &gnome_cmd_con_make_uri (std::string &s, ConnectionMethodID m
     }
 }
 
+GnomeKeyringAttributeList *gnome_cmd_con_create_keyring_attributes (const gchar *uri_str, const gchar *alias, ConnectionMethodID method);
+
+inline GnomeKeyringAttributeList *GnomeCmdCon::create_keyring_attributes()
+{
+    return gnome_cmd_con_create_keyring_attributes (uri, alias, method);
+}
+
 #endif // __GNOME_CMD_CON_H__
