@@ -20,6 +20,7 @@
 */
 
 #include <config.h>
+#include <libgnomeui/gnome-popup-menu.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir-indicator.h"
@@ -73,7 +74,6 @@ static void destroy (GtkObject *object)
 static void class_init (GnomeCmdDirIndicatorClass *klass)
 {
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     parent_class = (GtkFrameClass *) gtk_type_class (gtk_frame_get_type ());
 
@@ -88,22 +88,30 @@ static gboolean on_dir_indicator_clicked (GnomeCmdDirIndicator *indicator, GdkEv
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator), FALSE);
 
-    if (event->type == GDK_BUTTON_PRESS && event->button == 1)
+    if (event->type!=GDK_BUTTON_PRESS)
+        return FALSE;
+
+    if (event->button==1 || event->button==2)
     {
         // left click - work out the path
         const gchar *labelText = gtk_label_get_text (GTK_LABEL (indicator->priv->label));
-        gchar *chTo = g_strdup(labelText);
+        gchar *chTo = g_strdup (labelText);
         gint x = (gint) event->x;
 
-        for (gint i = 0; i < indicator->priv->numPositions; i++)
+        for (gint i=0; i < indicator->priv->numPositions; ++i)
             if (x < indicator->priv->slashPixelPosition[i])
             {
-                strncpy (chTo, labelText, indicator->priv->slashCharPosition[i]);
-                chTo[indicator->priv->slashCharPosition[i]] = 0x0;
-                gnome_cmd_main_win_switch_fs (main_win, fs);
-                fs->goto_directory(chTo);
-                g_free (chTo);
-                return TRUE;
+                chTo[indicator->priv->slashCharPosition[i]] = 0;
+                main_win->switch_fs(fs);
+                if (event->button==2 || event->state&GDK_CONTROL_MASK || fs->file_list()->locked)
+                {
+                    GnomeCmdCon *con = fs->get_connection();
+                    GnomeCmdDir *dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, chTo));
+                    fs->new_tab(dir);
+                }
+                else
+                    fs->goto_directory(chTo);
+                break;
             }
 
         // pointer is after directory name - just return
@@ -131,7 +139,7 @@ inline void update_markup (GnomeCmdDirIndicator *indicator, gint i)
 
         gchar *mt = get_mono_text (t);
         gchar *ms = get_bold_mono_text (s);
-        m = g_strdup_printf ("%s%s", ms, mt);
+        m = g_strconcat (ms, mt, NULL);
         g_free (t);
         g_free (mt);
         g_free (ms);
@@ -147,8 +155,6 @@ inline void update_markup (GnomeCmdDirIndicator *indicator, gint i)
 
 static gint on_dir_indicator_motion (GnomeCmdDirIndicator *indicator, GdkEventMotion *event, gpointer user_data)
 {
-    gint i, iX, iY;
-
     g_return_val_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator), FALSE);
 
     if (indicator->priv->slashCharPosition == NULL)
@@ -157,17 +163,17 @@ static gint on_dir_indicator_motion (GnomeCmdDirIndicator *indicator, GdkEventMo
         return FALSE;
 
     // find out where in the label the pointer is at
-    iX = (gint)event->x;
-    iY = (gint)event->y;
+    gint iX = (gint) event->x;
+    gint iY = (gint) event->y;
 
-    for (i=0; i < indicator->priv->numPositions; i++)
+    for (gint i=0; i < indicator->priv->numPositions; i++)
     {
         if (iX < indicator->priv->slashPixelPosition[i])
         {
             // underline the part that is selected
-            GdkCursor *cursor = gdk_cursor_new(GDK_HAND2);
-            gdk_window_set_cursor(GTK_WIDGET(indicator)->window, cursor);
-            gdk_cursor_destroy(cursor);
+            GdkCursor *cursor = gdk_cursor_new (GDK_HAND2);
+            gdk_window_set_cursor (GTK_WIDGET (indicator)->window, cursor);
+            gdk_cursor_unref (cursor);
 
             update_markup (indicator, i);
 
@@ -176,7 +182,7 @@ static gint on_dir_indicator_motion (GnomeCmdDirIndicator *indicator, GdkEventMo
 
         // clear underline, cursor=pointer
         update_markup (indicator, -1);
-        gdk_window_set_cursor(GTK_WIDGET (indicator)->window, NULL);
+        gdk_window_set_cursor (GTK_WIDGET (indicator)->window, NULL);
     }
 
     return TRUE;
@@ -189,7 +195,7 @@ static gint on_dir_indicator_leave (GnomeCmdDirIndicator *indicator, GdkEventMot
 
     // clear underline, cursor=pointer
     update_markup (indicator, -1);
-    gdk_window_set_cursor(GTK_WIDGET (indicator)->window, NULL);
+    gdk_window_set_cursor (GTK_WIDGET (indicator)->window, NULL);
 
     return TRUE;
 }
@@ -273,12 +279,23 @@ static void on_dir_history_item_selected (GtkMenuItem *item, const gchar *path)
 {
     g_return_if_fail (path != NULL);
 
-    GnomeCmdDirIndicator *indicator = (GnomeCmdDirIndicator *) gtk_object_get_data (GTK_OBJECT (item), "indicator");
+    GdkModifierType mask;
+    gdk_window_get_pointer (NULL, NULL, NULL, &mask);
+
+    GnomeCmdDirIndicator *indicator = (GnomeCmdDirIndicator *) g_object_get_data (G_OBJECT (item), "indicator");
 
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
-    gnome_cmd_main_win_switch_fs (main_win, indicator->priv->fs);
-    indicator->priv->fs->goto_directory(path);
+    main_win->switch_fs(indicator->priv->fs);
+
+    if (mask&GDK_CONTROL_MASK || indicator->priv->fs->file_list()->locked)
+    {
+        GnomeCmdCon *con = indicator->priv->fs->get_connection();
+        GnomeCmdDir *dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, path));
+        indicator->priv->fs->new_tab(dir);
+    }
+    else
+        indicator->priv->fs->goto_directory(path);
 }
 
 
@@ -286,12 +303,23 @@ static void on_bookmark_item_selected (GtkMenuItem *item, GnomeCmdBookmark *bm)
 {
     g_return_if_fail (bm != NULL);
 
-    GnomeCmdDirIndicator *indicator = (GnomeCmdDirIndicator *) gtk_object_get_data (GTK_OBJECT (item), "indicator");
+    GdkModifierType mask;
+    gdk_window_get_pointer (NULL, NULL, NULL, &mask);
+
+    GnomeCmdDirIndicator *indicator = (GnomeCmdDirIndicator *) g_object_get_data (G_OBJECT (item), "indicator");
 
     g_return_if_fail (GNOME_CMD_IS_DIR_INDICATOR (indicator));
 
-    gnome_cmd_main_win_switch_fs (main_win, indicator->priv->fs);
-    indicator->priv->fs->goto_directory(bm->path);
+    main_win->switch_fs(indicator->priv->fs);
+
+    if (mask&GDK_CONTROL_MASK || indicator->priv->fs->file_list()->locked)
+    {
+        GnomeCmdCon *con = indicator->priv->fs->get_connection();
+        GnomeCmdDir *dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, bm->path));
+        indicator->priv->fs->new_tab(dir);
+    }
+    else
+        indicator->priv->fs->goto_directory(bm->path);
 }
 
 
@@ -309,11 +337,11 @@ static void add_menu_item (GnomeCmdDirIndicator *indicator, GtkMenuShell *shell,
 {
     GtkWidget *item = text ? gtk_menu_item_new_with_label (text) : gtk_menu_item_new ();
 
-    gtk_widget_ref (item);
-    gtk_object_set_data (GTK_OBJECT (item), "indicator", indicator);
-    gtk_object_set_data_full (GTK_OBJECT (shell), "menu_item", item, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (item);
+    g_object_set_data (G_OBJECT (item), "indicator", indicator);
+    g_object_set_data_full (G_OBJECT (shell), "menu_item", item, g_object_unref);
     if (func)
-        gtk_signal_connect (GTK_OBJECT (item), "activate", GTK_SIGNAL_FUNC (func), data);
+        g_signal_connect (item, "activate", G_CALLBACK (func), data);
     gtk_widget_show (item);
     if (!text)
         gtk_widget_set_sensitive (item, FALSE);
@@ -321,18 +349,14 @@ static void add_menu_item (GnomeCmdDirIndicator *indicator, GtkMenuShell *shell,
 }
 
 
-static void popup_dir_history (GnomeCmdDirIndicator *indicator)
+void gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator)
 {
     if (indicator->priv->dir_history_popup) return;
 
     indicator->priv->dir_history_popup = gtk_menu_new ();
-    gtk_widget_ref (indicator->priv->dir_history_popup);
-    gtk_object_set_data_full (
-        GTK_OBJECT (indicator), "dir_history_popup",
-        indicator->priv->dir_history_popup, (GtkDestroyNotify) gtk_widget_unref);
-    gtk_signal_connect (
-        GTK_OBJECT (indicator->priv->dir_history_popup), "hide",
-        GTK_SIGNAL_FUNC (on_dir_history_popup_hide), indicator);
+    g_object_ref (indicator->priv->dir_history_popup);
+    g_object_set_data_full (G_OBJECT (indicator), "dir_history_popup", indicator->priv->dir_history_popup, g_object_unref);
+    g_signal_connect (indicator->priv->dir_history_popup, "hide", G_CALLBACK (on_dir_history_popup_hide), indicator);
 
     GnomeCmdCon *con = indicator->priv->fs->get_connection();
     History *history = gnome_cmd_con_get_dir_history (con);
@@ -366,12 +390,12 @@ static void on_bookmarks_add_current (GtkMenuItem *item, GnomeCmdDirIndicator *i
 
     GnomeCmdBookmark *bm = g_new0 (GnomeCmdBookmark, 1);
 
-    bm->name = g_strdup (gnome_cmd_file_get_name (f));
-    bm->path = gnome_cmd_file_get_path (f);
+    bm->name = g_strdup (f->get_name());
+    bm->path = f->get_path();
     bm->group = group;
 
     group->bookmarks = g_list_append (group->bookmarks, bm);
-    gnome_cmd_main_win_update_bookmarks (main_win);
+    main_win->update_bookmarks();
 }
 
 
@@ -381,14 +405,14 @@ static void on_bookmarks_manage (GtkMenuItem *item, GnomeCmdDirIndicator *indica
 }
 
 
-inline void popup_bookmarks (GnomeCmdDirIndicator *indicator)
+void gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator)
 {
     if (indicator->priv->bookmark_popup) return;
 
     indicator->priv->bookmark_popup = gtk_menu_new ();
-    gtk_widget_ref (indicator->priv->bookmark_popup);
-    gtk_object_set_data_full (GTK_OBJECT (indicator), "bookmark_popup", indicator->priv->bookmark_popup, (GtkDestroyNotify) gtk_widget_unref);
-    gtk_signal_connect (GTK_OBJECT (indicator->priv->bookmark_popup), "hide", GTK_SIGNAL_FUNC (on_bookmark_popup_hide), indicator);
+    g_object_ref (indicator->priv->bookmark_popup);
+    g_object_set_data_full (G_OBJECT (indicator), "bookmark_popup", indicator->priv->bookmark_popup, g_object_unref);
+    g_signal_connect (indicator->priv->bookmark_popup, "hide", G_CALLBACK (on_bookmark_popup_hide), indicator);
 
     GnomeCmdCon *con = indicator->priv->fs->get_connection();
     GnomeCmdBookmarkGroup *group = gnome_cmd_con_get_bookmarks (con);
@@ -433,11 +457,9 @@ static void init (GnomeCmdDirIndicator *indicator)
 
     // create the directory label and its event box
     indicator->priv->event_box = gtk_event_box_new ();
-    gtk_widget_ref (indicator->priv->event_box);
-    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "motion-notify-event",
-                               GTK_SIGNAL_FUNC (on_dir_indicator_motion), indicator);
-    gtk_signal_connect_object (GTK_OBJECT (indicator->priv->event_box), "leave-notify-event",
-                               GTK_SIGNAL_FUNC (on_dir_indicator_leave), indicator);
+    g_object_ref (indicator->priv->event_box);
+    g_signal_connect_swapped (indicator->priv->event_box, "motion-notify-event", G_CALLBACK (on_dir_indicator_motion), indicator);
+    g_signal_connect_swapped (indicator->priv->event_box, "leave-notify-event", G_CALLBACK (on_dir_indicator_leave), indicator);
     gtk_widget_set_events (indicator->priv->event_box, GDK_POINTER_MOTION_MASK);
 
     gtk_widget_show (indicator->priv->event_box);
@@ -448,16 +470,14 @@ static void init (GnomeCmdDirIndicator *indicator)
     // create the history popup button
     indicator->priv->history_button = gtk_button_new ();
     GTK_WIDGET_UNSET_FLAGS (indicator->priv->history_button, GTK_CAN_FOCUS);
-    gtk_widget_ref (indicator->priv->history_button);
+    g_object_ref (indicator->priv->history_button);
     gtk_button_set_relief (GTK_BUTTON (indicator->priv->history_button), gnome_cmd_data.button_relief);
-    gtk_object_set_data_full (GTK_OBJECT (indicator),
-                              "button", indicator->priv->history_button,
-                              (GtkDestroyNotify) gtk_widget_unref);
+    g_object_set_data_full (G_OBJECT (indicator), "button", indicator->priv->history_button, g_object_unref);
     gtk_widget_show (indicator->priv->history_button);
 
     arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);
-    gtk_widget_ref (arrow);
-    gtk_object_set_data_full (GTK_OBJECT (indicator), "arrow", arrow, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (arrow);
+    g_object_set_data_full (G_OBJECT (indicator), "arrow", arrow, g_object_unref);
     gtk_widget_show (arrow);
     gtk_container_add (GTK_CONTAINER (indicator->priv->history_button), arrow);
 
@@ -465,7 +485,7 @@ static void init (GnomeCmdDirIndicator *indicator)
     indicator->priv->bookmark_button = create_styled_pixmap_button (NULL, IMAGE_get_gnome_cmd_pixmap (PIXMAP_BOOKMARK));
     GTK_WIDGET_UNSET_FLAGS (indicator->priv->bookmark_button, GTK_CAN_FOCUS);
     gtk_button_set_relief (GTK_BUTTON (indicator->priv->bookmark_button), gnome_cmd_data.button_relief);
-    gtk_object_set_data_full (GTK_OBJECT (indicator), "button", indicator->priv->bookmark_button, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_set_data_full (G_OBJECT (indicator), "button", indicator->priv->bookmark_button, g_object_unref);
     gtk_widget_show (indicator->priv->bookmark_button);
 
     // pack
@@ -477,8 +497,8 @@ static void init (GnomeCmdDirIndicator *indicator)
     gtk_box_pack_start (GTK_BOX (bbox), indicator->priv->bookmark_button, FALSE, FALSE, 0);
     gtk_box_pack_start (GTK_BOX (bbox), indicator->priv->history_button, FALSE, FALSE, 0);
 
-    gtk_signal_connect (GTK_OBJECT (indicator->priv->history_button), "clicked", GTK_SIGNAL_FUNC (on_history_button_clicked), indicator);
-    gtk_signal_connect (GTK_OBJECT (indicator->priv->bookmark_button), "clicked", GTK_SIGNAL_FUNC (on_bookmark_button_clicked), indicator);
+    g_signal_connect (indicator->priv->history_button, "clicked", G_CALLBACK (on_history_button_clicked), indicator);
+    g_signal_connect (indicator->priv->bookmark_button, "clicked", G_CALLBACK (on_bookmark_button_clicked), indicator);
 }
 
 
@@ -511,9 +531,9 @@ GtkType gnome_cmd_dir_indicator_get_type ()
 
 GtkWidget *gnome_cmd_dir_indicator_new (GnomeCmdFileSelector *fs)
 {
-    GnomeCmdDirIndicator *dir_indicator = (GnomeCmdDirIndicator *) gtk_type_new (gnome_cmd_dir_indicator_get_type ());
+    GnomeCmdDirIndicator *dir_indicator = (GnomeCmdDirIndicator *) g_object_new (GNOME_CMD_TYPE_DIR_INDICATOR, NULL);
 
-    gtk_signal_connect (GTK_OBJECT (dir_indicator), "button-press-event", G_CALLBACK (on_dir_indicator_clicked), fs);
+    g_signal_connect (dir_indicator, "button-press-event", G_CALLBACK (on_dir_indicator_clicked), fs);
 
     dir_indicator->priv->fs = fs;
 
@@ -601,15 +621,3 @@ void gnome_cmd_dir_indicator_set_active (GnomeCmdDirIndicator *indicator, gboole
 {
     // FIXME: Do something creative here
 }
-
-
-void gnome_cmd_dir_indicator_show_history (GnomeCmdDirIndicator *indicator)
-{
-    popup_dir_history (indicator);
-}
-
-
-void gnome_cmd_dir_indicator_show_bookmarks (GnomeCmdDirIndicator *indicator)
-{
-    popup_bookmarks (indicator);
-}
