@@ -21,17 +21,14 @@
 #ifndef __GNOME_CMD_DIR_INDICATOR_H__
 #define __GNOME_CMD_DIR_INDICATOR_H__
 
-#include "gnome-cmd-con.h"
-#include "gnome-cmd-con-ftp.h"
-#include "gnome-cmd-con-device.h"
 #include "gnome-cmd-file-selector.h"
 
-#define GNOME_CMD_DIR_INDICATOR(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_dir_indicator_get_type (), GnomeCmdDirIndicator)
-#define GNOME_CMD_DIR_INDICATOR_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_dir_indicator_get_type (), GnomeCmdDirIndicatorClass)
-#define GNOME_CMD_IS_DIR_INDICATOR(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_dir_indicator_get_type ())
+#define GNOME_CMD_TYPE_DIR_INDICATOR              (gnome_cmd_dir_indicator_get_type ())
+#define GNOME_CMD_DIR_INDICATOR(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_DIR_INDICATOR, GnomeCmdDirIndicator))
+#define GNOME_CMD_DIR_INDICATOR_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_DIR_INDICATOR, GnomeCmdDirIndicatorClass))
+#define GNOME_CMD_IS_DIR_INDICATOR(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_DIR_INDICATOR))
+#define GNOME_CMD_IS_DIR_INDICATOR_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_DIR_INDICATOR))
+#define GNOME_CMD_DIR_INDICATOR_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_DIR_INDICATOR, GnomeCmdDirIndicatorClass))
 
 
 struct GnomeCmdDirIndicatorPrivate;
