@@ -23,7 +23,6 @@
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir.h"
-#include "gnome-cmd-file.h"
 #include "gnome-cmd-main-win.h"
 #include "gnome-cmd-con-smb.h"
 #include "gnome-cmd-data.h"
@@ -65,15 +64,18 @@ struct GnomeCmdDirPrivate
     GnomeCmdPath *path;
 
     gboolean lock;
+    gboolean needs_mtime_update;
 
     Handle *handle;
     GnomeVFSMonitorHandle *monitor_handle;
     gint monitor_users;
 };
 
-static GnomeCmdFileClass *parent_class = NULL;
 
-static guint dir_signals[LAST_SIGNAL] = { 0 };
+G_DEFINE_TYPE (GnomeCmdDir, gnome_cmd_dir, GNOME_CMD_TYPE_FILE)
+
+
+static guint signals[LAST_SIGNAL] = { 0 };
 
 
 static void monitor_callback (GnomeVFSMonitorHandle *handle, const gchar *monitor_uri, const gchar *info_uri, GnomeVFSMonitorEventType event_type, GnomeCmdDir *dir)
@@ -103,115 +105,11 @@ static void monitor_callback (GnomeVFSMonitorHandle *handle, const gchar *monito
 }
 
 
-/*******************************
- * Gtk class implementation
- *******************************/
-
-static void destroy (GtkObject *object)
-{
-    GnomeCmdDir *dir = GNOME_CMD_DIR (object);
-
-    DEBUG ('d', "dir destroying 0x%p %s\n", dir, gnome_cmd_path_get_path (dir->priv->path));
-
-    gnome_cmd_con_remove_from_cache (dir->priv->con, dir);
-
-    delete dir->priv->file_collection;
-
-    if (dir->priv->path)
-        g_object_unref (dir->priv->path);
-
-    dir->priv->handle->ref = NULL;
-    handle_unref (dir->priv->handle);
-
-    g_free (dir->priv);
-
-    if (DEBUG_ENABLED ('c'))
-    {
-        all_dirs = g_list_remove (all_dirs, dir);
-        deleted_dirs_cnt++;
-    }
-
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
-}
-
-
-static void class_init (GnomeCmdDirClass *klass)
-{
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-    GnomeCmdFileClass *file_class = GNOME_CMD_FILE_CLASS (klass);
-
-    parent_class = (GnomeCmdFileClass *) gtk_type_class (gnome_cmd_file_get_type ());
-
-    dir_signals[FILE_CREATED] =
-        gtk_signal_new ("file-created",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdDirClass, file_created),
-            gtk_marshal_NONE__POINTER,
-            GTK_TYPE_NONE,
-            1, GTK_TYPE_POINTER);
-
-    dir_signals[FILE_DELETED] =
-        gtk_signal_new ("file-deleted",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdDirClass, file_deleted),
-            gtk_marshal_NONE__POINTER,
-            GTK_TYPE_NONE,
-            1, GTK_TYPE_POINTER);
-
-    dir_signals[FILE_CHANGED] =
-        gtk_signal_new ("file-changed",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdDirClass, file_changed),
-            gtk_marshal_NONE__POINTER,
-            GTK_TYPE_NONE,
-            1, GTK_TYPE_POINTER);
-
-    dir_signals[FILE_RENAMED] =
-        gtk_signal_new ("file-renamed",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdDirClass, file_renamed),
-            gtk_marshal_NONE__POINTER,
-            GTK_TYPE_NONE,
-            1, GTK_TYPE_POINTER);
-
-    dir_signals[LIST_OK] =
-        gtk_signal_new ("list-ok",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdDirClass, list_ok),
-            gtk_marshal_NONE__POINTER,
-            GTK_TYPE_NONE,
-            1, GTK_TYPE_POINTER);
-
-    dir_signals[LIST_FAILED] =
-        gtk_signal_new ("list-failed",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (GnomeCmdDirClass, list_failed),
-            gtk_marshal_NONE__INT,
-            GTK_TYPE_NONE,
-            1, GTK_TYPE_INT);
-
-    object_class->destroy = destroy;
-    klass->file_created = NULL;
-    klass->file_deleted = NULL;
-    klass->file_changed = NULL;
-    klass->file_renamed = NULL;
-    klass->list_ok = NULL;
-    klass->list_failed = NULL;
-}
-
-
-static void init (GnomeCmdDir *dir)
+static void gnome_cmd_dir_init (GnomeCmdDir *dir)
 {
     // dir->voffset = 0;
     // dir->dialog = NULL;
-    dir->state = DIR_STATE_EMPTY;
+    dir->state = GnomeCmdDir::STATE_EMPTY;
 
     dir->priv = g_new0 (GnomeCmdDirPrivate, 1);
 
@@ -229,41 +127,117 @@ static void init (GnomeCmdDir *dir)
 }
 
 
+static void gnome_cmd_dir_finalize (GObject *object)
+{
+    GnomeCmdDir *dir = GNOME_CMD_DIR (object);
+
+    DEBUG ('d', "dir destroying 0x%p %s\n", dir, dir->priv->path->get_path());
+
+    gnome_cmd_con_remove_from_cache (dir->priv->con, dir);
+
+    delete dir->priv->file_collection;
+    delete dir->priv->path;
+
+    dir->priv->handle->ref = NULL;
+    handle_unref (dir->priv->handle);
+
+    g_free (dir->priv);
+
+    if (DEBUG_ENABLED ('c'))
+    {
+        all_dirs = g_list_remove (all_dirs, dir);
+        deleted_dirs_cnt++;
+    }
+
+    G_OBJECT_CLASS (gnome_cmd_dir_parent_class)->finalize (object);
+}
+
+
+static void gnome_cmd_dir_class_init (GnomeCmdDirClass *klass)
+{
+    GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+    signals[FILE_CREATED] =
+        g_signal_new ("file-created",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdDirClass, file_created),
+            NULL, NULL,
+            g_cclosure_marshal_VOID__POINTER,
+            G_TYPE_NONE,
+            1, G_TYPE_POINTER);
+
+    signals[FILE_DELETED] =
+        g_signal_new ("file-deleted",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdDirClass, file_deleted),
+            NULL, NULL,
+            g_cclosure_marshal_VOID__POINTER,
+            G_TYPE_NONE,
+            1, G_TYPE_POINTER);
+
+    signals[FILE_CHANGED] =
+        g_signal_new ("file-changed",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdDirClass, file_changed),
+            NULL, NULL,
+            g_cclosure_marshal_VOID__POINTER,
+            G_TYPE_NONE,
+            1, G_TYPE_POINTER);
+
+    signals[FILE_RENAMED] =
+        g_signal_new ("file-renamed",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdDirClass, file_renamed),
+            NULL, NULL,
+            g_cclosure_marshal_VOID__POINTER,
+            G_TYPE_NONE,
+            1, G_TYPE_POINTER);
+
+    signals[LIST_OK] =
+        g_signal_new ("list-ok",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdDirClass, list_ok),
+            NULL, NULL,
+            g_cclosure_marshal_VOID__POINTER,
+            G_TYPE_NONE,
+            1, G_TYPE_POINTER);
+
+    signals[LIST_FAILED] =
+        g_signal_new ("list-failed",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (GnomeCmdDirClass, list_failed),
+            NULL, NULL,
+            g_cclosure_marshal_VOID__INT,
+            G_TYPE_NONE,
+            1, G_TYPE_INT);
+
+    object_class->finalize = gnome_cmd_dir_finalize;
+    klass->file_created = NULL;
+    klass->file_deleted = NULL;
+    klass->file_changed = NULL;
+    klass->file_renamed = NULL;
+    klass->list_ok = NULL;
+    klass->list_failed = NULL;
+}
+
+
 /***********************************
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_dir_get_type ()
-{
-    static GtkType type = 0;
-
-    if (type == 0)
-    {
-        GtkTypeInfo info =
-        {
-            "GnomeCmdDir",
-            sizeof (GnomeCmdDir),
-            sizeof (GnomeCmdDirClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ NULL,
-            /* reserved_2 */ NULL,
-            (GtkClassInitFunc) NULL
-        };
-
-        type = gtk_type_unique (gnome_cmd_file_get_type (), &info);
-    }
-    return type;
-}
-
-
 GnomeCmdDir *gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *parent)
 {
     g_return_val_if_fail (info != NULL, NULL);
     g_return_val_if_fail (GNOME_CMD_IS_DIR (parent), NULL);
 
     GnomeCmdCon *con = gnome_cmd_dir_get_connection (parent);
-    GnomeCmdPath *path = gnome_cmd_path_get_child (gnome_cmd_dir_get_path (parent), info->name);
+    GnomeCmdPath *path =  gnome_cmd_dir_get_path (parent)->get_child(info->name);
 
     GnomeVFSURI *uri = gnome_cmd_con_create_uri (con, path);
     gchar *uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
@@ -274,17 +248,17 @@ GnomeCmdDir *gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *p
 
     if (dir)
     {
-        gtk_object_destroy (GTK_OBJECT (path));
-        gnome_cmd_file_update_info (GNOME_CMD_FILE (dir), info);
+        delete path;
+        GNOME_CMD_FILE (dir)->update_info(info);
         return dir;
     }
 
-    dir = (GnomeCmdDir *) gtk_type_new (gnome_cmd_dir_get_type ());
+    dir = (GnomeCmdDir *) g_object_new (GNOME_CMD_TYPE_DIR, NULL);
     gnome_cmd_file_setup (GNOME_CMD_FILE (dir), info, parent);
 
     dir->priv->con = con;
     gnome_cmd_dir_set_path (dir, path);
-    gtk_object_ref (GTK_OBJECT (path));
+    dir->priv->needs_mtime_update = FALSE;
 
     gnome_cmd_con_add_to_cache (gnome_cmd_dir_get_connection (parent), dir);
 
@@ -292,12 +266,12 @@ GnomeCmdDir *gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *p
 }
 
 
-GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info, GnomeCmdPath *path, GnomeCmdCon *con)
+GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeCmdCon *con)
 {
-    g_return_val_if_fail (info != NULL, NULL);
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
+    g_return_val_if_fail (con->base_info != NULL, NULL);
 
-    GnomeVFSURI *uri = gnome_cmd_con_create_uri (con, path);
+    GnomeVFSURI *uri = gnome_cmd_con_create_uri (con, con->base_path);
     gchar *uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
 
     GnomeCmdDir *dir = gnome_cmd_con_cache_lookup (con, uri_str);
@@ -305,16 +279,16 @@ GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info, GnomeCmdPath *p
     {
         g_free (uri_str);
         gnome_vfs_uri_unref (uri);
-        gnome_cmd_file_update_info (GNOME_CMD_FILE (dir), info);
+        GNOME_CMD_FILE (dir)->update_info(con->base_info);
         return dir;
     }
 
-    dir = (GnomeCmdDir *) gtk_type_new (gnome_cmd_dir_get_type ());
-    gnome_cmd_file_setup (GNOME_CMD_FILE (dir), info, NULL);
+    dir = (GnomeCmdDir *) g_object_new (GNOME_CMD_TYPE_DIR, NULL);
+    gnome_cmd_file_setup (GNOME_CMD_FILE (dir), con->base_info, NULL);
 
     dir->priv->con = con;
-    gnome_cmd_dir_set_path (dir, path);
-    gtk_object_ref (GTK_OBJECT (path));
+    gnome_cmd_dir_set_path (dir, con->base_path->clone());
+    dir->priv->needs_mtime_update = FALSE;
 
     gnome_cmd_con_add_to_cache (con, dir);
 
@@ -325,13 +299,7 @@ GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info, GnomeCmdPath *p
 GnomeCmdDir *gnome_cmd_dir_new (GnomeCmdCon *con, GnomeCmdPath *path)
 {
     g_return_val_if_fail (GNOME_CMD_IS_CON (con), NULL);
-    g_return_val_if_fail (GNOME_CMD_IS_PATH (path), NULL);
-
-    GnomeVFSFileInfo *info;
-    GnomeVFSResult res;
-    GnomeVFSFileInfoOptions infoOpts = (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_FOLLOW_LINKS |
-                                                                  GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
-                                                                  GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE);
+    g_return_val_if_fail (path!=NULL, NULL);
 
     GnomeVFSURI *uri = gnome_cmd_con_create_uri (con, path);
     if (!uri) return NULL;
@@ -345,22 +313,26 @@ GnomeCmdDir *gnome_cmd_dir_new (GnomeCmdCon *con, GnomeCmdPath *path)
         return dir;
     }
 
-    info = gnome_vfs_file_info_new ();
-    res = gnome_vfs_get_file_info_uri (uri, info, infoOpts);
+    GnomeVFSFileInfoOptions infoOpts = (GnomeVFSFileInfoOptions) (GNOME_VFS_FILE_INFO_FOLLOW_LINKS |
+                                                                  GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
+                                                                  GNOME_VFS_FILE_INFO_FORCE_FAST_MIME_TYPE);
+    GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
+    GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, infoOpts);
+
     if (res == GNOME_VFS_OK)
     {
-        dir = (GnomeCmdDir *) gtk_type_new (gnome_cmd_dir_get_type ());
+        dir = (GnomeCmdDir *) g_object_new (GNOME_CMD_TYPE_DIR, NULL);
         gnome_cmd_file_setup (GNOME_CMD_FILE (dir), info, NULL);
 
         dir->priv->con = con;
         gnome_cmd_dir_set_path (dir, path);
-        gtk_object_ref (GTK_OBJECT (path));
+        dir->priv->needs_mtime_update = FALSE;
 
         gnome_cmd_con_add_to_cache (con, dir);
     }
     else
     {
-        gnome_cmd_show_message (GTK_WINDOW (main_win), gnome_cmd_path_get_display_path (path), gnome_vfs_result_to_string (res));
+        gnome_cmd_show_message (*main_win, path->get_display_path(), gnome_vfs_result_to_string (res));
         gnome_vfs_file_info_unref (info);
     }
 
@@ -375,7 +347,7 @@ GnomeCmdDir *gnome_cmd_dir_get_parent (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
-    GnomeCmdPath *path = gnome_cmd_path_get_parent (dir->priv->path);
+    GnomeCmdPath *path = dir->priv->path->get_parent();
 
     return path ? gnome_cmd_dir_new (dir->priv->con, path) : NULL;
 }
@@ -385,7 +357,7 @@ GnomeCmdDir *gnome_cmd_dir_get_child (GnomeCmdDir *dir, const gchar *child)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
-    GnomeCmdPath *path = gnome_cmd_path_get_child (dir->priv->path, child);
+    GnomeCmdPath *path = dir->priv->path->get_child(child);
 
     return path ? gnome_cmd_dir_new (dir->priv->con, path) : NULL;
 }
@@ -407,14 +379,11 @@ Handle *gnome_cmd_dir_get_handle (GnomeCmdDir *dir)
 }
 
 
-GnomeVFSResult gnome_cmd_dir_get_files (GnomeCmdDir *dir, GList **files)
+GList *gnome_cmd_dir_get_files (GnomeCmdDir *dir)
 {
-    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), GNOME_VFS_ERROR_BAD_PARAMETERS);
+    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
-    if (files)
-        *files = dir->priv->files;
-
-    return dir->priv->last_result;
+    return dir->priv->files;
 }
 
 
@@ -424,9 +393,9 @@ static GList *create_file_list (GnomeCmdDir *dir, GList *info_list)
 
     // create a new list with GnomeCmdFile objects
 
-    for (GList *tmp = info_list; tmp; tmp = tmp->next)
+    for (GList *i = info_list; i; i = i->next)
     {
-        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) tmp->data;
+        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) i->data;
 
         if (info && info->name)
         {
@@ -448,7 +417,7 @@ static GList *create_file_list (GnomeCmdDir *dir, GList *info_list)
                 // look like normal directories
                 info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
                 // Determining smb MIME type: workgroup or server
-                gchar *uri_str = gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (dir));
+                gchar *uri_str = GNOME_CMD_FILE (dir)->get_uri_str();
 
                 info->mime_type = strcmp (uri_str, "smb:///") == 0 ? g_strdup ("x-directory/smb-workgroup") :
                                                                      g_strdup ("x-directory/smb-server");
@@ -468,7 +437,7 @@ static GList *create_file_list (GnomeCmdDir *dir, GList *info_list)
 
 static void on_list_done (GnomeCmdDir *dir, GList *infolist, GnomeVFSResult result)
 {
-    if (dir->state == DIR_STATE_LISTED)
+    if (dir->state == GnomeCmdDir::STATE_LISTED)
     {
         DEBUG('l', "File listing succeded\n");
 
@@ -477,7 +446,6 @@ static void on_list_done (GnomeCmdDir *dir, GList *infolist, GnomeVFSResult resu
 
         dir->priv->files = create_file_list (dir, infolist);
         dir->priv->file_collection->add(dir->priv->files);
-        dir->state = DIR_STATE_LISTED;
         g_list_free (infolist);
 
         if (dir->dialog)
@@ -488,10 +456,10 @@ static void on_list_done (GnomeCmdDir *dir, GList *infolist, GnomeVFSResult resu
         dir->priv->lock = FALSE;
         dir->priv->last_result = GNOME_VFS_OK;
 
-        DEBUG('l', "Emitting list_ok signal\n");
-        gtk_signal_emit (GTK_OBJECT (dir), dir_signals[LIST_OK], dir->priv->files);
+        DEBUG('l', "Emitting 'list-ok' signal\n");
+        g_signal_emit (dir, signals[LIST_OK], 0, dir->priv->files);
     }
-    else if (dir->state == DIR_STATE_EMPTY)
+    else if (dir->state == GnomeCmdDir::STATE_EMPTY)
     {
         DEBUG('l', "File listing failed: %s\n", gnome_vfs_result_to_string (result));
 
@@ -504,15 +472,15 @@ static void on_list_done (GnomeCmdDir *dir, GList *infolist, GnomeVFSResult resu
         dir->priv->last_result = result;
         dir->priv->lock = FALSE;
 
-        DEBUG('l', "Emitting list_failed signal\n");
-        gtk_signal_emit (GTK_OBJECT (dir), dir_signals[LIST_FAILED], result);
+        DEBUG('l', "Emitting 'list-failed' signal\n");
+        g_signal_emit (dir, signals[LIST_FAILED], 0, result);
     }
 }
 
 
 static void on_dir_list_cancel (GtkButton *btn, GnomeCmdDir *dir)
 {
-    if (dir->state == DIR_STATE_LISTING)
+    if (dir->state == GnomeCmdDir::STATE_LISTING)
     {
         DEBUG('l', "on_dir_list_cancel\n");
         dirlist_cancel (dir);
@@ -526,7 +494,7 @@ static void on_dir_list_cancel (GtkButton *btn, GnomeCmdDir *dir)
 static void create_list_progress_dialog (GnomeCmdDir *dir)
 {
     dir->dialog = gnome_cmd_dialog_new (NULL);
-    gtk_widget_ref (dir->dialog);
+    g_object_ref (dir->dialog);
 
     gnome_cmd_dialog_add_button (
         GNOME_CMD_DIALOG (dir->dialog),
@@ -546,7 +514,7 @@ static void create_list_progress_dialog (GnomeCmdDir *dir)
     gtk_box_pack_start (GTK_BOX (vbox), dir->pbar, FALSE, TRUE, 0);
 
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dir->dialog), vbox);
-    gnome_cmd_dialog_set_transient_for (GNOME_CMD_DIALOG (dir->dialog), GTK_WINDOW (main_win));
+    gtk_window_set_transient_for (GTK_WINDOW (dir->dialog), *main_win);
 
     gtk_widget_show_all (dir->dialog);
 }
@@ -572,16 +540,16 @@ void gnome_cmd_dir_list_files (GnomeCmdDir *dir, gboolean visprog)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
-    if (!dir->priv->files || gnome_vfs_uri_is_local (gnome_cmd_file_get_uri (GNOME_CMD_FILE (dir))))
+    if (!dir->priv->files || gnome_cmd_dir_is_local (dir))
     {
         DEBUG ('l', "relisting files for 0x%x %s %d\n",
                dir,
-               gnome_cmd_file_get_path (GNOME_CMD_FILE (dir)),
+               GNOME_CMD_FILE (dir)->get_path(),
                visprog);
         gnome_cmd_dir_relist_files (dir, visprog);
     }
     else
-        gtk_signal_emit (GTK_OBJECT (dir), dir_signals[LIST_OK], dir->priv->files);
+        g_signal_emit (dir, signals[LIST_OK], 0, dir->priv->files);
 }
 
 
@@ -597,11 +565,9 @@ void gnome_cmd_dir_set_path (GnomeCmdDir *dir, GnomeCmdPath *path)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
 
-    if (dir->priv->path)
-        gtk_object_destroy (GTK_OBJECT (dir->priv->path));
+    delete dir->priv->path;
 
     dir->priv->path = path;
-    gtk_object_ref (GTK_OBJECT (path));
 }
 
 
@@ -613,7 +579,7 @@ void gnome_cmd_dir_update_path (GnomeCmdDir *dir)
     if (!parent)
         return;
 
-    GnomeCmdPath *path = gnome_cmd_path_get_child (gnome_cmd_dir_get_path (parent), gnome_cmd_file_get_name (GNOME_CMD_FILE (dir)));
+    GnomeCmdPath *path = gnome_cmd_dir_get_path (parent)->get_child(GNOME_CMD_FILE (dir)->get_name());
     if (path)
         gnome_cmd_dir_set_path (dir, path);
 }
@@ -623,7 +589,7 @@ gchar *gnome_cmd_dir_get_display_path (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
-    return g_strdup (gnome_cmd_path_get_display_path (dir->priv->path));
+    return g_strdup (dir->priv->path->get_display_path());
 }
 
 
@@ -651,9 +617,9 @@ GnomeVFSURI *gnome_cmd_dir_get_child_uri (GnomeCmdDir *dir, const gchar *filenam
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
 
-    GnomeCmdPath *path = gnome_cmd_path_get_child (dir->priv->path, filename);
+    GnomeCmdPath *path = dir->priv->path->get_child(filename);
     GnomeVFSURI *uri = gnome_cmd_con_create_uri (dir->priv->con, path);
-    gtk_object_destroy (GTK_OBJECT (path));
+    delete path;
 
     return uri;
 }
@@ -703,7 +669,7 @@ GnomeVFSURI *gnome_cmd_dir_get_absolute_path_uri (GnomeCmdDir *dir, string absol
     GnomeCmdPath *path = gnome_cmd_con_create_path (dir->priv->con, absolute_filename.c_str());
     GnomeVFSURI *uri = gnome_cmd_con_create_uri (dir->priv->con, path);
 
-    gtk_object_destroy (GTK_OBJECT (path));
+    delete path;
 
     return uri;
 }
@@ -743,7 +709,9 @@ void gnome_cmd_dir_file_created (GnomeCmdDir *dir, const gchar *uri_str)
     dir->priv->file_collection->add(f);
     dir->priv->files = dir->priv->file_collection->get_list();
 
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_CREATED], f);
+    dir->priv->needs_mtime_update = TRUE;
+
+    g_signal_emit (dir, signals[FILE_CREATED], 0, f);
 }
 
 
@@ -758,7 +726,9 @@ void gnome_cmd_dir_file_deleted (GnomeCmdDir *dir, const gchar *uri_str)
     if (!GNOME_CMD_IS_FILE (f))
         return;
 
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_DELETED], f);
+    dir->priv->needs_mtime_update = TRUE;
+
+    g_signal_emit (dir, signals[FILE_DELETED], 0, f);
 
     dir->priv->file_collection->remove(uri_str);
     dir->priv->files = dir->priv->file_collection->get_list();
@@ -775,14 +745,16 @@ void gnome_cmd_dir_file_changed (GnomeCmdDir *dir, const gchar *uri_str)
 
     g_return_if_fail (GNOME_CMD_IS_FILE (f));
 
-    GnomeVFSURI *uri = gnome_cmd_file_get_uri (f);
+    GnomeVFSURI *uri = f->get_uri();
     GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
     GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, GNOME_VFS_FILE_INFO_GET_MIME_TYPE);
     gnome_vfs_uri_unref (uri);
 
-    gnome_cmd_file_update_info (f, info);
-    gnome_cmd_file_invalidate_metadata (f);
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_CHANGED], f);
+    dir->priv->needs_mtime_update = TRUE;
+
+    f->update_info(info);
+    f->invalidate_metadata();
+    g_signal_emit (dir, signals[FILE_CHANGED], 0, f);
 }
 
 
@@ -795,9 +767,11 @@ void gnome_cmd_dir_file_renamed (GnomeCmdDir *dir, GnomeCmdFile *f, const gchar
     if (GNOME_CMD_IS_DIR (f))
         gnome_cmd_con_remove_from_cache (dir->priv->con, old_uri_str);
 
+    dir->priv->needs_mtime_update = TRUE;
+
     dir->priv->file_collection->remove(old_uri_str);
     dir->priv->file_collection->add(f);
-    gtk_signal_emit (GTK_OBJECT (dir), dir_signals[FILE_RENAMED], f);
+    g_signal_emit (dir, signals[FILE_RENAMED], 0, f);
 }
 
 
@@ -817,7 +791,7 @@ void gnome_cmd_dir_start_monitoring (GnomeCmdDir *dir)
 
     if (dir->priv->monitor_users == 0)
     {
-        gchar *uri_str = gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (dir));
+        gchar *uri_str = GNOME_CMD_FILE (dir)->get_uri_str();
 
         result = gnome_vfs_monitor_add (
             &dir->priv->monitor_handle,
@@ -853,10 +827,10 @@ void gnome_cmd_dir_cancel_monitoring (GnomeCmdDir *dir)
             GnomeVFSResult result = gnome_vfs_monitor_cancel (dir->priv->monitor_handle);
             if (result == GNOME_VFS_OK)
                 DEBUG('n', "Removed monitor from 0x%p %s\n",
-                      dir, gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (dir)));
+                      dir, GNOME_CMD_FILE (dir)->get_uri_str());
             else
                 DEBUG('n', "Failed to remove monitor from 0x%p %s: %s\n",
-                      dir, gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (dir)),
+                      dir, GNOME_CMD_FILE (dir)->get_uri_str(),
                       gnome_vfs_result_to_string (result));
 
             dir->priv->monitor_handle = NULL;
@@ -865,9 +839,53 @@ void gnome_cmd_dir_cancel_monitoring (GnomeCmdDir *dir)
 }
 
 
+gboolean gnome_cmd_dir_is_monitored (GnomeCmdDir *dir)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), FALSE);
+
+    return dir->priv->monitor_users > 0;
+}
+
+
 gboolean gnome_cmd_dir_is_local (GnomeCmdDir *dir)
 {
     g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), FALSE);
 
     return gnome_cmd_con_is_local (dir->priv->con);
 }
+
+
+gboolean gnome_cmd_dir_update_mtime (GnomeCmdDir *dir)
+{
+    // this function also determines if cached dir is up-to-date (FALSE=yes)
+    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), FALSE);
+
+    // assume cache is updated
+    gboolean returnValue = FALSE;
+    GnomeVFSURI *uri = gnome_cmd_dir_get_uri (dir);
+    GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
+    GnomeVFSResult res = gnome_vfs_get_file_info_uri (uri, info, (GnomeVFSFileInfoOptions)
+                                            (GNOME_VFS_FILE_INFO_FOLLOW_LINKS | GNOME_VFS_FILE_INFO_NAME_ONLY));
+    if (res != GNOME_VFS_OK || GNOME_CMD_FILE(dir)->info->mtime != info->mtime)
+    {
+        // cache is not up-to-date
+        GNOME_CMD_FILE (dir)->info->mtime = info->mtime;
+        returnValue = TRUE;
+    }
+
+    gnome_vfs_file_info_unref (info);
+    gnome_vfs_uri_unref (uri);
+
+    // after this function we are sure dir's mtime is up-to-date
+    dir->priv->needs_mtime_update = FALSE;
+
+    return returnValue;
+}
+
+
+gboolean gnome_cmd_dir_needs_mtime_update (GnomeCmdDir *dir)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), FALSE);
+
+    return dir->priv->needs_mtime_update;
+}
