@@ -22,12 +22,15 @@
 #ifndef __GNOME_CMD_DIR_H__
 #define __GNOME_CMD_DIR_H__
 
-#define GNOME_CMD_DIR(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_dir_get_type (), GnomeCmdDir)
-#define GNOME_CMD_DIR_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_dir_get_type (), GnomeCmdDirClass)
-#define GNOME_CMD_IS_DIR(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_dir_get_type ())
+#define GNOME_CMD_TYPE_DIR              (gnome_cmd_dir_get_type ())
+#define GNOME_CMD_DIR(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_DIR, GnomeCmdDir))
+#define GNOME_CMD_DIR_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_DIR, GnomeCmdDirClass))
+#define GNOME_CMD_IS_DIR(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_DIR))
+#define GNOME_CMD_IS_DIR_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_DIR))
+#define GNOME_CMD_DIR_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_DIR, GnomeCmdDirClass))
+
+
+GType gnome_cmd_dir_get_type ();
 
 
 struct GnomeCmdDir;
@@ -41,32 +44,32 @@ typedef void (* DirListDoneFunc) (GnomeCmdDir *dir, GList *files, GnomeVFSResult
 #include "gnome-cmd-path.h"
 #include "handle.h"
 
-typedef enum
-{
-    DIR_STATE_EMPTY,
-    DIR_STATE_LISTED,
-    DIR_STATE_LISTING,
-    DIR_STATE_CANCELING
-} DirState;
-
 struct GnomeCmdDir
 {
-    GnomeCmdFile parent;
+    GnomeCmdFile parent;      // this MUST be the first member
+
+    GnomeCmdDirPrivate *priv;
+
+    enum State
+    {
+        STATE_EMPTY,
+        STATE_LISTED,
+        STATE_LISTING,
+        STATE_CANCELING
+    };
 
     gint voffset;
     GList *infolist;
     GnomeVFSAsyncHandle *list_handle;
     GnomeVFSResult list_result;
     gint list_counter;
-    DirState state;
+    State state;
 
     DirListDoneFunc done_func;
 
     GtkWidget *dialog;
     GtkWidget *label;
     GtkWidget *pbar;
-
-    GnomeCmdDirPrivate *priv;
 };
 
 struct GnomeCmdDirClass
@@ -83,10 +86,8 @@ struct GnomeCmdDirClass
 
 struct GnomeCmdCon;
 
-GtkType gnome_cmd_dir_get_type ();
-
 GnomeCmdDir *gnome_cmd_dir_new_from_info (GnomeVFSFileInfo *info, GnomeCmdDir *parent);
-GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeVFSFileInfo *info, GnomeCmdPath *path, GnomeCmdCon *con);
+GnomeCmdDir *gnome_cmd_dir_new_with_con (GnomeCmdCon *con);
 GnomeCmdDir *gnome_cmd_dir_new (GnomeCmdCon *con, GnomeCmdPath *path);
 GnomeCmdDir *gnome_cmd_dir_get_parent (GnomeCmdDir *dir);
 GnomeCmdDir *gnome_cmd_dir_get_child (GnomeCmdDir *dir, const gchar *child);
@@ -110,19 +111,20 @@ inline GnomeCmdFile *gnome_cmd_dir_new_parent_dir_file (GnomeCmdDir *dir)
     return gnome_cmd_file_new (info, dir);
 }
 
-inline void gnome_cmd_dir_ref (GnomeCmdDir *dir)
+inline GnomeCmdDir *gnome_cmd_dir_ref (GnomeCmdDir *dir)
 {
-    g_return_if_fail (GNOME_CMD_IS_DIR (dir));
-    gnome_cmd_file_ref (GNOME_CMD_FILE (dir));
+    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
+    GNOME_CMD_FILE (dir)->ref();
+    return dir;
 }
 
 inline void gnome_cmd_dir_unref (GnomeCmdDir *dir)
 {
     g_return_if_fail (GNOME_CMD_IS_DIR (dir));
-    gnome_cmd_file_unref (GNOME_CMD_FILE (dir));
+    GNOME_CMD_FILE (dir)->unref();
 }
 
-GnomeVFSResult gnome_cmd_dir_get_files (GnomeCmdDir *dir, GList **files);
+GList *gnome_cmd_dir_get_files (GnomeCmdDir *dir);
 void gnome_cmd_dir_relist_files (GnomeCmdDir *dir, gboolean visprog);
 void gnome_cmd_dir_list_files (GnomeCmdDir *dir, gboolean visprog);
 
@@ -147,7 +149,26 @@ gboolean gnome_cmd_dir_uses_fam (GnomeCmdDir *dir);
 
 void gnome_cmd_dir_start_monitoring (GnomeCmdDir *dir);
 void gnome_cmd_dir_cancel_monitoring (GnomeCmdDir *dir);
+gboolean gnome_cmd_dir_is_monitored (GnomeCmdDir *dir);
 gboolean gnome_cmd_dir_is_local (GnomeCmdDir *dir);
 void gnome_cmd_dir_set_content_changed (GnomeCmdDir *dir);
 
+gboolean gnome_cmd_dir_update_mtime (GnomeCmdDir *dir);
+gboolean gnome_cmd_dir_needs_mtime_update (GnomeCmdDir *dir);
+
+inline gchar *gnome_cmd_dir_get_free_space (GnomeCmdDir *dir)
+{
+    g_return_val_if_fail (GNOME_CMD_IS_DIR (dir), NULL);
+
+    GnomeVFSFileSize free_space;
+    GnomeVFSURI *uri = GNOME_CMD_FILE (dir)->get_uri();
+    GnomeVFSResult res = gnome_vfs_get_volume_free_space (uri, &free_space);
+    gnome_vfs_uri_unref (uri);
+
+    if (res!=GNOME_VFS_OK)
+        return NULL;
+
+    return gnome_vfs_format_file_size_for_display (free_space);
+}
+
 #endif // __GNOME_CMD_DIR_H__
