@@ -20,6 +20,7 @@
 */
 
 #include <config.h>
+#include <libgnomeui/gnome-stock-icons.h>
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-file-popmenu.h"
@@ -43,12 +44,12 @@ using namespace std;
 #define MAX_OPEN_WITH_APPS 20
 
 
-typedef struct
+struct OpenWithData
 {
     GList *files;
     GnomeCmdApp *app;
     GtkPixmap *pm;
-} OpenWithData;
+};
 
 
 static GtkMenuClass *parent_class = NULL;
@@ -95,7 +96,7 @@ static void cb_exec_default (GtkMenuItem *menu_item, GList *files)
     for (; files; files = files->next)
     {
         GnomeCmdFile *f = (GnomeCmdFile *) files->data;
-        GnomeVFSMimeApplication *vfs_app = gnome_cmd_app_get_default_application (f);
+        GnomeVFSMimeApplication *vfs_app = f->get_default_application();
 
         if (vfs_app)
         {
@@ -137,12 +138,12 @@ static gboolean on_open_with_other_ok (GnomeCmdStringDialog *string_dialog, cons
     for (; files; files = files->next)
     {
         cmd += ' ';
-        cmd += stringify (gnome_cmd_file_get_quoted_real_path (GNOME_CMD_FILE (files->data)));
+        cmd += stringify (GNOME_CMD_FILE (files->data)->get_quoted_real_path());
     }
 
-    GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (main_win, ACTIVE);
+    GnomeCmdFileSelector *fs = main_win->fs(ACTIVE);
     GnomeCmdDir *dir = fs->get_directory();
-    gchar *dpath = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dir));
+    gchar *dpath = GNOME_CMD_FILE (dir)->get_real_path();
     run_command_indir (cmd.c_str(), dpath, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (term_check)));
     g_free (dpath);
 
@@ -162,8 +163,8 @@ static void on_open_with_other (GtkMenuItem *menu_item, GList *files)
 
     GtkWidget *term_check = create_check (dialog, _("Needs terminal"), "term_check");
 
-    gtk_widget_ref (dialog);
-    gtk_object_set_data_full (GTK_OBJECT (menu_item), "new_textfile_dialog", dialog, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (dialog);
+    g_object_set_data_full (G_OBJECT (menu_item), "new_textfile_dialog", dialog, g_object_unref);
 
     gnome_cmd_dialog_add_category (GNOME_CMD_DIALOG (dialog), term_check);
 
@@ -175,7 +176,7 @@ static void on_execute (GtkMenuItem *menu_item, GList *files)
 {
     GnomeCmdFile *f = GNOME_CMD_FILE (files->data);
 
-    gnome_cmd_file_execute (f);
+    f->execute();
 }
 
 
@@ -245,9 +246,9 @@ static void add_fav_app_menu_item (GnomeCmdFilePopmenu *menu, GnomeCmdApp *app,
     gtk_container_add (GTK_CONTAINER (item), label);
 
     // Connect to the signal and set user data
-    gtk_object_set_data (GTK_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, data);
+    g_object_set_data (G_OBJECT (item), GNOMEUIINFO_KEY_UIDATA, data);
 
-    gtk_signal_connect (GTK_OBJECT (item), "activate", GTK_SIGNAL_FUNC (cb_exec_with_app), data);
+    g_signal_connect (item, "activate", G_CALLBACK (cb_exec_with_app), data);
 }
 
 
@@ -402,7 +403,7 @@ inline gchar *get_default_application_action_name (GList *files)
         return g_strdup (_("_Open"));
 
     GnomeCmdFile *f = (GnomeCmdFile *) files->data;
-    gchar *uri_str = gnome_cmd_file_get_uri_str (f);
+    gchar *uri_str = f->get_uri_str();
     GnomeVFSMimeApplication *app = gnome_vfs_mime_get_default_application_for_uri (uri_str, f->info->mime_type);
 
     g_free (uri_str);
@@ -434,7 +435,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
     static GnomeUIInfo open_uiinfo[] =
     {
         GNOMEUIINFO_ITEM_NONE(N_("_Open"), NULL, cb_exec_default),
-        GNOMEUIINFO_SUBTREE(N_("Open With..."), apps_uiinfo),
+        GNOMEUIINFO_SUBTREE(N_("Open Wit_h"), apps_uiinfo),
         GNOMEUIINFO_END
     };
 
@@ -460,7 +461,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
         GNOMEUIINFO_ITEM_NONE (N_("Rename"), NULL, on_rename),
         GNOMEUIINFO_ITEM_STOCK(N_("Send files"), NULL, file_sendto, GNOME_STOCK_MAIL_SND),
         GNOMEUIINFO_ITEM_FILENAME (N_("Open this _folder"), NULL, command_open_nautilus, PACKAGE_NAME G_DIR_SEPARATOR_S "nautilus.svg"),
-        GNOMEUIINFO_ITEM_FILENAME (N_("Open _terminal here"), NULL, command_open_terminal, PACKAGE_NAME G_DIR_SEPARATOR_S "terminal.svg"),
+        GNOMEUIINFO_ITEM_FILENAME (N_("Open _terminal here"), NULL, command_open_terminal__internal, PACKAGE_NAME G_DIR_SEPARATOR_S "terminal.svg"),
         GNOMEUIINFO_SEPARATOR,
         GNOMEUIINFO_ITEM_STOCK(N_("_Properties..."), NULL, on_properties, GTK_STOCK_PROPERTIES),
         GNOMEUIINFO_END
@@ -470,12 +471,12 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
     GList *files = fl->get_selected_files();
     if (!files) return NULL;
 
-    GnomeCmdFilePopmenu *menu = (GnomeCmdFilePopmenu *) gtk_type_new (gnome_cmd_file_popmenu_get_type ());
+    GnomeCmdFilePopmenu *menu = (GnomeCmdFilePopmenu *) g_object_new (GNOME_CMD_TYPE_FILE_POPMENU, NULL);
 
     GnomeCmdFile *f = (GnomeCmdFile *) files->data;
 
 
-    // Fill the "Open with..." menu with applications
+    // Fill the "Open With" menu with applications
     gint i = -1;
     menu->priv->data_list = NULL;
 
@@ -505,7 +506,7 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
 
     // Add open with other
     apps_uiinfo[++i].type = GNOME_APP_UI_ITEM;
-    apps_uiinfo[i].label = g_strdup (_("Other..."));
+    apps_uiinfo[i].label = g_strdup (_("Other _Application..."));
     apps_uiinfo[i].moreinfo = (gpointer) on_open_with_other;
     apps_uiinfo[i].user_data = files;
 
@@ -532,16 +533,16 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
     g_free ((gpointer) open_uiinfo[0].label);
 
     pos += 3;
-    if (gnome_cmd_file_is_executable (f) && g_list_length (files) == 1)
+    if (f->is_executable() && g_list_length (files) == 1)
         gnome_app_fill_menu (GTK_MENU_SHELL (menu), exec_uiinfo, NULL, FALSE, pos++);
 
     gnome_app_fill_menu (GTK_MENU_SHELL (menu), sep_uiinfo, NULL, FALSE, pos++);
 
     // Add favorite applications
     match_count = 0;
-    for (GList *tmp=gnome_cmd_data_get_fav_apps (); tmp; tmp = tmp->next)
+    for (GList *i=gnome_cmd_data.options.fav_apps; i; i = i->next)
     {
-        GnomeCmdApp *app = (GnomeCmdApp *) tmp->data;
+        GnomeCmdApp *app = (GnomeCmdApp *) i->data;
         if (fav_app_matches_files (app, files))
         {
             add_fav_app_menu_item (menu, app, pos++, files);
@@ -549,13 +550,12 @@ GtkWidget *gnome_cmd_file_popmenu_new (GnomeCmdFileList *fl)
         }
     }
 
-    for (GList *tmp=plugin_manager_get_all (); tmp; tmp = tmp->next)
+    for (GList *i=plugin_manager_get_all (); i; i = i->next)
     {
-        PluginData *data = (PluginData *) tmp->data;
+        PluginData *data = (PluginData *) i->data;
         if (data->active)
         {
-            GList *items = gnome_cmd_plugin_create_popup_menu_items (data->plugin,
-                                                                     gnome_cmd_main_win_get_state (main_win));
+            GList *items = gnome_cmd_plugin_create_popup_menu_items (data->plugin, main_win->get_state());
             if (items)
             {
                 add_plugin_menu_items (menu, items, pos);
