@@ -24,12 +24,12 @@
 
 #include "gnome-cmd-file-list.h"
 
-#define GNOME_CMD_FILE_POPMENU(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_file_popmenu_get_type (), GnomeCmdFilePopmenu)
-#define GNOME_CMD_FILE_POPMENU_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_file_popmenu_get_type (), GnomeCmdFilePopmenuClass)
-#define GNOME_CMD_IS_FILE_POPMENU(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_file_popmenu_get_type ())
+#define GNOME_CMD_TYPE_FILE_POPMENU              (gnome_cmd_file_popmenu_get_type ())
+#define GNOME_CMD_FILE_POPMENU(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_FILE_POPMENU, GnomeCmdFilePopmenu))
+#define GNOME_CMD_FILE_POPMENU_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_FILE_POPMENU, GnomeCmdFilePopmenuClass))
+#define GNOME_CMD_IS_FILE_POPMENU(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_FILE_POPMENU))
+#define GNOME_CMD_IS_FILE_POPMENU_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_FILE_POPMENU))
+#define GNOME_CMD_FILE_POPMENU_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_FILE_POPMENU, GnomeCmdFilePopmenuClass))
 
 
 struct GnomeCmdFilePopmenuPrivate;
