@@ -51,7 +51,7 @@ static void on_new_textfile (GtkMenuItem *item, GnomeCmdFileSelector *fs)
 
 static void on_refresh (GtkMenuItem *item, GnomeCmdFileSelector *fs)
 {
-    fs->reload();
+    fs->file_list()->reload();
 }
 
 
@@ -112,11 +112,11 @@ GtkWidget *gnome_cmd_list_popmenu_new (GnomeCmdFileSelector *fs)
 
     static GnomeUIInfo popmenu_uiinfo[] =
     {
-        GNOMEUIINFO_SUBTREE(N_("_New..."), new_uiinfo),
+        GNOMEUIINFO_SUBTREE(N_("_New"), new_uiinfo),
         GNOMEUIINFO_ITEM_STOCK(N_("_Paste"), NULL, on_paste, GTK_STOCK_PASTE),
         GNOMEUIINFO_SEPARATOR,
         GNOMEUIINFO_ITEM_FILENAME (N_("Open this _folder"), NULL, command_open_nautilus_in_cwd, PACKAGE_NAME G_DIR_SEPARATOR_S "nautilus.svg"),
-        GNOMEUIINFO_ITEM_FILENAME (N_("Open _terminal here"), NULL, command_open_terminal, PACKAGE_NAME G_DIR_SEPARATOR_S "terminal.svg"),
+        GNOMEUIINFO_ITEM_FILENAME (N_("Open _terminal here"), NULL, command_open_terminal__internal, PACKAGE_NAME G_DIR_SEPARATOR_S "terminal.svg"),
         GNOMEUIINFO_SEPARATOR,
         GNOMEUIINFO_ITEM_STOCK(N_("_Refresh"), NULL, on_refresh, GTK_STOCK_REFRESH),
         GNOMEUIINFO_END
@@ -133,7 +133,7 @@ GtkWidget *gnome_cmd_list_popmenu_new (GnomeCmdFileSelector *fs)
         if (popmenu_uiinfo[i].type == GNOME_APP_UI_ITEM)
             popmenu_uiinfo[i].user_data = fs;
 
-    GnomeCmdListPopmenu *menu = (GnomeCmdListPopmenu *) gtk_type_new (gnome_cmd_list_popmenu_get_type ());
+    GnomeCmdListPopmenu *menu = (GnomeCmdListPopmenu *) g_object_new (GNOME_CMD_TYPE_LIST_POPMENU, NULL);
 
     // Fill the menu
 
