@@ -24,12 +24,12 @@
 
 #include "gnome-cmd-file-selector.h"
 
-#define GNOME_CMD_LIST_POPMENU(obj) \
-    GTK_CHECK_CAST (obj, gnome_cmd_list_popmenu_get_type (), GnomeCmdListPopmenu)
-#define GNOME_CMD_LIST_POPMENU_CLASS(klass) \
-    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_list_popmenu_get_type (), GnomeCmdListPopmenuClass)
-#define GNOME_CMD_IS_LIST_POPMENU(obj) \
-    GTK_CHECK_TYPE (obj, gnome_cmd_list_popmenu_get_type ())
+#define GNOME_CMD_TYPE_LIST_POPMENU              (gnome_cmd_list_popmenu_get_type ())
+#define GNOME_CMD_LIST_POPMENU(obj)              (G_TYPE_CHECK_INSTANCE_CAST((obj), GNOME_CMD_TYPE_LIST_POPMENU, GnomeCmdListPopmenu))
+#define GNOME_CMD_LIST_POPMENU_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass), GNOME_CMD_TYPE_LIST_POPMENU, GnomeCmdListPopmenuClass))
+#define GNOME_CMD_IS_LIST_POPMENU(obj)           (G_TYPE_CHECK_INSTANCE_TYPE((obj), GNOME_CMD_TYPE_LIST_POPMENU))
+#define GNOME_CMD_IS_LIST_POPMENU_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_LIST_POPMENU))
+#define GNOME_CMD_LIST_POPMENU_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS((obj), GNOME_CMD_TYPE_LIST_POPMENU, GnomeCmdListPopmenuClass))
 
 
 struct GnomeCmdListPopmenu
