@@ -54,7 +54,7 @@ inline GtkWidget *create_menu_button (const gchar *stock_id, const gchar *label_
 
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), button);
     gtk_widget_set_events (button, GDK_BUTTON_PRESS_MASK);
-    g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_menu_button_clicked), menu);
+    g_signal_connect (button, "clicked", G_CALLBACK (on_menu_button_clicked), menu);
 
     return button;
 }
@@ -80,10 +80,10 @@ GtkWidget *gnome_cmd_button_menu_new_from_stock (const gchar *stock_id, const gc
 
 gulong gnome_cmd_button_menu_connect_handler (GtkWidget *button, GtkWidget *menu)
 {
-    return g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (on_menu_button_clicked), menu);
+    return g_signal_connect (button, "clicked", G_CALLBACK (on_menu_button_clicked), menu);
 }
 
 void gnome_cmd_button_menu_disconnect_handler (GtkWidget *button, GtkWidget *menu)
 {
-    g_signal_handlers_disconnect_by_func (G_OBJECT (button), gpointer (on_menu_button_clicked), menu);
+    g_signal_handlers_disconnect_by_func (button, (gpointer) on_menu_button_clicked, menu);
 }
