@@ -59,7 +59,7 @@ static void scan_plugins_in_dir (const gchar *dpath)
 
    if (dir_size==-1)
    {
-       g_warning ( "pathconf(\".\"): %s", strerror(errno) );
+       g_warning ( "pathconf(\".\"): %s", strerror(errno));
       return;
    }
 
@@ -96,7 +96,7 @@ static void scan_plugins_in_dir (const gchar *dpath)
                     data->name = g_strdup (ent->d_name);
                     *strchr (data->name, '.') = '\0';               // strip {.py, .pyc} off
 
-                    data->path = g_build_path (G_DIR_SEPARATOR_S, dpath, data->name, NULL);
+                    data->path = g_build_filename (dpath, data->name, NULL);
                     g_strdelimit (data->name, "_-", ' ');           // replace '[-_]' with ' '
 
                     // if there is already data->name plugin in py_plugins list ...
@@ -129,7 +129,7 @@ static void scan_plugins_in_dir (const gchar *dpath)
 
 void python_plugin_manager_init ()
 {
-    gchar *user_dir = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir(), ".gnome-commander/plugins", NULL);
+    gchar *user_dir = g_build_filename (g_get_home_dir(), "." PACKAGE "/plugins", NULL);
     gchar *set_plugin_path = g_strdup_printf("sys.path = ['%s', '%s'] + sys.path", user_dir, PLUGIN_DIR);
 
     DEBUG('p', "User plugin dir: %s\n", user_dir);
@@ -176,7 +176,7 @@ GList *gnome_cmd_python_plugin_get_list()
 
 inline gchar *get_dir_as_str (GnomeCmdMainWin *mw, FileSelectorID id)
 {
-    GnomeCmdFileSelector *fs = gnome_cmd_main_win_get_fs (mw, id);
+    GnomeCmdFileSelector *fs = mw->fs(id);
 
     if (!fs)
         return NULL;
@@ -212,7 +212,7 @@ gboolean gnome_cmd_python_plugin_execute(const PythonPluginData *plugin, GnomeCm
 
     if (!pmod)
     {
-        create_error_dialog (_("Can't load python module 'gnomevfs' ('gnome.vfs')\n"));
+        gnome_cmd_show_message (*main_win, _("Can't load python module 'gnomevfs' ('gnome.vfs')"));
         goto out_A;
     }
 
@@ -248,7 +248,7 @@ gboolean gnome_cmd_python_plugin_execute(const PythonPluginData *plugin, GnomeCm
     GnomeCmdFileSelector *active_fs;
     GnomeCmdFileList     *active_fl;
 
-    active_fs = gnome_cmd_main_win_get_fs (mw, ACTIVE);
+    active_fs = mw->fs(ACTIVE);
     active_fl = active_fs ? active_fs->file_list() : NULL;
 
     if (!GNOME_CMD_IS_FILE_LIST (active_fl))
@@ -298,7 +298,7 @@ gboolean gnome_cmd_python_plugin_execute(const PythonPluginData *plugin, GnomeCm
     for (gint i=0; f; f=f->next, ++i)
     {
         GnomeCmdFile *finfo = (GnomeCmdFile *) f->data;
-        gchar *uri_str = gnome_cmd_file_get_uri_str (finfo);
+        gchar *uri_str = finfo->get_uri_str();
         PyObject *pArgs  = Py_BuildValue("(s)", uri_str);
         PyObject *pURI = PyEval_CallObject(pURIclass, pArgs);
         Py_XDECREF(pArgs);
