@@ -74,13 +74,18 @@ static void set_filter (GnomeCmdQuicksearchPopup *popup, const gchar *text)
         popup->priv->matches = NULL;
     }
 
-    gchar *pattern = g_strconcat (text, "*", NULL);
+    gchar *pattern;
+
+    if (gnome_cmd_data.options.quick_search_exact_match_begin)
+        pattern = gnome_cmd_data.options.quick_search_exact_match_end ? g_strdup (text) : g_strconcat (text, "*", NULL);
+    else
+        pattern = gnome_cmd_data.options.quick_search_exact_match_end ? g_strconcat ("*", text, NULL) : g_strconcat ("*", text, "*", NULL);
 
     for (GList *files = popup->priv->fl->get_visible_files(); files; files = files->next)
     {
         GnomeCmdFile *f = (GnomeCmdFile *) files->data;
 
-        if (gnome_cmd_filter_fnmatch (pattern, f->info->name, gnome_cmd_data.case_sens_sort))
+        if (gnome_cmd_filter_fnmatch (pattern, f->info->name, gnome_cmd_data.options.case_sens_sort))
         {
             if (first)
             {
@@ -153,7 +158,7 @@ static gboolean on_key_pressed (GtkWidget *entry, GdkEventKey *event, GnomeCmdQu
         case GDK_F8:
             popup->priv->fl->select_row(GNOME_CMD_CLIST (popup->priv->fl)->drag_motion_row);
             hide_popup (popup);
-            gnome_cmd_main_win_keypressed (main_win, event);
+            main_win->key_pressed(event);
             return TRUE;
 
         default:
@@ -217,7 +222,7 @@ inline void set_popup_position (GnomeCmdQuicksearchPopup *popup)
     gint x, y, w, h;
 
     gdk_window_get_origin (wid->window, &x, &y);
-    gdk_window_get_size (wid->window, &w, &h);
+    gdk_drawable_get_size (wid->window, &w, &h);
 
     y += h;
 
@@ -264,24 +269,20 @@ static void init (GnomeCmdQuicksearchPopup *popup)
     popup->lbl = gtk_label_new (_("Search"));
     popup->entry = gtk_entry_new ();
 
-    gtk_widget_ref (popup->frame);
-    gtk_widget_ref (popup->box);
-    gtk_widget_ref (popup->lbl);
-    gtk_widget_ref (popup->entry);
+    g_object_ref (popup->frame);
+    g_object_ref (popup->box);
+    g_object_ref (popup->lbl);
+    g_object_ref (popup->entry);
 
     gtk_box_pack_start (GTK_BOX (popup->box), popup->lbl, FALSE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (popup->box), popup->entry, FALSE, TRUE, 0);
     gtk_container_add (GTK_CONTAINER (popup->frame), popup->box);
     gtk_container_add (GTK_CONTAINER (popup), popup->frame);
 
-    gtk_signal_connect (GTK_OBJECT (popup->entry), "key-press-event",
-                        GTK_SIGNAL_FUNC (on_key_pressed), popup);
-    gtk_signal_connect_after (GTK_OBJECT (popup->entry), "key-press-event",
-                              GTK_SIGNAL_FUNC (on_key_pressed_after), popup);
-    gtk_signal_connect_after (GTK_OBJECT (popup->entry), "changed",
-                              GTK_SIGNAL_FUNC (on_text_changed), popup);
-    gtk_signal_connect (GTK_OBJECT (popup->entry), "button-press-event",
-                        GTK_SIGNAL_FUNC (on_button_press), popup);
+    g_signal_connect (popup->entry, "key-press-event", G_CALLBACK (on_key_pressed), popup);
+    g_signal_connect_after (popup->entry, "key-press-event", G_CALLBACK (on_key_pressed_after), popup);
+    g_signal_connect_after (popup->entry, "changed", G_CALLBACK (on_text_changed), popup);
+    g_signal_connect (popup->entry, "button-press-event", G_CALLBACK (on_button_press), popup);
 
     gtk_widget_show (popup->lbl);
     gtk_widget_show (popup->entry);
@@ -325,7 +326,7 @@ GtkWidget *gnome_cmd_quicksearch_popup_new (GnomeCmdFileList *fl)
 {
     GnomeCmdQuicksearchPopup *popup;
 
-    popup = (GnomeCmdQuicksearchPopup *) gtk_type_new (gnome_cmd_quicksearch_popup_get_type ());
+    popup = (GnomeCmdQuicksearchPopup *) g_object_new (GNOME_CMD_TYPE_QUICKSEARCH_POPUP, NULL);
     GTK_WINDOW (popup)->type = GTK_WINDOW_POPUP;
     popup->priv->fl = fl;
     popup->priv->last_focused_file = NULL;
