@@ -73,7 +73,7 @@ namespace GnomeCmd
 
       public:
 
-        operator gboolean ()                    {  return !malformed_pattern;   }
+        operator gboolean () const              {  return !malformed_pattern;   }
     };
 
     class RegexFind: public Regex
@@ -109,7 +109,6 @@ namespace GnomeCmd
         gchar *replace(const std::string &s)    {  return replace(s.c_str());  }
     };
 
-
     inline ReplacePattern::ReplacePattern(const gchar *from, const gchar *to, gboolean case_sensitive): FindPattern(from,case_sensitive)
     {
         if (to)  replacement = to;
