@@ -22,9 +22,11 @@
 #ifndef __GNOME_CMD_STYLE_H__
 #define __GNOME_CMD_STYLE_H__
 
+#include "gnome-cmd-data.h"
+
 extern GtkStyle *list_style, *sel_list_style;
 extern GtkStyle *alt_list_style, *alt_sel_list_style;
 
-void gnome_cmd_style_create ();
+void gnome_cmd_style_create (GnomeCmdData::Options &cfg);
 
 #endif // __GNOME_CMD_STYLE_H__
