@@ -33,14 +33,8 @@
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-file-list.h"
 #include "gnome-cmd-file-selector.h"
-#include "gnome-cmd-con-dialog.h"
 #include "gnome-cmd-main-win.h"
-#include "gnome-cmd-make-copy-dialog.h"
-#include "gnome-cmd-prepare-copy-dialog.h"
-#include "gnome-cmd-prepare-move-dialog.h"
 #include "gnome-cmd-python-plugin.h"
-#include "gnome-cmd-chmod-dialog.h"
-#include "gnome-cmd-chown-dialog.h"
 #include "gnome-cmd-user-actions.h"
 #include "gnome-cmd-dir-indicator.h"
 #include "gnome-cmd-style.h"
@@ -48,12 +42,18 @@
 #include "cap.h"
 #include "utils.h"
 #include "dialogs/gnome-cmd-advrename-dialog.h"
+#include "dialogs/gnome-cmd-chmod-dialog.h"
+#include "dialogs/gnome-cmd-chown-dialog.h"
+#include "dialogs/gnome-cmd-con-dialog.h"
 #include "dialogs/gnome-cmd-remote-dialog.h"
 #include "dialogs/gnome-cmd-key-shortcuts-dialog.h"
+#include "dialogs/gnome-cmd-make-copy-dialog.h"
 #include "dialogs/gnome-cmd-manage-bookmarks-dialog.h"
 #include "dialogs/gnome-cmd-mkdir-dialog.h"
 #include "dialogs/gnome-cmd-search-dialog.h"
 #include "dialogs/gnome-cmd-options-dialog.h"
+#include "dialogs/gnome-cmd-prepare-copy-dialog.h"
+#include "dialogs/gnome-cmd-prepare-move-dialog.h"
 
 using namespace std;
 
