@@ -31,6 +31,7 @@
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-main-win.h"
+#include "gnome-cmd-xml-config.h"
 #include "dict.h"
 
 #define GNOME_CMD_USER_ACTION(f)   void f(GtkMenuItem *menuitem=NULL, gpointer user_data=NULL)
@@ -88,7 +89,7 @@ inline std::string key2str(const GdkEventKey &event)
 
 inline GdkEventKey str2key(gchar *s, guint &state, guint &key_val)
 {
-    g_strdown (s);
+    s = g_ascii_strdown (s, -1);
 
     gchar *key = strrchr(s, '>');       // find last '>'
     key = key ? key+1 : s;
@@ -114,6 +115,8 @@ inline GdkEventKey str2key(gchar *s, guint &state, guint &key_val)
         break;
     }
 
+    g_free (s);
+
     GdkEventKey event;
 
     event.keyval = key_val;
@@ -160,12 +163,14 @@ class GnomeCmdUserActions
   public:
 
     void init();
+    void set_defaults();
     void shutdown();
 
     void load(const gchar *section);
-    void write(const gchar *section);
 
-    void clear ()                                                           {   action.clear();               }
+    void clear()                                                            {   action.clear();               }
+
+    gboolean has_action(const gchar *a)                                     {  return action_func[a]!=NULL;   }
 
     gboolean register_action(guint state, guint keyval, const gchar *name, const char *user_data=NULL);
     gboolean register_action(guint keyval, const gchar *name, const char *user_data=NULL);
@@ -187,11 +192,14 @@ class GnomeCmdUserActions
 
     const_iterator begin()                                                  {  return action.begin();                                 }
     const_iterator end()                                                    {  return action.end();                                   }
+    unsigned size()                                                         {  return action.size();                                  }
 
     const gchar *name(const_iterator &i)                                    {  return action_func[i->second.func].c_str();            }
     const gchar *name(const std::string description)                        {  return action_func[action_name[description]].c_str();  }
     const gchar *description(const_iterator &i)                             {  return action_name[i->second.func].c_str();            }
     const gchar *options(const_iterator &i)                                 {  return i->second.user_data.c_str();                    }
+
+    friend XML::xstream &operator << (XML::xstream &xml, GnomeCmdUserActions &usr);
 };
 
 
@@ -217,6 +225,7 @@ GNOME_CMD_USER_ACTION(no_action);
 
 /************** File Menu **************/
 GNOME_CMD_USER_ACTION(file_copy);
+GNOME_CMD_USER_ACTION(file_copy_as);
 GNOME_CMD_USER_ACTION(file_move);
 GNOME_CMD_USER_ACTION(file_delete);
 GNOME_CMD_USER_ACTION(file_view);
@@ -262,7 +271,9 @@ GNOME_CMD_USER_ACTION(edit_copy_fnames);
 
 /************** Command Menu **************/
 GNOME_CMD_USER_ACTION(command_execute);
+GNOME_CMD_USER_ACTION(command_open_terminal__internal);             // this function is NOT exposed to user as UserAction
 GNOME_CMD_USER_ACTION(command_open_terminal);
+GNOME_CMD_USER_ACTION(command_open_terminal_as_root);
 GNOME_CMD_USER_ACTION(command_open_nautilus);
 GNOME_CMD_USER_ACTION(command_open_nautilus_in_cwd);
 GNOME_CMD_USER_ACTION(command_root_mode);
@@ -273,6 +284,7 @@ GNOME_CMD_USER_ACTION(view_concombo);
 GNOME_CMD_USER_ACTION(view_toolbar);
 GNOME_CMD_USER_ACTION(view_buttonbar);
 GNOME_CMD_USER_ACTION(view_cmdline);
+GNOME_CMD_USER_ACTION(view_dir_history);
 GNOME_CMD_USER_ACTION(view_hidden_files);
 GNOME_CMD_USER_ACTION(view_backup_files);
 GNOME_CMD_USER_ACTION(view_up);
@@ -282,14 +294,23 @@ GNOME_CMD_USER_ACTION(view_forward);
 GNOME_CMD_USER_ACTION(view_last);
 GNOME_CMD_USER_ACTION(view_refresh);
 GNOME_CMD_USER_ACTION(view_equal_panes);
+GNOME_CMD_USER_ACTION(view_maximize_pane);
 GNOME_CMD_USER_ACTION(view_in_left_pane);
 GNOME_CMD_USER_ACTION(view_in_right_pane);
 GNOME_CMD_USER_ACTION(view_in_active_pane);
 GNOME_CMD_USER_ACTION(view_in_inactive_pane);
+GNOME_CMD_USER_ACTION(view_directory);
 GNOME_CMD_USER_ACTION(view_home);
 GNOME_CMD_USER_ACTION(view_root);
 GNOME_CMD_USER_ACTION(view_new_tab);
 GNOME_CMD_USER_ACTION(view_close_tab);
+GNOME_CMD_USER_ACTION(view_close_all_tabs);
+GNOME_CMD_USER_ACTION(view_close_duplicate_tabs);
+GNOME_CMD_USER_ACTION(view_prev_tab);
+GNOME_CMD_USER_ACTION(view_next_tab);
+GNOME_CMD_USER_ACTION(view_in_new_tab);
+GNOME_CMD_USER_ACTION(view_in_inactive_tab);
+GNOME_CMD_USER_ACTION(view_toggle_tab_lock);
 
 /************** Bookmarks Menu **************/
 GNOME_CMD_USER_ACTION(bookmarks_add_current);
@@ -298,13 +319,14 @@ GNOME_CMD_USER_ACTION(bookmarks_goto);
 
 /************** Options Menu **************/
 GNOME_CMD_USER_ACTION(options_edit);
-GNOME_CMD_USER_ACTION(options_edit_mime_types);
 GNOME_CMD_USER_ACTION(options_edit_shortcuts);
 
 /************** Connections Menu **************/
 GNOME_CMD_USER_ACTION(connections_open);
 GNOME_CMD_USER_ACTION(connections_new);
 GNOME_CMD_USER_ACTION(connections_change);          // this function is NOT exposed to user as UserAction
+GNOME_CMD_USER_ACTION(connections_change_left);
+GNOME_CMD_USER_ACTION(connections_change_right);
 GNOME_CMD_USER_ACTION(connections_close);           // this function is NOT exposed to user as UserAction
 GNOME_CMD_USER_ACTION(connections_close_current);
 
