@@ -118,7 +118,7 @@ static void init (GnomeCmdXferProgressWin *win)
 
 GtkWidget *gnome_cmd_xfer_progress_win_new (guint no_of_files)
 {
-    GnomeCmdXferProgressWin *win = (GnomeCmdXferProgressWin *) gtk_type_new (gnome_cmd_xfer_progress_win_get_type ());
+    GnomeCmdXferProgressWin *win = (GnomeCmdXferProgressWin *) g_object_new (GNOME_CMD_TYPE_XFER_PROGRESS_WIN, NULL);
 
     if (no_of_files<2)
     {
@@ -171,8 +171,8 @@ void gnome_cmd_xfer_progress_win_set_total_progress (GnomeCmdXferProgressWin *wi
         gtk_progress_set_percentage (GTK_PROGRESS (win->fileprog), file_prog);
     }
 
-    gchar *bytes_total_str = g_strdup (size2string (bytes_total, gnome_cmd_data.size_disp_mode));
-    const gchar *bytes_copied_str = size2string (bytes_copied, gnome_cmd_data.size_disp_mode);
+    gchar *bytes_total_str = g_strdup (size2string (bytes_total, gnome_cmd_data.options.size_disp_mode));
+    const gchar *bytes_copied_str = size2string (bytes_copied, gnome_cmd_data.options.size_disp_mode);
 
     gchar text[128];
 
