@@ -15,29 +15,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-*/
-
-/* gmarkup.c - Simple XML-like parser
- *
- *  Copyright 2000, 2003 Red Hat, Inc.
- *  Copyright 2007, 2008 Ryan Lortie <desrt@desrt.ca>
- *
- * GLib is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * GLib is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with GLib; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *   Boston, MA 02111-1307, USA.
+    along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -48,16 +26,21 @@
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-xml-config.h"
-#include "gnome-cmd-advrename-dialog.h"
+#include "gnome-cmd-con-list.h"
 #include "gnome-cmd-regex.h"
+#include "gnome-cmd-user-actions.h"
 #include "dict.h"
 #include "utils.h"
+#include "dialogs/gnome-cmd-advrename-dialog.h"
 
 using namespace std;
 
 
+gchar *XML::xstream::escaped_text = NULL;
+
+
 #if !GLIB_CHECK_VERSION (2, 16, 0)
-typedef enum
+enum GMarkupCollectType
 {
   G_MARKUP_COLLECT_INVALID,
   G_MARKUP_COLLECT_STRING,
@@ -66,7 +49,7 @@ typedef enum
   G_MARKUP_COLLECT_TRISTATE,
 
   G_MARKUP_COLLECT_OPTIONAL = (1 << 16)
-} GMarkupCollectType;
+};
 
 
 static gboolean
@@ -329,6 +312,12 @@ failure:
 
 enum {XML_ELEM_NOT_FOUND,
       XML_GNOMECOMMANDER,
+      XML_GNOMECOMMANDER_LAYOUT,
+      XML_GNOMECOMMANDER_LAYOUT_PANEL,
+      XML_GNOMECOMMANDER_LAYOUT_PANEL_TAB,
+      XML_GNOMECOMMANDER_HISTORY,
+      XML_GNOMECOMMANDER_HISTORY_DIRECTORIES,
+      XML_GNOMECOMMANDER_HISTORY_DIRECTORIES_DIRECTORY,
       XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL,
       XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_WINDOWSIZE,
       XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_PROFILE,
@@ -339,13 +328,42 @@ enum {XML_ELEM_NOT_FOUND,
       XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_PROFILE_CASECONVERSION,
       XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_PROFILE_TRIMBLANKS,
       XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_HISTORY,
-      XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_HISTORY_TEMPLATE};
+      XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_HISTORY_TEMPLATE,
+      XML_GNOMECOMMANDER_SEARCHTOOL,
+      XML_GNOMECOMMANDER_SEARCHTOOL_WINDOWSIZE,
+      XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE,
+      XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_PATTERN,
+      XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_SUBDIRECTORIES,
+      XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_TEXT,
+      XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY,
+      XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY_PATTERN,
+      XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY_TEXT,
+      XML_GNOMECOMMANDER_BOOKMARKSTOOL,
+      XML_GNOMECOMMANDER_BOOKMARKSTOOL_WINDOWSIZE,
+      XML_GNOMECOMMANDER_CONNECTIONS,
+      XML_GNOMECOMMANDER_CONNECTIONS_CONNECTION,
+      XML_GNOMECOMMANDER_BOOKMARKS,
+      XML_GNOMECOMMANDER_BOOKMARKS_GROUP,
+      XML_GNOMECOMMANDER_BOOKMARKS_GROUP_BOOKMARK,
+      XML_GNOMECOMMANDER_SELECTIONS,
+      XML_GNOMECOMMANDER_SELECTIONS_PROFILE,
+      XML_GNOMECOMMANDER_SELECTIONS_PROFILE_PATTERN,
+      XML_GNOMECOMMANDER_SELECTIONS_PROFILE_SUBDIRECTORIES,
+      XML_GNOMECOMMANDER_SELECTIONS_PROFILE_TEXT,
+      XML_GNOMECOMMANDER_KEYBINDINGS,
+      XML_GNOMECOMMANDER_KEYBINDINGS_KEY};
 
 
 static DICT<guint> xml_elem_names(XML_ELEM_NOT_FOUND);
 static stack<string> xml_paths;
 
 static GnomeCmdData::AdvrenameConfig::Profile xml_adv_profile;
+static GnomeCmdData::Selection xml_search_profile;
+
+static DICT<FileSelectorID> xml_fs_names(INACTIVE);
+static FileSelectorID xml_fs = INACTIVE;
+
+static GnomeCmdCon *xml_con = NULL;
 
 
 static bool is_default(GnomeCmdData::AdvrenameConfig::Profile &profile)
@@ -373,10 +391,45 @@ static void xml_start(GMarkupParseContext *context,
 
     GnomeCmdData *cfg = (GnomeCmdData *) user_data;
     gchar *param1, *param2, *param3;
-    gboolean param4;
+    gboolean param4, param5;
 
     switch (xml_elem_names[xml_paths.top()])
     {
+        case XML_GNOMECOMMANDER_LAYOUT_PANEL:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "name", &param1,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                xml_fs = xml_fs_names[param1];
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_LAYOUT_PANEL_TAB:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             GMarkupCollectType(G_MARKUP_COLLECT_STRING|G_MARKUP_COLLECT_OPTIONAL), "path", &param1,    //  FIXME: temporarily, G_MARKUP_COLLECT_OPTIONAL to be removed after 1.4
+                                             G_MARKUP_COLLECT_STRING|G_MARKUP_COLLECT_OPTIONAL, "dir", &param2,
+                                             G_MARKUP_COLLECT_STRING, "sort", &param3,
+                                             G_MARKUP_COLLECT_BOOLEAN, "asc", &param4,
+                                             G_MARKUP_COLLECT_BOOLEAN|G_MARKUP_COLLECT_OPTIONAL, "lock", &param5,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                string dir(param1?param1:(param2?param2:""));     //  FIXME: temporarily, dir(param1) after 1.4
+                gint sort = atoi(param3);
+
+                if (!dir.empty() && sort<GnomeCmdFileList::NUM_COLUMNS)
+                    cfg->tabs[xml_fs].push_back(make_pair(dir,make_triple((GnomeCmdFileList::ColumnID) sort,(GtkSortType) param4,param5)));
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_HISTORY_DIRECTORIES_DIRECTORY:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "path", &param1,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                gnome_cmd_con_get_dir_history (get_home_con())->add(param1);
+            }
+            break;
+
         case XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_WINDOWSIZE:
             if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
                                              G_MARKUP_COLLECT_STRING, "width", &param1,
@@ -440,6 +493,188 @@ static void xml_start(GMarkupParseContext *context,
                 xml_adv_profile.trim_blanks = atoi(param1);
             break;
 
+        case XML_GNOMECOMMANDER_SEARCHTOOL_WINDOWSIZE:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "width", &param1,
+                                             G_MARKUP_COLLECT_STRING, "height", &param2,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                cfg->search_defaults.width = atoi(param1);
+                cfg->search_defaults.height = atoi(param2);
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_BOOKMARKSTOOL_WINDOWSIZE:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "width", &param1,
+                                             G_MARKUP_COLLECT_STRING, "height", &param2,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                cfg->bookmarks_defaults.width = atoi(param1);
+                cfg->bookmarks_defaults.height = atoi(param2);
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_CONNECTIONS:
+            cfg->XML_cfg_has_connections = TRUE;
+            break;
+
+        case XML_GNOMECOMMANDER_CONNECTIONS_CONNECTION:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "name", &param1,
+                                             G_MARKUP_COLLECT_STRING, "uri", &param2,
+                                             G_MARKUP_COLLECT_STRING, "auth", &param3,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                if (gnome_cmd_con_list_get()->has_alias(param1))
+                    g_warning ("<Connections> duplicate entry: '%s' - ignored", param1);
+                else
+                {
+                    GnomeCmdConRemote *server = gnome_cmd_con_remote_new (param1, param2);
+
+                    if (server)
+                        gnome_cmd_con_list_get()->add(server);
+                    else
+                        g_warning ("<Connection> invalid URI: '%s' - ignored", param2);
+                }
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_BOOKMARKS:
+            cfg->XML_cfg_has_bookmarks = TRUE;
+            break;
+
+        case XML_GNOMECOMMANDER_BOOKMARKS_GROUP:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "name", &param1,
+                                             G_MARKUP_COLLECT_BOOLEAN|G_MARKUP_COLLECT_OPTIONAL, "remote", &param4,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                if (param4) //  if remote...
+                    xml_con = gnome_cmd_con_list_get()->find_alias(param1);
+                else
+                    if (strcmp(param1,"Home")==0)
+                        xml_con = gnome_cmd_con_list_get()->get_home();
+                    else
+                        if (strcmp(param1,"SMB")==0)
+                            xml_con = gnome_cmd_con_list_get()->get_smb();
+                        else
+                            xml_con = NULL;
+
+                if (!xml_con)
+                    g_warning ("<Bookmarks> unknown connection: '%s' - ignored", param1);
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_BOOKMARKS_GROUP_BOOKMARK:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRDUP, "name", &param1,
+                                             G_MARKUP_COLLECT_STRDUP, "path", &param2,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                if (xml_con)
+                    gnome_cmd_con_add_bookmark (xml_con, param1, param2);
+                else
+                {
+                    // g_warning ("<Bookmarks> unknown connection: '%s' - ignored", param1);
+                    g_free (param1);
+                    g_free (param2);
+                }
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE:
+        case XML_GNOMECOMMANDER_SELECTIONS_PROFILE:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "name", &param1,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                xml_search_profile.reset();
+                xml_search_profile.name = param1;
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_PATTERN:
+        case XML_GNOMECOMMANDER_SELECTIONS_PROFILE_PATTERN:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "syntax", &param1,
+                                             G_MARKUP_COLLECT_BOOLEAN, "match-case", &param4,
+                                             G_MARKUP_COLLECT_INVALID))
+            {
+                xml_search_profile.syntax = strcmp(param1,"regex")==0 ? Filter::TYPE_REGEX : Filter::TYPE_FNMATCH;
+                //  FIXME:  xml_search_profile.? = param4;
+            }
+            break;
+
+        case XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_SUBDIRECTORIES:
+        case XML_GNOMECOMMANDER_SELECTIONS_PROFILE_SUBDIRECTORIES:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_STRING, "max-depth", &param1,
+                                             G_MARKUP_COLLECT_INVALID))
+                xml_search_profile.max_depth = atoi(param1);
+            break;
+
+        case XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_TEXT:
+        case XML_GNOMECOMMANDER_SELECTIONS_PROFILE_TEXT:
+            if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                             G_MARKUP_COLLECT_BOOLEAN, "match-case", &param4,
+                                             G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "content-search", &param5,
+                                             G_MARKUP_COLLECT_INVALID))
+                xml_search_profile.match_case = param4;
+                xml_search_profile.content_search = param5;
+            break;
+
+        case XML_GNOMECOMMANDER_KEYBINDINGS_KEY:
+            {
+                gboolean shift, control, alt, super, hyper, meta;
+
+                if (g_markup_collect_attributes (element_name, attribute_names, attribute_values, error,
+                                                 G_MARKUP_COLLECT_STRING, "name", &param1,
+                                                 G_MARKUP_COLLECT_STRING, "action", &param2,
+                                                 G_MARKUP_COLLECT_STRING | G_MARKUP_COLLECT_OPTIONAL, "options", &param3,
+                                                 G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "shift", &shift,
+                                                 G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "control", &control,
+                                                 G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "alt", &alt,
+                                                 G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "super", &super,
+#if GTK_CHECK_VERSION (2, 10, 0)
+                                                 G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "hyper", &hyper,
+                                                 G_MARKUP_COLLECT_BOOLEAN | G_MARKUP_COLLECT_OPTIONAL, "meta", &meta,
+#endif
+                                                 G_MARKUP_COLLECT_INVALID))
+                    {
+                        if (gcmd_user_actions.has_action(param2))
+                        {
+                            guint keyval = gdk_key_names[param1];
+
+                             if (keyval==GDK_VoidSymbol)
+                                if (strlen(param1)==1 && ascii_isalnum (*param1))
+                                    keyval = *param1;
+
+                            if (keyval!=GDK_VoidSymbol)
+                            {
+                                guint accel_mask = 0;
+
+                                if (shift)  accel_mask |= GDK_SHIFT_MASK;
+                                if (control)  accel_mask |= GDK_CONTROL_MASK;
+                                if (alt)  accel_mask |= GDK_MOD1_MASK;
+#if GTK_CHECK_VERSION (2, 10, 0)
+                                if (super)  accel_mask |= GDK_SUPER_MASK;
+                                if (hyper)  accel_mask |= GDK_HYPER_MASK;
+                                if (meta)  accel_mask |= GDK_META_MASK;
+#else
+                                if (super)  accel_mask |= GDK_MOD4_MASK;
+#endif
+                                gcmd_user_actions.register_action(accel_mask, keyval, param2, param3);
+                            }
+                            else
+                                g_warning ("<KeyBindings> invalid key name: '%s' - ignored", param1);
+                        }
+                        else
+                            g_warning ("<KeyBindings> unknown user action: '%s' - ignored", param2);
+                    }
+            }
+            break;
+
         default:
             break;
     }
@@ -455,6 +690,10 @@ static void xml_end (GMarkupParseContext *context,
 
     switch (xml_elem_names[xml_paths.top()])
     {
+        case XML_GNOMECOMMANDER_HISTORY_DIRECTORIES:
+            gnome_cmd_con_get_dir_history (get_home_con())->reverse();
+            break;
+
         case XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_PROFILE:
             cfg->advrename_defaults.profiles.push_back(xml_adv_profile);
             break;
@@ -477,6 +716,21 @@ static void xml_end (GMarkupParseContext *context,
             cfg->advrename_defaults.templates.reverse();
             break;
 
+        case XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE:
+            if (xml_search_profile.name=="Default")
+                cfg->search_defaults.default_profile = xml_search_profile;
+            break;
+
+        case XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY:
+            cfg->search_defaults.name_patterns.reverse();
+            cfg->search_defaults.content_patterns.reverse();
+            break;
+
+        case XML_GNOMECOMMANDER_SELECTIONS_PROFILE:
+            if (xml_search_profile.name!="Default")
+                cfg->selections.push_back(xml_search_profile);
+            break;
+
         default:
             break;
     }
@@ -503,6 +757,24 @@ static void xml_end (GMarkupParseContext *context,
             cfg->advrename_defaults.templates.add(text);
             break;
 
+        case XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_PATTERN:
+        case XML_GNOMECOMMANDER_SELECTIONS_PROFILE_PATTERN:
+            xml_search_profile.filename_pattern = text;
+            break;
+
+        case XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_TEXT:
+        case XML_GNOMECOMMANDER_SELECTIONS_PROFILE_TEXT:
+            xml_search_profile.text_pattern = text;
+            break;
+
+        case XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY_PATTERN:
+            cfg->search_defaults.name_patterns.add(text);
+            break;
+
+        case XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY_TEXT:
+            cfg->search_defaults.content_patterns.add(text);
+            break;
+
         default:
             break;
     }
@@ -520,7 +792,13 @@ gboolean gnome_cmd_xml_config_parse (const gchar *xml, gsize xml_len, GnomeCmdDa
     }
     xml_elem_data[] = {
                         {XML_GNOMECOMMANDER, "/GnomeCommander"},
+                        {XML_GNOMECOMMANDER_LAYOUT, "/GnomeCommander/Layout"},
+                        {XML_GNOMECOMMANDER_LAYOUT_PANEL, "/GnomeCommander/Layout/Panel"},
+                        {XML_GNOMECOMMANDER_LAYOUT_PANEL_TAB, "/GnomeCommander/Layout/Panel/Tab"},
                         {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL, "/GnomeCommander/AdvancedRenameTool"},
+                        {XML_GNOMECOMMANDER_HISTORY, "/GnomeCommander/History"},
+                        {XML_GNOMECOMMANDER_HISTORY_DIRECTORIES, "/GnomeCommander/History/Directories"},
+                        {XML_GNOMECOMMANDER_HISTORY_DIRECTORIES_DIRECTORY, "/GnomeCommander/History/Directories/Directory"},
                         {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_WINDOWSIZE, "/GnomeCommander/AdvancedRenameTool/WindowSize"},
                         {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_PROFILE, "/GnomeCommander/AdvancedRenameTool/Profile"},
                         {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_PROFILE_TEMPLATE, "/GnomeCommander/AdvancedRenameTool/Profile/Template"},
@@ -531,11 +809,35 @@ gboolean gnome_cmd_xml_config_parse (const gchar *xml, gsize xml_len, GnomeCmdDa
                         {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_PROFILE_TRIMBLANKS, "/GnomeCommander/AdvancedRenameTool/Profile/TrimBlanks"},
                         {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_HISTORY, "/GnomeCommander/AdvancedRenameTool/History"},
                         {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_HISTORY_TEMPLATE, "/GnomeCommander/AdvancedRenameTool/History/Template"},
-                        {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_HISTORY, "/GnomeCommander/AdvancedRenameTool/TemplateHistory"},                      //  FIXME: for compatibility, to be removed after 1.2.8 release
-                        {XML_GNOMECOMMANDER_ADVANCEDRENAMETOOL_HISTORY_TEMPLATE, "/GnomeCommander/AdvancedRenameTool/TemplateHistory/Template"}     //  FIXME: for compatibility, to be removed after 1.2.8 release
+                        {XML_GNOMECOMMANDER_SEARCHTOOL, "/GnomeCommander/SearchTool"},
+                        {XML_GNOMECOMMANDER_SEARCHTOOL_WINDOWSIZE, "/GnomeCommander/SearchTool/WindowSize"},
+                        {XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE, "/GnomeCommander/SearchTool/Profile"},
+                        {XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_PATTERN, "/GnomeCommander/SearchTool/Profile/Pattern"},
+                        {XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_SUBDIRECTORIES, "/GnomeCommander/SearchTool/Profile/Subdirectories"},
+                        {XML_GNOMECOMMANDER_SEARCHTOOL_PROFILE_TEXT, "/GnomeCommander/SearchTool/Profile/Text"},
+                        {XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY, "/GnomeCommander/SearchTool/History"},
+                        {XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY_PATTERN, "/GnomeCommander/SearchTool/History/Pattern"},
+                        {XML_GNOMECOMMANDER_SEARCHTOOL_HISTORY_TEXT, "/GnomeCommander/SearchTool/History/Text"},
+                        {XML_GNOMECOMMANDER_BOOKMARKSTOOL, "/GnomeCommander/BookmarksTool"},
+                        {XML_GNOMECOMMANDER_BOOKMARKSTOOL_WINDOWSIZE, "/GnomeCommander/BookmarksTool/WindowSize"},
+                        {XML_GNOMECOMMANDER_CONNECTIONS, "/GnomeCommander/Connections"},
+                        {XML_GNOMECOMMANDER_CONNECTIONS_CONNECTION, "/GnomeCommander/Connections/Connection"},
+                        {XML_GNOMECOMMANDER_BOOKMARKS, "/GnomeCommander/Bookmarks"},
+                        {XML_GNOMECOMMANDER_BOOKMARKS_GROUP, "/GnomeCommander/Bookmarks/Group"},
+                        {XML_GNOMECOMMANDER_BOOKMARKS_GROUP_BOOKMARK, "/GnomeCommander/Bookmarks/Group/Bookmark"},
+                        {XML_GNOMECOMMANDER_SELECTIONS, "/GnomeCommander/Selections"},
+                        {XML_GNOMECOMMANDER_SELECTIONS_PROFILE, "/GnomeCommander/Selections/Profile"},
+                        {XML_GNOMECOMMANDER_SELECTIONS_PROFILE_PATTERN, "/GnomeCommander/Selections/Profile/Pattern"},
+                        {XML_GNOMECOMMANDER_SELECTIONS_PROFILE_SUBDIRECTORIES, "/GnomeCommander/Selections/Profile/Subdirectories"},
+                        {XML_GNOMECOMMANDER_SELECTIONS_PROFILE_TEXT, "/GnomeCommander/Selections/Profile/Text"},
+                        {XML_GNOMECOMMANDER_KEYBINDINGS, "/GnomeCommander/KeyBindings"},
+                        {XML_GNOMECOMMANDER_KEYBINDINGS_KEY, "/GnomeCommander/KeyBindings/Key"}
                        };
 
-    load_data (xml_elem_names, xml_elem_data, G_N_ELEMENTS(xml_elem_data));
+    load_data (xml_elem_names, xml_elem_data, G_N_ELEMENTS (xml_elem_data));
+
+    xml_fs_names.add(LEFT,"left");
+    xml_fs_names.add(RIGHT,"right");
 
     if (xml_len==-1)
         xml_len = strlen (xml);
@@ -580,72 +882,3 @@ gboolean gnome_cmd_xml_config_load (const gchar *path, GnomeCmdData &cfg)
 
     return retval;
 }
-
-
-inline void fprintf_escaped(FILE *f, const char *format, ...)
-{
-    va_list args;
-
-    va_start (args, format);
-    gchar *s = g_markup_vprintf_escaped (format, args);
-    va_end (args);
-
-    fputs(s, f);
-    g_free (s);
-}
-
-
-void gnome_cmd_xml_config_save (const gchar *path, GnomeCmdData &cfg)
-{
-    FILE *f = fopen(path,"w");
-
-    if (!f)
-        return;
-
-    fputs("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n", f);
-    fputs("<!-- Created with GNOME Commander (http://gcmd.github.io/) -->\n", f);
-    fputs("<GnomeCommander version=\"" VERSION "\">\n", f);
-    fputs("\t<AdvancedRenameTool>\n", f);
-    fprintf (f, "\t\t<WindowSize width=\"%i\" height=\"%i\" />\n", cfg.advrename_defaults.width, cfg.advrename_defaults.height);
-
-    fprintf_escaped(f, "\t\t<Profile name=\"%s\">\n", "Default");
-    fprintf_escaped(f, "\t\t\t<Template>%s</Template>\n", cfg.advrename_defaults.templates.empty()  ? "$N" : cfg.advrename_defaults.templates.front());
-    fprintf(f, "\t\t\t<Counter start=\"%u\" step=\"%i\" width=\"%u\" />\n", cfg.advrename_defaults.default_profile.counter_start,
-                                                                            cfg.advrename_defaults.default_profile.counter_step,
-                                                                            cfg.advrename_defaults.default_profile.counter_width);
-    fputs("\t\t\t<Regexes>\n", f);
-
-    for (std::vector<GnomeCmd::ReplacePattern>::const_iterator r=cfg.advrename_defaults.default_profile.regexes.begin(); r!=cfg.advrename_defaults.default_profile.regexes.end(); ++r)
-        fprintf_escaped(f, "\t\t\t\t<Regex pattern=\"%s\" replace=\"%s\" match-case=\"%u\" />\n", r->pattern.c_str(), r->replacement.c_str(), r->match_case);
-
-    fputs("\t\t\t</Regexes>\n", f);
-    fprintf(f, "\t\t\t<CaseConversion use=\"%u\" />\n", cfg.advrename_defaults.default_profile.case_conversion);
-    fprintf(f, "\t\t\t<TrimBlanks use=\"%u\" />\n", cfg.advrename_defaults.default_profile.trim_blanks);
-    fputs("\t\t</Profile>\n", f);
-
-    for (std::vector<GnomeCmdData::AdvrenameConfig::Profile>::const_iterator p=cfg.advrename_defaults.profiles.begin(); p!=cfg.advrename_defaults.profiles.end(); ++p)
-    {
-        fprintf_escaped(f, "\t\t<Profile name=\"%s\">\n", p->name.c_str());
-        fprintf_escaped(f, "\t\t\t<Template>%s</Template>\n", p->template_string.empty() ? "$N" : p->template_string.c_str());
-        fprintf(f, "\t\t\t<Counter start=\"%u\" step=\"%i\" width=\"%u\" />\n", p->counter_start, p->counter_step, p->counter_width);
-        fputs("\t\t\t<Regexes>\n", f);
-        for (std::vector<GnomeCmd::ReplacePattern>::const_iterator r=p->regexes.begin(); r!=p->regexes.end(); ++r)
-            fprintf_escaped(f, "\t\t\t\t<Regex pattern=\"%s\" replace=\"%s\" match-case=\"%u\" />\n", r->pattern.c_str(), r->replacement.c_str(), r->match_case);
-        fputs("\t\t\t</Regexes>\n", f);
-        fprintf(f, "\t\t\t<CaseConversion use=\"%u\" />\n", p->case_conversion);
-        fprintf(f, "\t\t\t<TrimBlanks use=\"%u\" />\n", p->trim_blanks);
-        fputs("\t\t</Profile>\n", f);
-    }
-
-    fputs("\t\t<History>\n", f);
-
-    for (GList *i=cfg.advrename_defaults.templates.ents; i; i=i->next)
-        fprintf_escaped(f, "\t\t\t<Template>%s</Template>\n", (const gchar *) i->data);
-
-    fputs("\t\t</History>\n", f);
-    fputs("\t</AdvancedRenameTool>\n", f);
-    fputs("</GnomeCommander>\n", f);
-    fputs("", f);
-
-    fclose(f);
-}
