@@ -22,16 +22,22 @@
 #ifndef __HISTORY_H__
 #define __HISTORY_H__
 
-struct History
+class History
 {
-    GList *ents;
-    GList *pos;
     gint max;
     gboolean is_locked;
 
-    History(gint max): ents(NULL), pos(NULL), is_locked(FALSE)       {  this->max = max;  }
+    GList *pos;
+
+  public:
+
+    GList *ents;
+
+    History(gint max): is_locked(FALSE), pos(NULL), ents(NULL)       {  this->max = max;  }
     ~History();
 
+    History &operator = (GList *list);
+
     guint size()                                         {  return g_list_length (ents);  }
     gboolean empty()                                     {  return ents==NULL;            }
 
@@ -50,6 +56,21 @@ struct History
 
     void lock()                                             {  is_locked = TRUE;         }
     void unlock()                                           {  is_locked = FALSE;        }
+
+    gboolean locked() const                                 {  return is_locked;         }
 };
 
+inline History &History::operator = (GList *list)
+{
+    if (ents)
+    {
+        g_list_foreach (ents, (GFunc) g_free, NULL);
+        g_list_free (ents);
+    }
+
+    pos = ents = list;      //  FIXME: no check for max and dups...
+
+    return *this;
+}
+
 #endif // __HISTORY_H__
