@@ -29,9 +29,6 @@
 using namespace std;
 
 
-#define NUM_FILE_TYPE_PIXMAPS 8
-
-
 struct CacheEntry
 {
     gboolean dead_end;
@@ -42,7 +39,7 @@ struct CacheEntry
 };
 
 
-static const gchar *file_type_pixmap_files[NUM_FILE_TYPE_PIXMAPS] = {
+static const gchar *file_type_pixmap_files[] = {
     "file-type-icons/file_type_regular.xpm",
     "file-type-icons/file_type_regular.xpm",
     "file-type-icons/file_type_dir.xpm",
@@ -54,6 +51,9 @@ static const gchar *file_type_pixmap_files[NUM_FILE_TYPE_PIXMAPS] = {
 };
 
 
+#define NUM_FILE_TYPE_PIXMAPS G_N_ELEMENTS(file_type_pixmap_files)
+
+
 static const gchar *pixmap_files[NUM_PIXMAPS] = {"",
                                                  "gnome_cmd_arrow_up.xpm",
                                                  "gnome_cmd_arrow_down.xpm",
@@ -99,21 +99,20 @@ void IMAGE_init ()
 
     for (gint i=1; i<NUM_PIXMAPS; i++)
     {
-        gchar *path = g_build_path (G_DIR_SEPARATOR_S, PIXMAPS_DIR, pixmap_files[i], NULL);
+        gchar *path = g_build_filename (PIXMAPS_DIR, pixmap_files[i], NULL);
 
         DEBUG ('i', "imageloader: loading pixmap: %s\n", path);
 
         pixmaps[i] = gnome_cmd_pixmap_new_from_file (path);
         if (!pixmaps[i])
         {
-            gchar *path2 = g_build_path (G_DIR_SEPARATOR_S, "../pixmaps", pixmap_files[i], NULL);
+            gchar *path2 = g_build_filename ("../pixmaps", pixmap_files[i], NULL);
 
-            warn_print (_("Couldn't load installed file type pixmap, trying to load from source-dir\n"));
-            warn_print (_("Trying to load %s instead\n"), path2);
+            g_warning (_("Couldn't load installed file type pixmap, trying to load %s instead"), path2);
 
             pixmaps[i] = gnome_cmd_pixmap_new_from_file (path2);
             if (!pixmaps[i])
-                warn_print (_("Can't find the pixmap anywhere. Make sure you have installed the program or is executing gnome-commander from the gnome-commander-%s/src directory\n"), VERSION);
+                g_warning (_("Can't find the pixmap anywhere. Make sure you have installed the program or is executing gnome-commander from the gnome-commander-%s/src directory"), VERSION);
 
             g_free (path2);
         }
@@ -126,19 +125,18 @@ void IMAGE_init ()
      for (gint i=0; i<NUM_FILE_TYPE_PIXMAPS; i++)
     {
         CacheEntry *e = &file_type_pixmaps[i];
-        gchar *path = g_build_path (G_DIR_SEPARATOR_S, PIXMAPS_DIR, file_type_pixmap_files[i], NULL);
+        gchar *path = g_build_filename (PIXMAPS_DIR, file_type_pixmap_files[i], NULL);
 
         DEBUG ('i', "imageloader: loading pixmap: %s\n", path);
 
         if (!load_icon (path, &e->pixmap, &e->mask, &e->lnk_pixmap, &e->lnk_mask))
         {
-            gchar *path2 = g_build_path (G_DIR_SEPARATOR_S, "../pixmaps", pixmap_files[i], NULL);
+            gchar *path2 = g_build_filename ("../pixmaps", pixmap_files[i], NULL);
 
-            warn_print (_("Couldn't load installed pixmap, trying to load from source-dir\n"));
-            warn_print (_("Trying to load %s instead\n"), path2);
+            g_warning (_("Couldn't load installed pixmap, trying to load %s instead"), path2);
 
             if (!load_icon (path2, &e->pixmap, &e->mask, &e->lnk_pixmap, &e->lnk_mask))
-                warn_print (_("Can't find the pixmap anywhere. Make sure you have installed the program or is executing gnome-commander from the gnome-commander-%s/src directory\n"), VERSION);
+                g_warning (_("Can't find the pixmap anywhere. Make sure you have installed the program or is executing gnome-commander from the gnome-commander-%s/src directory"), VERSION);
             g_free (path2);
         }
 
@@ -224,7 +222,7 @@ static const gchar *get_type_icon_name (GnomeVFSFileType type)
  */
 inline gchar *get_mime_file_type_icon_path (GnomeVFSFileType type, const gchar *icon_dir)
 {
-    return g_build_path (G_DIR_SEPARATOR_S, icon_dir, get_type_icon_name (type), NULL);
+    return g_build_filename (icon_dir, get_type_icon_name (type), NULL);
 }
 
 
@@ -236,7 +234,7 @@ inline gchar *get_mime_file_type_icon_path (GnomeVFSFileType type, const gchar *
 inline gchar *get_mime_document_type_icon_path (const gchar *mime_type, const gchar *icon_dir)
 {
     gchar *icon_name = get_mime_icon_name (mime_type);
-    gchar *icon_path = g_build_path (G_DIR_SEPARATOR_S, icon_dir, icon_name, NULL);
+    gchar *icon_path = g_build_filename (icon_dir, icon_name, NULL);
     g_free (icon_name);
 
     return icon_path;
@@ -252,7 +250,7 @@ inline gchar *get_category_icon_path (const gchar *mime_type, const gchar *icon_
 {
     for (gint i=0; i<G_N_ELEMENTS(categories); i++)
         if (g_str_has_prefix (mime_type, categories[i][0]))
-            return g_build_path (G_DIR_SEPARATOR_S, icon_dir, categories[i][1], NULL);
+            return g_build_filename (icon_dir, categories[i][1], NULL);
 
     return NULL;
 }
@@ -285,14 +283,14 @@ static gboolean load_icon (const gchar *icon_path, GdkPixmap **pm, GdkBitmap **b
 
 
     // Scale the pixmap if needed
-    h = gnome_cmd_data.icon_size;
+    h = gnome_cmd_data.options.icon_size;
     if (h != gdk_pixbuf_get_height (pixbuf))
     {
         scale = (gfloat)h/(gfloat)gdk_pixbuf_get_height (pixbuf);
         w = (gint)(scale*(gfloat)gdk_pixbuf_get_width (pixbuf));
 
-        GdkPixbuf *tmp = gdk_pixbuf_scale_simple (pixbuf, w, h, gnome_cmd_data.icon_scale_quality);
-        gdk_pixbuf_unref (pixbuf);
+        GdkPixbuf *tmp = gdk_pixbuf_scale_simple (pixbuf, w, h, gnome_cmd_data.options.icon_scale_quality);
+        g_object_unref (pixbuf);
         pixbuf = tmp;
     }
 
@@ -310,8 +308,8 @@ static gboolean load_icon (const gchar *icon_path, GdkPixmap **pm, GdkBitmap **b
 
     gdk_pixbuf_render_pixmap_and_mask (pixbuf, pm, bm, 128);
     gdk_pixbuf_render_pixmap_and_mask (lnk_pixbuf, lpm, lbm, 128);
-    gdk_pixbuf_unref (pixbuf);
-    gdk_pixbuf_unref (lnk_pixbuf);
+    g_object_unref (pixbuf);
+    g_object_unref (lnk_pixbuf);
 
     return TRUE;
 }
@@ -400,10 +398,10 @@ static gboolean get_mime_icon (GnomeVFSFileType type,
                                GdkPixmap **pixmap,
                                GdkBitmap **mask)
 {
-    if (get_mime_icon_in_dir (gnome_cmd_data_get_theme_icon_dir(), type, mime_type, symlink, pixmap, mask))
+    if (get_mime_icon_in_dir (gnome_cmd_data.options.theme_icon_dir, type, mime_type, symlink, pixmap, mask))
         return TRUE;
 
-    return get_mime_icon_in_dir (gnome_cmd_data_get_document_icon_dir(), type, mime_type, symlink, pixmap, mask);
+    return get_mime_icon_in_dir (gnome_cmd_data.options.document_icon_dir, type, mime_type, symlink, pixmap, mask);
 }
 
 
@@ -427,7 +425,7 @@ gboolean IMAGE_get_pixmap_and_mask (GnomeVFSFileType type,
                                     GdkPixmap **pixmap,
                                     GdkBitmap **mask)
 {
-    switch (gnome_cmd_data.layout)
+    switch (gnome_cmd_data.options.layout)
     {
         case GNOME_CMD_LAYOUT_TYPE_ICONS:
             return get_type_icon (type, symlink, pixmap, mask);
@@ -451,8 +449,8 @@ static gboolean remove_entry (const gchar *key, CacheEntry *entry, gpointer user
 
     if (!entry->dead_end)
     {
-        gdk_pixmap_unref (entry->pixmap);
-        gdk_bitmap_unref (entry->mask);
+        g_object_unref (entry->pixmap);
+        g_object_unref (entry->mask);
     }
 
     g_free (entry);
