@@ -50,13 +50,13 @@ inline void bch_free(GHashTable *bch)
 
 static void bch_set_value(GHashTable *bch, int key, int value)
 {
-    g_hash_table_insert(bch, (gpointer) key, (gpointer) value);
+    g_hash_table_insert (bch, (gpointer) key, (gpointer) value);
 }
 
 
 int bch_get_value(GViewerBMChartypeData *data, char_type key, int default_value)
 {
-    gint value = GPOINTER_TO_INT (g_hash_table_lookup(data->bad, GINT_TO_POINTER (CHARTYPE_CASE(key, data->case_sensitive))));
+    gint value = GPOINTER_TO_INT (g_hash_table_lookup (data->bad, GINT_TO_POINTER (CHARTYPE_CASE(key, data->case_sensitive))));
 
     return value==0 ? default_value : value;
 }
@@ -98,7 +98,7 @@ inline void suffices(char_type *pattern, int m, gboolean case_sens, int *suff)
 
 static void goodsuff_compute(char_type *pattern, int m, gboolean case_sens, /*out*/ int *good)
 {
-   int *suff = g_new0(int, m);
+   int *suff = g_new0 (int, m);
    int j;
 
    suffices(pattern, m, case_sens, suff);
@@ -120,18 +120,18 @@ static void goodsuff_compute(char_type *pattern, int m, gboolean case_sens, /*ou
 
 GViewerBMChartypeData *create_bm_chartype_data(const gchar *pattern, gboolean case_sensitive)
 {
-    GViewerBMChartypeData *data = g_new0(GViewerBMChartypeData, 1);
+    GViewerBMChartypeData *data = g_new0 (GViewerBMChartypeData, 1);
 
     data->case_sensitive = case_sensitive;
 
-    data->pattern = convert_utf8_to_chartype_array(pattern, &data->pattern_len);
+    data->pattern = convert_utf8_to_chartype_array(pattern, data->pattern_len);
     if (!data->pattern)
         goto error;
 
     data->bad = bch_create();
     bch_compute(data->bad, data->pattern, data->pattern_len, case_sensitive);
 
-    data->good = g_new0(int, data->pattern_len);
+    data->good = g_new0 (int, data->pattern_len);
     goodsuff_compute(data->pattern, data->pattern_len, case_sensitive, data->good);
 
     return data;
@@ -144,7 +144,7 @@ error:
 
 void free_bm_chartype_data(GViewerBMChartypeData*data)
 {
-    if (data==NULL)
+    if (!data)
         return;
 
     g_free (data->good);
