@@ -44,7 +44,9 @@
 using namespace std;
 
 
-static GtkWidgetClass *parent_class = NULL;
+#define IMAGE_RENDER_DEFAULT_WIDTH      100
+#define IMAGE_RENDER_DEFAULT_HEIGHT     200
+
 
 enum {
   IMAGE_STATUS_CHANGED,
@@ -54,8 +56,14 @@ enum {
 static guint image_render_signals[LAST_SIGNAL] = { 0 };
 
 
+struct ImageRenderClass
+{
+    GtkWidgetClass parent_class;
+    void (*image_status_changed)  (ImageRender *obj, ImageRender::Status *status);
+};
+
 // Class Private Data
-struct ImageRenderPrivate
+struct ImageRender::Private
 {
     guint8 button; // The button pressed in "button_press_event"
 
@@ -82,11 +90,11 @@ struct ImageRenderPrivate
     gint        orig_pixbuf_loaded;
 };
 
-// Gtk class related static functions
-static void image_render_init (ImageRender *w);
-static void image_render_class_init (ImageRenderClass *klass);
-static void image_render_destroy (GtkObject *object);
 
+G_DEFINE_TYPE (ImageRender, image_render, GTK_TYPE_WIDGET)
+
+
+// Gtk class related static functions
 static void image_render_redraw (ImageRender *w);
 
 static gboolean image_render_key_press (GtkWidget *widget, GdkEventKey *event);
@@ -117,60 +125,30 @@ static void image_render_update_adjustments (ImageRender *obj);
     public functions
     (defined in the header file)
 *****************************************/
-GtkType image_render_get_type ()
-{
-    static GtkType type = 0;
-    if (type == 0)
-    {
-        GtkTypeInfo info =
-        {
-            "ImageRender",
-            sizeof (ImageRender),
-            sizeof (ImageRenderClass),
-            (GtkClassInitFunc) image_render_class_init,
-            (GtkObjectInitFunc) image_render_init,
-            /* reserved_1 */ NULL,
-            /* reserved_2 */ NULL,
-            (GtkClassInitFunc) NULL
-        };
-        type = gtk_type_unique (gtk_widget_get_type(), &info);
-    }
-    return type;
-}
-
-
-GtkWidget *image_render_new ()
-{
-    ImageRender *w = (ImageRender *) gtk_type_new (image_render_get_type ());
-
-    return GTK_WIDGET (w);
-}
-
-
 void image_render_set_h_adjustment (ImageRender *obj, GtkAdjustment *adjustment)
 {
-    g_return_if_fail (obj != NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
     if (obj->priv->h_adjustment)
     {
-        gtk_signal_disconnect_by_data (GTK_OBJECT (obj->priv->h_adjustment), (gpointer) obj);
+        g_signal_handlers_disconnect_matched (obj->priv->h_adjustment, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, obj);
         g_object_unref (obj->priv->h_adjustment);
     }
 
     obj->priv->h_adjustment = adjustment;
-    gtk_object_ref (GTK_OBJECT (obj->priv->h_adjustment));
+    g_object_ref (obj->priv->h_adjustment);
 
-    gtk_signal_connect (GTK_OBJECT (adjustment), "changed",
-              (GtkSignalFunc) image_render_h_adjustment_changed ,
-              (gpointer) obj);
-    gtk_signal_connect (GTK_OBJECT (adjustment), "value-changed",
-              (GtkSignalFunc) image_render_h_adjustment_value_changed ,
-              (gpointer) obj);
+    g_signal_connect (adjustment, "changed", G_CALLBACK (image_render_h_adjustment_changed), obj);
+    g_signal_connect (adjustment, "value-changed", G_CALLBACK (image_render_h_adjustment_value_changed), obj);
 
-    obj->priv->old_h_adj_value = adjustment->value;
+    obj->priv->old_h_adj_value = gtk_adjustment_get_value (adjustment);
+#if GTK_CHECK_VERSION (2, 14, 0)
+    obj->priv->old_h_adj_lower = gtk_adjustment_get_lower (adjustment);
+    obj->priv->old_h_adj_upper = gtk_adjustment_get_upper (adjustment);
+#else
     obj->priv->old_h_adj_lower = adjustment->lower;
     obj->priv->old_h_adj_upper = adjustment->upper;
+#endif
 
     image_render_h_adjustment_update (obj);
 }
@@ -178,69 +156,36 @@ void image_render_set_h_adjustment (ImageRender *obj, GtkAdjustment *adjustment)
 
 void image_render_set_v_adjustment (ImageRender *obj, GtkAdjustment *adjustment)
 {
-    g_return_if_fail (obj != NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
     if (obj->priv->v_adjustment)
     {
-        gtk_signal_disconnect_by_data (GTK_OBJECT (obj->priv->v_adjustment), (gpointer) obj);
+        g_signal_handlers_disconnect_matched (obj->priv->v_adjustment, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, obj);
         g_object_unref (obj->priv->v_adjustment);
     }
 
     obj->priv->v_adjustment = adjustment;
-    gtk_object_ref (GTK_OBJECT (obj->priv->v_adjustment));
+    g_object_ref (obj->priv->v_adjustment);
 
-    gtk_signal_connect (GTK_OBJECT (adjustment), "changed",
-              (GtkSignalFunc) image_render_v_adjustment_changed ,
-              (gpointer) obj);
-    gtk_signal_connect (GTK_OBJECT (adjustment), "value-changed",
-              (GtkSignalFunc) image_render_v_adjustment_value_changed ,
-              (gpointer) obj);
+    g_signal_connect (adjustment, "changed", G_CALLBACK (image_render_v_adjustment_changed), obj);
+    g_signal_connect (adjustment, "value-changed",  G_CALLBACK (image_render_v_adjustment_value_changed), obj);
 
-    obj->priv->old_v_adj_value = adjustment->value;
+    obj->priv->old_v_adj_value = gtk_adjustment_get_value (adjustment);
+#if GTK_CHECK_VERSION (2, 14, 0)
+    obj->priv->old_v_adj_lower = gtk_adjustment_get_lower (adjustment);
+    obj->priv->old_v_adj_upper = gtk_adjustment_get_upper (adjustment);
+#else
     obj->priv->old_v_adj_lower = adjustment->lower;
     obj->priv->old_v_adj_upper = adjustment->upper;
+#endif
 
     image_render_v_adjustment_update (obj);
 }
 
 
-static void image_render_class_init (ImageRenderClass *klass)
-{
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-
-    parent_class = (GtkWidgetClass *) gtk_type_class (gtk_widget_get_type ());
-
-    object_class->destroy = image_render_destroy;
-
-    widget_class->key_press_event = image_render_key_press;
-    widget_class->button_press_event = image_render_button_press;
-    widget_class->button_release_event = image_render_button_release;
-    widget_class->motion_notify_event = image_render_motion_notify;
-
-    widget_class->expose_event = image_render_expose;
-
-    widget_class->size_request = image_render_size_request;
-    widget_class->size_allocate = image_render_size_allocate;
-
-    widget_class->realize = image_render_realize;
-
-    image_render_signals[IMAGE_STATUS_CHANGED] =
-        gtk_signal_new ("image-status-changed",
-            GTK_RUN_LAST,
-            G_OBJECT_CLASS_TYPE (object_class),
-            GTK_SIGNAL_OFFSET (ImageRenderClass, image_status_changed),
-            gtk_marshal_NONE__POINTER,
-            GTK_TYPE_NONE,
-            1, GTK_TYPE_POINTER);
-
-}
-
-
 static void image_render_init (ImageRender *w)
 {
-    w->priv = g_new0(ImageRenderPrivate, 1);
+    w->priv = g_new0 (ImageRender::Private, 1);
 
     w->priv->button = 0;
 
@@ -262,15 +207,12 @@ static void image_render_init (ImageRender *w)
     w->priv->orig_pixbuf = NULL;
     w->priv->disp_pixbuf = NULL;
 
-    GTK_WIDGET_SET_FLAGS(GTK_WIDGET (w), GTK_CAN_FOCUS);
+    GTK_WIDGET_SET_FLAGS (GTK_WIDGET (w), GTK_CAN_FOCUS);
 }
 
 
-static void image_render_destroy (GtkObject *object)
+static void image_render_finalize (GObject *object)
 {
-    g_return_if_fail (object != NULL);
-    g_return_if_fail (IS_IMAGE_RENDER (object));
-
     ImageRender *w = IMAGE_RENDER (object);
 
     if (w->priv)
@@ -295,28 +237,54 @@ static void image_render_destroy (GtkObject *object)
 
             if (w->priv->v_adjustment)
                 g_object_unref (w->priv->v_adjustment);
-            w->priv->v_adjustment = NULL;
 
             if (w->priv->h_adjustment)
                 g_object_unref (w->priv->h_adjustment);
-            w->priv->h_adjustment = NULL;
 
             g_free (w->priv);
-            w->priv = NULL;
         }
     }
 
-    if (GTK_OBJECT_CLASS(parent_class)->destroy)
-        (*GTK_OBJECT_CLASS(parent_class)->destroy) (object);
+    G_OBJECT_CLASS (image_render_parent_class)->finalize (object);
+}
+
+
+static void image_render_class_init (ImageRenderClass *klass)
+{
+    GObjectClass *object_class = G_OBJECT_CLASS (klass);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
+
+    object_class->finalize = image_render_finalize;
+
+    widget_class->key_press_event = image_render_key_press;
+    widget_class->button_press_event = image_render_button_press;
+    widget_class->button_release_event = image_render_button_release;
+    widget_class->motion_notify_event = image_render_motion_notify;
+
+    widget_class->expose_event = image_render_expose;
+
+    widget_class->size_request = image_render_size_request;
+    widget_class->size_allocate = image_render_size_allocate;
+
+    widget_class->realize = image_render_realize;
+
+    image_render_signals[IMAGE_STATUS_CHANGED] =
+        g_signal_new ("image-status-changed",
+            G_TYPE_FROM_CLASS (klass),
+            G_SIGNAL_RUN_LAST,
+            G_STRUCT_OFFSET (ImageRenderClass, image_status_changed),
+            NULL, NULL,
+            g_cclosure_marshal_VOID__POINTER,
+            G_TYPE_NONE,
+            1, G_TYPE_POINTER);
 }
 
 
 void image_render_notify_status_changed (ImageRender *w)
 {
-    g_return_if_fail (w!= NULL);
     g_return_if_fail (IS_IMAGE_RENDER (w));
 
-    ImageRenderStatus stat;
+    ImageRender::Status stat;
 
     memset(&stat, 0, sizeof(stat));
 
@@ -330,7 +298,7 @@ void image_render_notify_status_changed (ImageRender *w)
         stat.bits_per_sample = gdk_pixbuf_get_bits_per_sample(w->priv->orig_pixbuf);
     }
 
-    gtk_signal_emit (GTK_OBJECT(w), image_render_signals[IMAGE_STATUS_CHANGED], &stat);
+    g_signal_emit (w, image_render_signals[IMAGE_STATUS_CHANGED], 0, &stat);
 }
 
 
@@ -342,7 +310,6 @@ static gboolean image_render_key_press (GtkWidget *widget, GdkEventKey *event)
 
 static void image_render_realize (GtkWidget *widget)
 {
-    g_return_if_fail (widget != NULL);
     g_return_if_fail (IS_IMAGE_RENDER (widget));
 
     GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
@@ -364,13 +331,16 @@ static void image_render_realize (GtkWidget *widget)
     attributes.colormap = gtk_widget_get_colormap (widget);
 
     gint attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
-    widget->window = gdk_window_new (widget->parent->window, &attributes, attributes_mask);
 
-    widget->style = gtk_style_attach (widget->style, widget->window);
-
-    gdk_window_set_user_data (widget->window, widget);
-
-    gtk_style_set_background (widget->style, widget->window, GTK_STATE_ACTIVE);
+    GdkWindow *window = gdk_window_new (widget->parent->window, &attributes, attributes_mask);
+#if GTK_CHECK_VERSION (2,18,0)
+    gtk_widget_set_window (widget, window);
+#else
+    widget->window = window;
+#endif
+    widget->style = gtk_style_attach (widget->style, window);
+    gdk_window_set_user_data (window, widget);
+    gtk_style_set_background (widget->style, window, GTK_STATE_ACTIVE);
 
     // image_render_prepare_disp_pixbuf (obj);
     if (!obj->priv->scaled_pixbuf_loaded)
@@ -384,7 +354,11 @@ static void image_render_redraw (ImageRender *w)
         return;
 
     image_render_notify_status_changed (w);
+#if GTK_CHECK_VERSION (2,14,0)
+    gdk_window_invalidate_rect (gtk_widget_get_window (GTK_WIDGET (w)), NULL, FALSE);
+#else
     gdk_window_invalidate_rect (GTK_WIDGET (w)->window, NULL, FALSE);
+#endif
 }
 
 
@@ -397,7 +371,6 @@ static void image_render_size_request (GtkWidget *widget, GtkRequisition *requis
 
 static void image_render_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 {
-    g_return_if_fail (widget != NULL);
     g_return_if_fail (IS_IMAGE_RENDER (widget));
     g_return_if_fail (allocation != NULL);
 
@@ -405,8 +378,11 @@ static void image_render_size_allocate (GtkWidget *widget, GtkAllocation *alloca
 
     if (GTK_WIDGET_REALIZED (widget))
     {
+#if GTK_CHECK_VERSION (2,14,0)
+        gdk_window_move_resize (gtk_widget_get_window (widget), allocation->x, allocation->y, allocation->width, allocation->height);
+#else
         gdk_window_move_resize (widget->window, allocation->x, allocation->y, allocation->width, allocation->height);
-
+#endif
         image_render_prepare_disp_pixbuf (IMAGE_RENDER (widget));
     }
 }
@@ -414,7 +390,6 @@ static void image_render_size_allocate (GtkWidget *widget, GtkAllocation *alloca
 
 static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
 {
-    g_return_val_if_fail (widget != NULL, FALSE);
     g_return_val_if_fail (IS_IMAGE_RENDER (widget), FALSE);
     g_return_val_if_fail (event != NULL, FALSE);
 
@@ -423,7 +398,11 @@ static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
 
     ImageRender *w = IMAGE_RENDER (widget);
 
+#if GTK_CHECK_VERSION (2,14,0)
+    gdk_window_clear_area (gtk_widget_get_window (widget), 0, 0, widget->allocation.width, widget->allocation.height);
+#else
     gdk_window_clear_area (widget->window, 0, 0, widget->allocation.width, widget->allocation.height);
+#endif
 
     if (!w->priv->disp_pixbuf)
         return FALSE;
@@ -431,13 +410,17 @@ static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
     gint xc, yc;
 
     if (w->priv->best_fit ||
-        (gdk_pixbuf_get_width(w->priv->disp_pixbuf) < widget->allocation.width &&
-         gdk_pixbuf_get_height(w->priv->disp_pixbuf) < widget->allocation.height))
+        (gdk_pixbuf_get_width (w->priv->disp_pixbuf) < widget->allocation.width &&
+         gdk_pixbuf_get_height (w->priv->disp_pixbuf) < widget->allocation.height))
     {
-        xc = widget->allocation.width / 2 - gdk_pixbuf_get_width(w->priv->disp_pixbuf)/2;
-        yc = widget->allocation.height / 2 - gdk_pixbuf_get_height(w->priv->disp_pixbuf)/2;
+        xc = widget->allocation.width / 2 - gdk_pixbuf_get_width (w->priv->disp_pixbuf)/2;
+        yc = widget->allocation.height / 2 - gdk_pixbuf_get_height (w->priv->disp_pixbuf)/2;
 
-        gdk_draw_pixbuf(widget->window,
+#if GTK_CHECK_VERSION (2,14,0)
+        gdk_draw_pixbuf (gtk_widget_get_window (widget),
+#else
+        gdk_draw_pixbuf (widget->window,
+#endif
                 NULL,
                 w->priv->disp_pixbuf,
                 0, 0, // source X, Y
@@ -451,36 +434,36 @@ static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
         gint dst_x, dst_y;
         gint width, height;
 
-        if (widget->allocation.width > gdk_pixbuf_get_width(w->priv->disp_pixbuf))
+        if (widget->allocation.width > gdk_pixbuf_get_width (w->priv->disp_pixbuf))
         {
             src_x = 0;
-            dst_x = widget->allocation.width / 2 - gdk_pixbuf_get_width(w->priv->disp_pixbuf)/2;
-            width = gdk_pixbuf_get_width(w->priv->disp_pixbuf);
+            dst_x = widget->allocation.width / 2 - gdk_pixbuf_get_width (w->priv->disp_pixbuf)/2;
+            width = gdk_pixbuf_get_width (w->priv->disp_pixbuf);
         }
         else
         {
-            src_x = (int)w->priv->h_adjustment->value;
+            src_x = (int) gtk_adjustment_get_value (w->priv->h_adjustment);
             dst_x = 0;
-            width = MIN(widget->allocation.width, gdk_pixbuf_get_width(w->priv->disp_pixbuf));
-            if (src_x + width > gdk_pixbuf_get_width(w->priv->disp_pixbuf))
-                src_x = gdk_pixbuf_get_width(w->priv->disp_pixbuf) - width;
+            width = MIN(widget->allocation.width, gdk_pixbuf_get_width (w->priv->disp_pixbuf));
+            if (src_x + width > gdk_pixbuf_get_width (w->priv->disp_pixbuf))
+                src_x = gdk_pixbuf_get_width (w->priv->disp_pixbuf) - width;
         }
 
 
-        if ((int)w->priv->h_adjustment->value > gdk_pixbuf_get_height(w->priv->disp_pixbuf))
+        if ((int) gtk_adjustment_get_value (w->priv->h_adjustment) > gdk_pixbuf_get_height (w->priv->disp_pixbuf))
         {
             src_y = 0;
-            dst_y = widget->allocation.height / 2 - gdk_pixbuf_get_height(w->priv->disp_pixbuf)/2;
-            height = gdk_pixbuf_get_height(w->priv->disp_pixbuf);
+            dst_y = widget->allocation.height / 2 - gdk_pixbuf_get_height (w->priv->disp_pixbuf)/2;
+            height = gdk_pixbuf_get_height (w->priv->disp_pixbuf);
         }
         else
         {
-            src_y = (int)w->priv->v_adjustment->value;
+            src_y = (int) gtk_adjustment_get_value (w->priv->v_adjustment);
             dst_y = 0;
-            height = MIN(widget->allocation.height, gdk_pixbuf_get_height(w->priv->disp_pixbuf));
+            height = MIN(widget->allocation.height, gdk_pixbuf_get_height (w->priv->disp_pixbuf));
 
-            if (src_y + height > gdk_pixbuf_get_height(w->priv->disp_pixbuf))
-                src_y = gdk_pixbuf_get_height(w->priv->disp_pixbuf) - height;
+            if (src_y + height > gdk_pixbuf_get_height (w->priv->disp_pixbuf))
+                src_y = gdk_pixbuf_get_height (w->priv->disp_pixbuf) - height;
         }
 
 #if 0
@@ -488,14 +471,18 @@ static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
                 src_x, src_y,
                 dst_x, dst_y,
                 width, height,
-                gdk_pixbuf_get_width(w->priv->disp_pixbuf),
-                gdk_pixbuf_get_height(w->priv->disp_pixbuf),
+                gdk_pixbuf_get_width (w->priv->disp_pixbuf),
+                gdk_pixbuf_get_height (w->priv->disp_pixbuf),
                 widget->allocation.width,
                 widget->allocation.height,
                 (int)w->priv->h_adjustment->value,
                 (int)w->priv->v_adjustment->value);
 #endif
+#if GTK_CHECK_VERSION (2,14,0)
+        gdk_draw_pixbuf(gtk_widget_get_window (widget),
+#else
         gdk_draw_pixbuf(widget->window,
+#endif
                         NULL,
                         w->priv->disp_pixbuf,
                         src_x, src_y,
@@ -512,7 +499,6 @@ static gboolean image_render_expose (GtkWidget *widget, GdkEventExpose *event)
 
 static gboolean image_render_button_press (GtkWidget *widget, GdkEventButton *event)
 {
-    g_return_val_if_fail (widget != NULL, FALSE);
     g_return_val_if_fail (IS_IMAGE_RENDER (widget), FALSE);
     g_return_val_if_fail (event != NULL, FALSE);
 
@@ -534,7 +520,6 @@ static gboolean image_render_button_press (GtkWidget *widget, GdkEventButton *ev
 
 static gboolean image_render_button_release (GtkWidget *widget, GdkEventButton *event)
 {
-    g_return_val_if_fail (widget != NULL, FALSE);
     g_return_val_if_fail (IS_IMAGE_RENDER (widget), FALSE);
     g_return_val_if_fail (event != NULL, FALSE);
 
@@ -553,7 +538,6 @@ static gboolean image_render_button_release (GtkWidget *widget, GdkEventButton *
 
 static gboolean image_render_motion_notify (GtkWidget *widget, GdkEventMotion *event)
 {
-    g_return_val_if_fail (widget != NULL, FALSE);
     g_return_val_if_fail (IS_IMAGE_RENDER (widget), FALSE);
     g_return_val_if_fail (event != NULL, FALSE);
 
@@ -566,9 +550,15 @@ static gboolean image_render_motion_notify (GtkWidget *widget, GdkEventMotion *e
         gint x = event->x;
         gint y = event->y;
 
+#if GTK_CHECK_VERSION (2,14,0)
+        GdkWindow *window = gtk_widget_get_window (widget);
+
+        if (event->is_hint || (event->window != window))
+            gdk_window_get_pointer (window, &x, &y, &mods);
+#else
         if (event->is_hint || (event->window != widget->window))
             gdk_window_get_pointer (widget->window, &x, &y, &mods);
-
+#endif
         // TODO: respond to motion event
     }
 
@@ -578,20 +568,27 @@ static gboolean image_render_motion_notify (GtkWidget *widget, GdkEventMotion *e
 
 static void image_render_h_adjustment_update (ImageRender *obj)
 {
-    g_return_if_fail (obj != NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
-    gfloat new_value = obj->priv->h_adjustment->value;
+    gfloat new_value = gtk_adjustment_get_value (obj->priv->h_adjustment);
 
+#if GTK_CHECK_VERSION (2,14,0)
+    if (new_value < gtk_adjustment_get_lower (obj->priv->h_adjustment))
+        new_value = gtk_adjustment_get_lower (obj->priv->h_adjustment);
+
+    if (new_value > gtk_adjustment_get_upper (obj->priv->h_adjustment))
+        new_value = gtk_adjustment_get_upper (obj->priv->h_adjustment);
+#else
     if (new_value < obj->priv->h_adjustment->lower)
         new_value = obj->priv->h_adjustment->lower;
 
     if (new_value > obj->priv->h_adjustment->upper)
         new_value = obj->priv->h_adjustment->upper;
+#endif
 
-    if (new_value != obj->priv->h_adjustment->value)
+    if (new_value != gtk_adjustment_get_value (obj->priv->h_adjustment))
     {
-        obj->priv->h_adjustment->value = new_value;
+        gtk_adjustment_set_value (obj->priv->h_adjustment, new_value);
         gtk_signal_emit_by_name (GTK_OBJECT (obj->priv->h_adjustment), "value-changed");
     }
 
@@ -609,6 +606,18 @@ static void image_render_h_adjustment_changed (GtkAdjustment *adjustment, gpoint
 
     ImageRender *obj = IMAGE_RENDER (data);
 
+#if GTK_CHECK_VERSION (2,14,0)
+    if ((obj->priv->old_h_adj_value != gtk_adjustment_get_value (adjustment)) ||
+        (obj->priv->old_h_adj_lower != gtk_adjustment_get_lower (adjustment)) ||
+        (obj->priv->old_h_adj_upper != gtk_adjustment_get_upper (adjustment)))
+    {
+        image_render_h_adjustment_update (obj);
+
+        obj->priv->old_h_adj_value = gtk_adjustment_get_value (adjustment);
+        obj->priv->old_h_adj_lower = gtk_adjustment_get_lower (adjustment);
+        obj->priv->old_h_adj_upper = gtk_adjustment_get_upper (adjustment);
+    }
+#else
     if ((obj->priv->old_h_adj_value != adjustment->value) ||
         (obj->priv->old_h_adj_lower != adjustment->lower) ||
         (obj->priv->old_h_adj_upper != adjustment->upper))
@@ -619,6 +628,7 @@ static void image_render_h_adjustment_changed (GtkAdjustment *adjustment, gpoint
         obj->priv->old_h_adj_lower = adjustment->lower;
         obj->priv->old_h_adj_upper = adjustment->upper;
     }
+#endif
 }
 
 
@@ -629,30 +639,37 @@ static void image_render_h_adjustment_value_changed (GtkAdjustment *adjustment,
 
     ImageRender *obj = IMAGE_RENDER (data);
 
-    if (obj->priv->old_h_adj_value != adjustment->value)
+    if (obj->priv->old_h_adj_value != gtk_adjustment_get_value (adjustment))
     {
         image_render_h_adjustment_update (obj);
-        obj->priv->old_h_adj_value = adjustment->value;
+        obj->priv->old_h_adj_value = gtk_adjustment_get_value (adjustment);
     }
 }
 
 
 static void image_render_v_adjustment_update (ImageRender *obj)
 {
-    g_return_if_fail (obj != NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
-    gfloat new_value = obj->priv->v_adjustment->value;
+    gfloat new_value = gtk_adjustment_get_value (obj->priv->v_adjustment);
 
+#if GTK_CHECK_VERSION (2,14,0)
+    if (new_value < gtk_adjustment_get_lower (obj->priv->v_adjustment))
+        new_value = gtk_adjustment_get_lower (obj->priv->v_adjustment);
+
+    if (new_value > gtk_adjustment_get_upper (obj->priv->v_adjustment))
+        new_value = gtk_adjustment_get_upper (obj->priv->v_adjustment);
+#else
     if (new_value < obj->priv->v_adjustment->lower)
         new_value = obj->priv->v_adjustment->lower;
 
     if (new_value > obj->priv->v_adjustment->upper)
         new_value = obj->priv->v_adjustment->upper;
+#endif
 
-    if (new_value != obj->priv->v_adjustment->value)
+    if (new_value != gtk_adjustment_get_value (obj->priv->v_adjustment))
     {
-        obj->priv->v_adjustment->value = new_value;
+        gtk_adjustment_set_value (obj->priv->v_adjustment, new_value);
         gtk_signal_emit_by_name (GTK_OBJECT (obj->priv->v_adjustment), "value-changed");
     }
 
@@ -670,6 +687,18 @@ static void image_render_v_adjustment_changed (GtkAdjustment *adjustment, gpoint
 
     ImageRender *obj = IMAGE_RENDER (data);
 
+#if GTK_CHECK_VERSION (2,14,0)
+    if ((obj->priv->old_v_adj_value != gtk_adjustment_get_value (adjustment)) ||
+        (obj->priv->old_v_adj_lower != gtk_adjustment_get_lower (adjustment)) ||
+        (obj->priv->old_v_adj_upper != gtk_adjustment_get_upper (adjustment)))
+    {
+        image_render_v_adjustment_update (obj);
+
+        obj->priv->old_v_adj_value = gtk_adjustment_get_value (adjustment);
+        obj->priv->old_v_adj_lower = gtk_adjustment_get_lower (adjustment);
+        obj->priv->old_v_adj_upper = gtk_adjustment_get_upper (adjustment);
+    }
+#else
     if ((obj->priv->old_v_adj_value != adjustment->value) ||
         (obj->priv->old_v_adj_lower != adjustment->lower) ||
         (obj->priv->old_v_adj_upper != adjustment->upper))
@@ -680,6 +709,7 @@ static void image_render_v_adjustment_changed (GtkAdjustment *adjustment, gpoint
         obj->priv->old_v_adj_lower = adjustment->lower;
         obj->priv->old_v_adj_upper = adjustment->upper;
     }
+#endif
 }
 
 
@@ -690,17 +720,16 @@ static void image_render_v_adjustment_value_changed (GtkAdjustment *adjustment,
 
     ImageRender *obj = IMAGE_RENDER (data);
 
-    if (obj->priv->old_v_adj_value != adjustment->value)
+    if (obj->priv->old_v_adj_value != gtk_adjustment_get_value (adjustment))
     {
         image_render_v_adjustment_update (obj);
-        obj->priv->old_v_adj_value = adjustment->value;
+        obj->priv->old_v_adj_value = gtk_adjustment_get_value (adjustment);
     }
 }
 
 
 static void image_render_free_pixbuf (ImageRender *obj)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
     image_render_wait_for_loader_thread (obj);
@@ -709,11 +738,11 @@ static void image_render_free_pixbuf (ImageRender *obj)
     obj->priv->scaled_pixbuf_loaded = FALSE;
 
     if (obj->priv->orig_pixbuf)
-        g_object_unref (G_OBJECT (obj->priv->orig_pixbuf));
+        g_object_unref (obj->priv->orig_pixbuf);
     obj->priv->orig_pixbuf = NULL;
 
     if (obj->priv->disp_pixbuf)
-        g_object_unref (G_OBJECT (obj->priv->disp_pixbuf));
+        g_object_unref (obj->priv->disp_pixbuf);
     obj->priv->disp_pixbuf = NULL;
 
     g_free (obj->priv->filename);
@@ -721,16 +750,15 @@ static void image_render_free_pixbuf (ImageRender *obj)
 }
 
 
-static gpointer image_render_pixbuf_loading_thread (gpointer data)
+static gpointer image_render_pixbuf_loading_thread (ImageRender *obj)
 {
     GError *err = NULL;
-    ImageRender *obj = (ImageRender *) data;
 
-    obj->priv->orig_pixbuf = gdk_pixbuf_new_from_file(obj->priv->filename, &err);
+    obj->priv->orig_pixbuf = gdk_pixbuf_new_from_file (obj->priv->filename, &err);
 
     g_atomic_int_inc (&obj->priv->orig_pixbuf_loaded);
 
-    g_object_unref (G_OBJECT (obj));
+    g_object_unref (obj);
 
     return NULL;
 }
@@ -738,10 +766,9 @@ static gpointer image_render_pixbuf_loading_thread (gpointer data)
 
 inline void image_render_wait_for_loader_thread (ImageRender *obj)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER (obj));
 
-    if (obj->priv->pixbuf_loading_thread !=NULL)
+    if (obj->priv->pixbuf_loading_thread)
     {
         /*
             ugly hack: use a busy wait loop, until the loader thread is done.
@@ -762,7 +789,6 @@ inline void image_render_wait_for_loader_thread (ImageRender *obj)
 
 void image_render_load_scaled_pixbuf (ImageRender *obj)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
     g_return_if_fail (obj->priv->filename!=NULL);
     g_return_if_fail (obj->priv->scaled_pixbuf_loaded==FALSE);
@@ -774,12 +800,12 @@ void image_render_load_scaled_pixbuf (ImageRender *obj)
 
     GError *err = NULL;
 
-    obj->priv->disp_pixbuf  = gdk_pixbuf_new_from_file_at_scale(obj->priv->filename, width, height, TRUE, &err);
+    obj->priv->disp_pixbuf  = gdk_pixbuf_new_from_file_at_scale (obj->priv->filename, width, height, TRUE, &err);
 
     if (err)
     {
-        g_warning("pixbuf loading failed: %s", err->message);
-        g_error_free(err);
+        g_warning ("pixbuf loading failed: %s", err->message);
+        g_error_free (err);
         obj->priv->orig_pixbuf = NULL;
         obj->priv->disp_pixbuf = NULL;
         return;
@@ -791,7 +817,6 @@ void image_render_load_scaled_pixbuf (ImageRender *obj)
 
 inline void image_render_start_background_pixbuf_loading (ImageRender *obj)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER (obj));
     g_return_if_fail (obj->priv->filename!=NULL);
 
@@ -801,14 +826,13 @@ inline void image_render_start_background_pixbuf_loading (ImageRender *obj)
     obj->priv->orig_pixbuf_loaded = 0;
 
     // Start background loading
-    g_object_ref (G_OBJECT (obj));
-    obj->priv->pixbuf_loading_thread = g_thread_create(image_render_pixbuf_loading_thread, (gpointer) obj, FALSE, NULL);
+    g_object_ref (obj);
+    obj->priv->pixbuf_loading_thread = g_thread_create((GThreadFunc) image_render_pixbuf_loading_thread, (gpointer) obj, FALSE, NULL);
 }
 
 
 void image_render_load_file (ImageRender *obj, const gchar *filename)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
     image_render_free_pixbuf (obj);
@@ -823,7 +847,6 @@ void image_render_load_file (ImageRender *obj, const gchar *filename)
 
 static void image_render_prepare_disp_pixbuf (ImageRender *obj)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
     // this will be set only if the loader thread finished loading the big pixbuf
@@ -834,35 +857,35 @@ static void image_render_prepare_disp_pixbuf (ImageRender *obj)
         return;
 
     if (obj->priv->disp_pixbuf)
-        g_object_unref (G_OBJECT (obj->priv->disp_pixbuf));
+        g_object_unref (obj->priv->disp_pixbuf);
     obj->priv->disp_pixbuf = NULL;
 
-    if (gdk_pixbuf_get_height(obj->priv->orig_pixbuf)==0)
+    if (gdk_pixbuf_get_height (obj->priv->orig_pixbuf)==0)
         return;
 
     if (obj->priv->best_fit)
     {
-        if (gdk_pixbuf_get_height(obj->priv->orig_pixbuf) < GTK_WIDGET (obj)->allocation.height &&
-            gdk_pixbuf_get_width(obj->priv->orig_pixbuf) < GTK_WIDGET (obj)->allocation.width)
+        if (gdk_pixbuf_get_height (obj->priv->orig_pixbuf) < GTK_WIDGET (obj)->allocation.height &&
+            gdk_pixbuf_get_width (obj->priv->orig_pixbuf) < GTK_WIDGET (obj)->allocation.width)
         {
             // no need to scale down
 
             obj->priv->disp_pixbuf = obj->priv->orig_pixbuf;
-            g_object_ref (G_OBJECT (obj->priv->disp_pixbuf));
+            g_object_ref (obj->priv->disp_pixbuf);
             return;
         }
 
         int height = GTK_WIDGET (obj)->allocation.height;
         int width = (((double) GTK_WIDGET (obj)->allocation.height) /
-                  gdk_pixbuf_get_height(obj->priv->orig_pixbuf))*
-                    gdk_pixbuf_get_width(obj->priv->orig_pixbuf);
+                  gdk_pixbuf_get_height (obj->priv->orig_pixbuf))*
+                    gdk_pixbuf_get_width (obj->priv->orig_pixbuf);
 
         if (width >= GTK_WIDGET (obj)->allocation.width)
         {
             width = GTK_WIDGET (obj)->allocation.width;
             height = (((double)GTK_WIDGET (obj)->allocation.width) /
-                  gdk_pixbuf_get_width(obj->priv->orig_pixbuf))*
-                    gdk_pixbuf_get_height(obj->priv->orig_pixbuf);
+                  gdk_pixbuf_get_width (obj->priv->orig_pixbuf))*
+                    gdk_pixbuf_get_height (obj->priv->orig_pixbuf);
         }
 
         if (width<=1 || height<=1)
@@ -878,8 +901,8 @@ static void image_render_prepare_disp_pixbuf (ImageRender *obj)
         // not "best_fit" = scaling mode
         obj->priv->disp_pixbuf = gdk_pixbuf_scale_simple(
                 obj->priv->orig_pixbuf,
-                (int)(gdk_pixbuf_get_width(obj->priv->orig_pixbuf) * obj->priv->scale_factor),
-                (int)(gdk_pixbuf_get_height(obj->priv->orig_pixbuf) * obj->priv->scale_factor),
+                (int)(gdk_pixbuf_get_width (obj->priv->orig_pixbuf) * obj->priv->scale_factor),
+                (int)(gdk_pixbuf_get_height (obj->priv->orig_pixbuf) * obj->priv->scale_factor),
                 GDK_INTERP_NEAREST);
     }
 
@@ -889,46 +912,67 @@ static void image_render_prepare_disp_pixbuf (ImageRender *obj)
 
 static void image_render_update_adjustments (ImageRender *obj)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
     if (!obj->priv->disp_pixbuf)
         return;
 
     if (obj->priv->best_fit ||
-        (gdk_pixbuf_get_width(obj->priv->disp_pixbuf) < GTK_WIDGET (obj)->allocation.width  &&
-         gdk_pixbuf_get_height(obj->priv->disp_pixbuf) < GTK_WIDGET (obj)->allocation.height))
+        (gdk_pixbuf_get_width (obj->priv->disp_pixbuf) < GTK_WIDGET (obj)->allocation.width  &&
+         gdk_pixbuf_get_height (obj->priv->disp_pixbuf) < GTK_WIDGET (obj)->allocation.height))
     {
         if (obj->priv->h_adjustment)
         {
+#if GTK_CHECK_VERSION (2,14,0)
+            gtk_adjustment_set_lower (obj->priv->h_adjustment, 0);
+            gtk_adjustment_set_upper (obj->priv->h_adjustment, 0);
+#else
             obj->priv->h_adjustment->lower = 0;
             obj->priv->h_adjustment->upper = 0;
-            obj->priv->h_adjustment->value = 0;
-            gtk_adjustment_changed(obj->priv->h_adjustment);
+#endif
+            gtk_adjustment_set_value (obj->priv->h_adjustment, 0);
+            gtk_adjustment_changed (obj->priv->h_adjustment);
         }
         if (obj->priv->v_adjustment)
         {
+#if GTK_CHECK_VERSION (2,14,0)
+            gtk_adjustment_set_lower (obj->priv->v_adjustment, 0);
+            gtk_adjustment_set_upper (obj->priv->v_adjustment, 0);
+#else
             obj->priv->v_adjustment->lower = 0;
             obj->priv->v_adjustment->upper = 0;
-            obj->priv->v_adjustment->value = 0;
-            gtk_adjustment_changed(obj->priv->v_adjustment);
+#endif
+            gtk_adjustment_set_value (obj->priv->v_adjustment, 0);
+            gtk_adjustment_changed (obj->priv->v_adjustment);
         }
     }
     else
     {
         if (obj->priv->h_adjustment)
         {
+#if GTK_CHECK_VERSION (2,14,0)
+            gtk_adjustment_set_lower (obj->priv->h_adjustment, 0);
+            gtk_adjustment_set_upper (obj->priv->h_adjustment, gdk_pixbuf_get_width (obj->priv->disp_pixbuf));
+            gtk_adjustment_set_page_size (obj->priv->h_adjustment, GTK_WIDGET (obj)->allocation.width);
+#else
             obj->priv->h_adjustment->lower = 0;
-            obj->priv->h_adjustment->upper = gdk_pixbuf_get_width(obj->priv->disp_pixbuf);
+            obj->priv->h_adjustment->upper = gdk_pixbuf_get_width (obj->priv->disp_pixbuf);
             obj->priv->h_adjustment->page_size = GTK_WIDGET (obj)->allocation.width;
-            gtk_adjustment_changed(obj->priv->h_adjustment);
+#endif
+            gtk_adjustment_changed (obj->priv->h_adjustment);
         }
         if (obj->priv->v_adjustment)
         {
+#if GTK_CHECK_VERSION (2,14,0)
+            gtk_adjustment_set_lower (obj->priv->v_adjustment, 0);
+            gtk_adjustment_set_upper (obj->priv->v_adjustment, gdk_pixbuf_get_height (obj->priv->disp_pixbuf));
+            gtk_adjustment_set_page_size (obj->priv->v_adjustment, GTK_WIDGET (obj)->allocation.height);
+#else
             obj->priv->v_adjustment->lower = 0;
-            obj->priv->v_adjustment->upper = gdk_pixbuf_get_height(obj->priv->disp_pixbuf);
+            obj->priv->v_adjustment->upper = gdk_pixbuf_get_height (obj->priv->disp_pixbuf);
             obj->priv->v_adjustment->page_size = GTK_WIDGET (obj)->allocation.height;
-            gtk_adjustment_changed(obj->priv->v_adjustment);
+#endif
+            gtk_adjustment_changed (obj->priv->v_adjustment);
         }
     }
 }
@@ -936,7 +980,6 @@ static void image_render_update_adjustments (ImageRender *obj)
 
 void image_render_set_best_fit(ImageRender *obj, gboolean active)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
     obj->priv->best_fit = active;
@@ -947,7 +990,6 @@ void image_render_set_best_fit(ImageRender *obj, gboolean active)
 
 gboolean image_render_get_best_fit(ImageRender *obj)
 {
-    g_return_val_if_fail (obj!=NULL, FALSE);
     g_return_val_if_fail (IS_IMAGE_RENDER(obj), FALSE);
 
     return obj->priv->best_fit;
@@ -956,7 +998,6 @@ gboolean image_render_get_best_fit(ImageRender *obj)
 
 void image_render_set_scale_factor(ImageRender *obj, double scalefactor)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
 
     obj->priv->scale_factor = scalefactor;
@@ -967,37 +1008,34 @@ void image_render_set_scale_factor(ImageRender *obj, double scalefactor)
 
 double image_render_get_scale_factor(ImageRender *obj)
 {
-    g_return_val_if_fail (obj!=NULL, 1);
     g_return_val_if_fail (IS_IMAGE_RENDER(obj), 1);
 
     return obj->priv->scale_factor;
 }
 
 
-void image_render_operation(ImageRender *obj, IMAGEOPERATION op)
+void image_render_operation(ImageRender *obj, ImageRender::DISPLAYMODE op)
 {
-    g_return_if_fail (obj!=NULL);
     g_return_if_fail (IS_IMAGE_RENDER(obj));
-
     g_return_if_fail (obj->priv->orig_pixbuf);
 
     GdkPixbuf *temp = NULL;
 
     switch (op)
     {
-        case ROTATE_CLOCKWISE:
+        case ImageRender::ROTATE_CLOCKWISE:
             temp = gdk_pixbuf_rotate_simple (obj->priv->orig_pixbuf, GDK_PIXBUF_ROTATE_CLOCKWISE);
             break;
-        case ROTATE_COUNTERCLOCKWISE:
+        case ImageRender::ROTATE_COUNTERCLOCKWISE:
             temp = gdk_pixbuf_rotate_simple (obj->priv->orig_pixbuf, GDK_PIXBUF_ROTATE_COUNTERCLOCKWISE);
             break;
-        case ROTATE_UPSIDEDOWN:
+        case ImageRender::ROTATE_UPSIDEDOWN:
             temp = gdk_pixbuf_rotate_simple (obj->priv->orig_pixbuf, GDK_PIXBUF_ROTATE_UPSIDEDOWN);
             break;
-        case FLIP_VERTICAL:
+        case ImageRender::FLIP_VERTICAL:
             temp = gdk_pixbuf_flip (obj->priv->orig_pixbuf, FALSE);
             break;
-        case FLIP_HORIZONTAL:
+        case ImageRender::FLIP_HORIZONTAL:
             temp = gdk_pixbuf_flip (obj->priv->orig_pixbuf, TRUE);
             break;
         default:
