@@ -83,7 +83,7 @@ GtkType scroll_box_get_type ()
 
 GtkWidget* scroll_box_new ()
 {
-    ScrollBox *w = (ScrollBox *) gtk_type_new (scroll_box_get_type ());
+    ScrollBox *w = (ScrollBox *) g_object_new (scroll_box_get_type (), NULL);
 
     return GTK_WIDGET (w);
 }
@@ -94,7 +94,7 @@ static void scroll_box_class_init (ScrollBoxClass *klass)
     GtkObjectClass *object_class;
 
     object_class = GTK_OBJECT_CLASS (klass);
-    parent_class = (GtkTableClass *) gtk_type_class(gtk_table_get_type());
+    parent_class = (GtkTableClass *) gtk_type_class (gtk_table_get_type ());
 
     object_class->destroy = scroll_box_destroy;
 }
@@ -102,14 +102,14 @@ static void scroll_box_class_init (ScrollBoxClass *klass)
 
 static void scroll_box_init (ScrollBox *w)
 {
-    w->priv = g_new0(ScrollBoxPrivate, 1);
+    w->priv = g_new0 (ScrollBoxPrivate, 1);
 
-    gtk_table_resize(GTK_TABLE(w), 2, 2);
-    gtk_table_set_homogeneous(GTK_TABLE(w), FALSE);
+    gtk_table_resize (GTK_TABLE (w), 2, 2);
+    gtk_table_set_homogeneous (GTK_TABLE (w), FALSE);
 
     w->priv->vscroll = gtk_vscrollbar_new (NULL);
     gtk_widget_show (w->priv->vscroll);
-    gtk_table_attach (GTK_TABLE(w), w->priv->vscroll, 1, 2, 0, 1,
+    gtk_table_attach (GTK_TABLE (w), w->priv->vscroll, 1, 2, 0, 1,
         (GtkAttachOptions) (GTK_FILL),
         (GtkAttachOptions) (GTK_FILL), 0, 0);
 
@@ -120,14 +120,13 @@ static void scroll_box_init (ScrollBox *w)
             (GtkAttachOptions) (GTK_FILL), 0, 0);
     w->priv->client = NULL;
 
-    g_signal_connect(G_OBJECT (w), "button-press-event", G_CALLBACK(scroll_box_button_press), (gpointer) w);
-    g_signal_connect(G_OBJECT (w), "destroy-event", G_CALLBACK(scroll_box_destroy), (gpointer) w);
+    g_signal_connect (w, "button-press-event", G_CALLBACK (scroll_box_button_press), w);
+    g_signal_connect (w, "destroy-event", G_CALLBACK (scroll_box_destroy), w);
 }
 
 
 static void scroll_box_destroy (GtkObject *widget)
 {
-    g_return_if_fail (widget!= NULL);
     g_return_if_fail (IS_SCROLL_BOX (widget));
 
     ScrollBox *w = SCROLL_BOX (widget);
@@ -135,7 +134,7 @@ static void scroll_box_destroy (GtkObject *widget)
     if (w->priv)
     {
         if (w->priv->client)
-            g_object_unref (G_OBJECT (w->priv->client));
+            g_object_unref (w->priv->client);
         w->priv->client=NULL;
 
         g_free(w->priv);
@@ -149,16 +148,14 @@ static void scroll_box_destroy (GtkObject *widget)
 
 GtkRange *scroll_box_get_v_range(ScrollBox *obj)
 {
-    g_return_val_if_fail (obj!= NULL, FALSE);
     g_return_val_if_fail (IS_SCROLL_BOX (obj), FALSE);
 
-    return GTK_RANGE(obj->priv->vscroll);
+    return GTK_RANGE (obj->priv->vscroll);
 }
 
 
 static gboolean scroll_box_button_press(GtkWidget *widget, GdkEventButton *event, gpointer data)
 {
-    g_return_val_if_fail (widget != NULL, FALSE);
     g_return_val_if_fail (IS_SCROLL_BOX (widget), FALSE);
     g_return_val_if_fail (event != NULL, FALSE);
 
@@ -170,18 +167,17 @@ static gboolean scroll_box_button_press(GtkWidget *widget, GdkEventButton *event
 
 void scroll_box_set_client (ScrollBox *obj, GtkWidget *client)
 {
-    g_return_if_fail (obj != NULL);
     g_return_if_fail (IS_SCROLL_BOX (obj));
     g_return_if_fail (client!=NULL);
 
     if (obj->priv->client)
     {
         if (obj->priv->client)
-            g_object_unref (G_OBJECT (obj->priv->client));
+            g_object_unref (obj->priv->client);
         obj->priv->client = NULL;
     }
 
-    g_object_ref (G_OBJECT (client));
+    g_object_ref (client);
     gtk_widget_show (client);
     obj->priv->client = client;
     gtk_table_attach (GTK_TABLE (obj), client , 0, 1, 0, 1,
@@ -192,7 +188,6 @@ void scroll_box_set_client (ScrollBox *obj, GtkWidget *client)
 
 GtkWidget *scroll_box_get_client (ScrollBox *obj)
 {
-    g_return_val_if_fail (obj!= NULL, NULL);
     g_return_val_if_fail (IS_SCROLL_BOX (obj), NULL);
 
     return obj->priv->client;
@@ -201,35 +196,31 @@ GtkWidget *scroll_box_get_client (ScrollBox *obj)
 
 void scroll_box_set_h_adjustment (ScrollBox *obj, GtkAdjustment *adjustment)
 {
-    g_return_if_fail (obj != NULL);
-    g_return_if_fail (IS_SCROLL_BOX(obj));
+    g_return_if_fail (IS_SCROLL_BOX (obj));
 
-    gtk_range_set_adjustment(GTK_RANGE(obj->priv->hscroll), adjustment);
+    gtk_range_set_adjustment (GTK_RANGE (obj->priv->hscroll), adjustment);
 }
 
 
 void scroll_box_set_v_adjustment (ScrollBox *obj, GtkAdjustment *adjustment)
 {
-    g_return_if_fail (obj != NULL);
-    g_return_if_fail (IS_SCROLL_BOX(obj));
+    g_return_if_fail (IS_SCROLL_BOX (obj));
 
-    gtk_range_set_adjustment(GTK_RANGE(obj->priv->vscroll), adjustment);
+    gtk_range_set_adjustment (GTK_RANGE (obj->priv->vscroll), adjustment);
 }
 
 
 GtkAdjustment *scroll_box_get_h_adjustment (ScrollBox *obj)
 {
-    g_return_val_if_fail (obj != NULL, NULL);
-    g_return_val_if_fail (IS_SCROLL_BOX(obj), NULL);
+    g_return_val_if_fail (IS_SCROLL_BOX (obj), NULL);
 
-    return gtk_range_get_adjustment (GTK_RANGE(obj->priv->hscroll));
+    return gtk_range_get_adjustment (GTK_RANGE (obj->priv->hscroll));
 }
 
 
 GtkAdjustment *scroll_box_get_v_adjustment (ScrollBox *obj)
 {
-    g_return_val_if_fail (obj != NULL, NULL);
-    g_return_val_if_fail (IS_SCROLL_BOX(obj), NULL);
+    g_return_val_if_fail (IS_SCROLL_BOX (obj), NULL);
 
-    return gtk_range_get_adjustment (GTK_RANGE(obj->priv->vscroll));
+    return gtk_range_get_adjustment (GTK_RANGE (obj->priv->vscroll));
 }
