@@ -25,7 +25,6 @@
 
 #include <config.h>
 #include <string.h>
-#include <libgnome/libgnome.h>
 
 #include "libgviewer.h"
 #include "gnome-cmd-includes.h"
@@ -59,18 +58,17 @@ struct GViewerSearchDlgPrivate
 };
 
 
-guint8 *gviewer_search_dlg_get_search_hex_buffer (GViewerSearchDlg *sdlg, /*out*/ guint *buflen)
+guint8 *gviewer_search_dlg_get_search_hex_buffer (GViewerSearchDlg *sdlg, /*out*/ guint &buflen)
 {
     g_return_val_if_fail (sdlg!=NULL, NULL);
     g_return_val_if_fail (sdlg->priv!=NULL, NULL);
-    g_return_val_if_fail (buflen!=NULL, NULL);
     g_return_val_if_fail (sdlg->priv->search_hex_buffer!=NULL, NULL);
     g_return_val_if_fail (sdlg->priv->search_hex_buflen>0, NULL);
 
     guint8 *result = g_new0 (guint8, sdlg->priv->search_hex_buflen);
     memcpy (result, sdlg->priv->search_hex_buffer, sdlg->priv->search_hex_buflen);
 
-    *buflen = sdlg->priv->search_hex_buflen;
+    buflen = sdlg->priv->search_hex_buflen;
 
     return result;
 }
@@ -188,7 +186,7 @@ static void search_dlg_action_response (GtkDialog *dlg, gint arg1, GViewerSearch
     }
     else    // hex mode search
     {
-        sdlg->priv->search_hex_buffer = text2hex(pattern, &sdlg->priv->search_hex_buflen);
+        sdlg->priv->search_hex_buffer = text2hex (pattern, sdlg->priv->search_hex_buflen);
         g_return_if_fail (sdlg->priv->search_hex_buffer!=NULL);
 
         gnome_cmd_data.intviewer_defaults.hex_patterns.add(pattern);
@@ -207,20 +205,20 @@ static void class_init (GViewerSearchDlgClass *klass)
 
 void entry_changed (GtkEntry *entry, gpointer  user_data)
 {
-    g_return_if_fail (IS_GVIEWER_SEARCH_DLG(user_data));
+    g_return_if_fail (IS_GVIEWER_SEARCH_DLG (user_data));
 
     gboolean enable = FALSE;
 
-    GViewerSearchDlg *sdlg = GVIEWER_SEARCH_DLG(user_data);
+    GViewerSearchDlg *sdlg = GVIEWER_SEARCH_DLG (user_data);
     g_return_if_fail (sdlg->priv!=NULL);
 
     if (sdlg->priv->searchmode==SEARCH_MODE_HEX)
     {
         // Only if the use entered a valid hex string, enable the "find" button
         guint len;
-        guint8 *buf = text2hex (gtk_entry_get_text (entry), &len);
+        guint8 *buf = text2hex (gtk_entry_get_text (entry), len);
 
-        enable = (buf!=NULL) && (len>0);
+        enable = buf!=NULL && len>0;
         g_free (buf);
     }
     else
@@ -239,17 +237,17 @@ static void search_dlg_init (GViewerSearchDlg *sdlg)
     GtkTable *table;
     GtkWidget *entry;
 
-    sdlg->priv = g_new0(GViewerSearchDlgPrivate, 1);
+    sdlg->priv = g_new0 (GViewerSearchDlgPrivate, 1);
 
     sdlg->priv->searchmode = (SEARCHMODE) gnome_cmd_data.intviewer_defaults.search_mode;
 
-    gtk_window_set_title(GTK_WINDOW (dlg), _("Find"));
-    gtk_window_set_modal(GTK_WINDOW (dlg), TRUE);
-    gtk_dialog_add_button(dlg, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-    gtk_dialog_add_button(dlg, GTK_STOCK_FIND, GTK_RESPONSE_OK);
-    gtk_dialog_set_default_response(dlg, GTK_RESPONSE_OK);
+    gtk_window_set_title (GTK_WINDOW (dlg), _("Find"));
+    gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
+    gtk_dialog_add_button (dlg, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+    gtk_dialog_add_button (dlg, GTK_STOCK_FIND, GTK_RESPONSE_OK);
+    gtk_dialog_set_default_response (dlg, GTK_RESPONSE_OK);
 
-    g_signal_connect_swapped(GTK_WIDGET (dlg), "response", G_CALLBACK (search_dlg_action_response), sdlg);
+    g_signal_connect_swapped (GTK_WIDGET (dlg), "response", G_CALLBACK (search_dlg_action_response), sdlg);
 
     // 2x4 Table
     table = GTK_TABLE (gtk_table_new (2, 2, FALSE));
@@ -274,13 +272,13 @@ static void search_dlg_init (GViewerSearchDlg *sdlg)
 
     // Search mode radio buttons
     sdlg->priv->text_mode = gtk_radio_button_new_with_mnemonic(NULL, _("_Text"));
-    sdlg->priv->hex_mode = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(sdlg->priv->text_mode), _("_Hexadecimal"));
+    sdlg->priv->hex_mode = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON (sdlg->priv->text_mode), _("_Hexadecimal"));
 
-    g_signal_connect(sdlg->priv->text_mode, "toggled", G_CALLBACK (search_mode_text), sdlg);
-    g_signal_connect(sdlg->priv->hex_mode, "toggled", G_CALLBACK (search_mode_hex), sdlg);
+    g_signal_connect (sdlg->priv->text_mode, "toggled", G_CALLBACK (search_mode_text), sdlg);
+    g_signal_connect (sdlg->priv->hex_mode, "toggled", G_CALLBACK (search_mode_hex), sdlg);
 
-    gtk_table_attach(table, sdlg->priv->text_mode, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
-    gtk_table_attach(table, sdlg->priv->hex_mode, 1, 2, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
+    gtk_table_attach (table, sdlg->priv->text_mode, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+    gtk_table_attach (table, sdlg->priv->hex_mode, 1, 2, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 
     // Case-Sensitive Checkbox
     sdlg->priv->case_sensitive_checkbox = gtk_check_button_new_with_mnemonic(_("_Match case"));
@@ -312,10 +310,9 @@ static void search_dlg_init (GViewerSearchDlg *sdlg)
 
 static void search_dlg_destroy (GtkObject *object)
 {
-    g_return_if_fail (object != NULL);
-    g_return_if_fail (IS_GVIEWER_SEARCH_DLG(object));
+    g_return_if_fail (IS_GVIEWER_SEARCH_DLG (object));
 
-    GViewerSearchDlg *w = GVIEWER_SEARCH_DLG(object);
+    GViewerSearchDlg *w = GVIEWER_SEARCH_DLG (object);
 
     if (w->priv)
     {
@@ -360,7 +357,7 @@ GType gviewer_search_dlg_get_type ()
 
 GtkWidget* gviewer_search_dlg_new (GtkWindow *parent)
 {
-    GViewerSearchDlg *dlg = (GViewerSearchDlg *) gtk_type_new (gviewer_search_dlg_get_type());
+    GViewerSearchDlg *dlg = (GViewerSearchDlg *) g_object_new (gviewer_search_dlg_get_type(), NULL);
 
     return GTK_WIDGET (dlg);
 }
