@@ -25,8 +25,7 @@
 
 #include <config.h>
 #include <glib.h>
-#include <libgnomeui/libgnomeui.h>
-#include <libgnome/libgnome.h>
+#include <libgnome/gnome-config.h>
 
 #include "gvtypes.h"
 #include "viewer-utils.h"
@@ -100,35 +99,31 @@ int unicode2utf8 (unsigned int unicode, unsigned char *out)
 }
 
 
-char_type *convert_utf8_to_chartype_array (const gchar *utf8text, /*out*/ int *array_length)
+char_type *convert_utf8_to_chartype_array (const gchar *utf8text, /*out*/ int &array_length)
 {
     g_return_val_if_fail (utf8text!=NULL, NULL);
-    g_return_val_if_fail (array_length!=NULL, NULL);
-
     g_return_val_if_fail (g_utf8_validate(utf8text, -1, NULL), NULL);
 
-    glong index;
     guint32 unicode_char;
-    const gchar *pos;
-    char_type *result;
 
     glong length = g_utf8_strlen(utf8text, -1);
     g_return_val_if_fail (length>0, NULL);
 
-    result = g_new0 (char_type, length);
-    *array_length = length;
+    char_type *result = g_new0 (char_type, length);
+    array_length = length;
 
-    pos = utf8text;
-    for (index=0; index<length; ++index)
+    const gchar *pos = utf8text;
+
+    for (glong index=0; index<length; ++index)
     {
         unicode_char = g_utf8_get_char(pos);
 
         unicode2utf8(unicode_char, (unsigned char*)&result[index]);
 
         pos = g_utf8_next_char(pos);
-        if (pos==NULL)
+        if (!pos)
         {
-            g_warning("unexpected NULL found in UTF8 string");
+            g_warning ("unexpected NULL found in UTF8 string");
             break;
         }
     }
@@ -153,10 +148,9 @@ guint8 *mem_reverse (const guint8 *buffer, guint buflen)
 }
 
 
-guint8 *text2hex (const gchar *text, /*out*/ guint *buflen)
+guint8 *text2hex (const gchar *text, /*out*/ guint &buflen)
 {
     g_return_val_if_fail (text!=NULL, NULL);
-    g_return_val_if_fail (buflen!=NULL, NULL);
 
     guint8 *result;
     int len;
@@ -198,6 +192,6 @@ guint8 *text2hex (const gchar *text, /*out*/ guint *buflen)
             }
             high_nib = !high_nib;
         };
-    *buflen = len;
+    buflen = len;
     return result;
 }
