@@ -33,12 +33,12 @@ gint     gviewer_get_int (const gchar *path, int def);
 gboolean gviewer_get_bool (const gchar *path, gboolean def);
 
 int unicode2utf8(unsigned int unicode, unsigned char *out);
-char_type *convert_utf8_to_chartype_array(const gchar *utf8text, /*out*/ int *array_length);
+char_type *convert_utf8_to_chartype_array(const gchar *utf8text, /*out*/ int &array_length);
 
 guint8 *mem_reverse(const guint8 *buffer, guint buflen);
 
 /* returns NULL if 'text' is not a valid hex string (whitespaces are OK, and are ignored) */
-guint8 *text2hex(const gchar *text, /*out*/ guint *buflen);
+guint8 *text2hex (const gchar *text, /*out*/ guint &buflen);
 
 /*  if "ch" is lower case english letter (a-z), returns UPPER case letter, otherwise returns unmodified "ch" */
 inline char_type chartype_toupper(char_type ch)
