@@ -36,9 +36,6 @@
 #include <gtk/gtktable.h>
 #include <gtk/gtkmarshal.h>
 
-#include <libgnome/libgnome.h>
-#include <libgnomevfs/gnome-vfs.h>
-
 #include "libgviewer.h"
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-file.h"
@@ -87,8 +84,9 @@ static void gviewer_init (GViewer *w);
 static void gviewer_class_init (GViewerClass *klass);
 static void gviewer_destroy (GtkObject *object);
 
-static void gviewer_text_status_update(TextRender *obj, TextRenderStatus *status, GViewer *viewer);
-static void gviewer_image_status_update(ImageRender *obj, ImageRenderStatus *status, GViewer *viewer);
+static void gviewer_text_status_update(TextRender *obj, TextRender::Status *status, GViewer *viewer);
+static void gviewer_image_status_update(ImageRender *obj, ImageRender::Status *status, GViewer *viewer);
+static gboolean on_text_viewer_button_pressed (GtkWidget *treeview, GdkEventButton *event, GViewer *viewer);
 
 static VIEWERDISPLAYMODE guess_display_mode(const unsigned char *data, int len);
 static void gviewer_auto_detect_display_mode(GViewer *obj);
@@ -123,7 +121,7 @@ GtkType gviewer_get_type ()
 
 GtkWidget *gviewer_new ()
 {
-    GViewer *w = (GViewer *) gtk_type_new (gviewer_get_type ());
+    GViewer *w = (GViewer *) g_object_new (gviewer_get_type (), NULL);
 
     return GTK_WIDGET (w);
 }
@@ -152,8 +150,8 @@ static void gviewer_init (GViewer *w)
 {
     w->priv = g_new0 (GViewerPrivate, 1);
 
-    gtk_table_resize(GTK_TABLE(w), 1, 1);
-    gtk_table_set_homogeneous(GTK_TABLE(w), FALSE);
+    gtk_table_resize (GTK_TABLE (w), 1, 1);
+    gtk_table_set_homogeneous(GTK_TABLE (w), FALSE);
 
     w->priv->img_initialized = FALSE;
     w->priv->dispmode = DISP_MODE_TEXT_FIXED;
@@ -172,7 +170,7 @@ static void gviewer_init (GViewer *w)
     scroll_box_set_client (SCROLL_BOX(w->priv->tscrollbox), GTK_WIDGET (w->priv->textr));
     gtk_widget_show (GTK_WIDGET (w->priv->textr));
     gtk_widget_show (w->priv->tscrollbox);
-    g_object_ref (G_OBJECT (w->priv->tscrollbox));
+    g_object_ref (w->priv->tscrollbox);
 
     w->priv->imgr  = (ImageRender *) image_render_new();
     gviewer_set_best_fit(w, DEFAULT_BEST_FIT);
@@ -185,24 +183,25 @@ static void gviewer_init (GViewer *w)
     scroll_box_set_client (SCROLL_BOX(w->priv->iscrollbox), GTK_WIDGET (w->priv->imgr));
     gtk_widget_show (GTK_WIDGET (w->priv->imgr));
     gtk_widget_show (w->priv->iscrollbox);
-    g_object_ref (G_OBJECT (w->priv->iscrollbox));
+    g_object_ref (w->priv->iscrollbox);
 
     w->priv->last_client = w->priv->tscrollbox;
-    gtk_table_attach (GTK_TABLE(w), GTK_WIDGET (w->priv->tscrollbox), 0, 1, 0, 1,
+    gtk_table_attach (GTK_TABLE (w), GTK_WIDGET (w->priv->tscrollbox), 0, 1, 0, 1,
                       (GtkAttachOptions)(GTK_FILL|GTK_EXPAND),
                       (GtkAttachOptions)(GTK_FILL|GTK_EXPAND), 0, 0);
 
-    g_signal_connect (G_OBJECT (w), "destroy-event", G_CALLBACK (gviewer_destroy), (gpointer) w);
+    g_signal_connect (w, "destroy-event", G_CALLBACK (gviewer_destroy), w);
 
-    g_signal_connect (G_OBJECT (w->priv->textr), "text-status-changed", G_CALLBACK (gviewer_text_status_update), (gpointer) w);
-    g_signal_connect (G_OBJECT (w->priv->imgr), "image-status-changed", G_CALLBACK (gviewer_image_status_update), (gpointer) w);
+    g_signal_connect (w->priv->textr, "text-status-changed", G_CALLBACK (gviewer_text_status_update), w);
+    g_signal_connect (w->priv->imgr, "image-status-changed", G_CALLBACK (gviewer_image_status_update), w);
+
+    g_signal_connect (w->priv->textr, "button-press-event", G_CALLBACK (on_text_viewer_button_pressed), w);
 }
 
 
 #define MAX_STATUS_LENGTH 128
-static void gviewer_text_status_update(TextRender *obj, TextRenderStatus *status, GViewer *viewer)
+static void gviewer_text_status_update(TextRender *obj, TextRender::Status *status, GViewer *viewer)
 {
-    g_return_if_fail (viewer!= NULL);
     g_return_if_fail (IS_GVIEWER (viewer));
     g_return_if_fail (status!=NULL);
 
@@ -215,13 +214,12 @@ static void gviewer_text_status_update(TextRender *obj, TextRenderStatus *status
                status->column,
                status->wrap_mode?_("Wrap"):"");
 
-    gtk_signal_emit (GTK_OBJECT(viewer), gviewer_signals[STATUS_LINE_CHANGED], temp);
+    gtk_signal_emit (GTK_OBJECT (viewer), gviewer_signals[STATUS_LINE_CHANGED], temp);
 }
 
 
-static void gviewer_image_status_update(ImageRender *obj, ImageRenderStatus *status, GViewer *viewer)
+static void gviewer_image_status_update(ImageRender *obj, ImageRender::Status *status, GViewer *viewer)
 {
-    g_return_if_fail (viewer!= NULL);
     g_return_if_fail (IS_GVIEWER (viewer));
     g_return_if_fail (status!=NULL);
 
@@ -247,21 +245,43 @@ static void gviewer_image_status_update(ImageRender *obj, ImageRenderStatus *sta
                     status->best_fit?_("(fit to window)"):zoom);
     }
 
-    gtk_signal_emit (GTK_OBJECT(viewer), gviewer_signals[STATUS_LINE_CHANGED], temp);
+    gtk_signal_emit (GTK_OBJECT (viewer), gviewer_signals[STATUS_LINE_CHANGED], temp);
+}
+
+
+
+static gboolean on_text_viewer_button_pressed (GtkWidget *treeview, GdkEventButton *event, GViewer *viewer)
+{
+    if (event->type==GDK_BUTTON_PRESS && event->button==3)
+    {
+        GtkWidget *menu = gtk_menu_new ();
+        GtkWidget *menuitem;
+
+        menuitem = gtk_image_menu_item_new_with_mnemonic (_("_Copy selection"));
+        gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU));
+        g_signal_connect (menuitem, "activate", G_CALLBACK (gviewer_copy_selection), viewer);
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+
+        gtk_widget_show_all (menu);
+        gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, event->button, event->time);
+
+        return TRUE;
+    }
+
+    return FALSE;
 }
 
 
 static void gviewer_destroy (GtkObject *widget)
 {
-    g_return_if_fail (widget!= NULL);
     g_return_if_fail (IS_GVIEWER (widget));
 
     GViewer *w = GVIEWER (widget);
 
     if (w->priv)
     {
-        g_object_unref (G_OBJECT (w->priv->iscrollbox));
-        g_object_unref (G_OBJECT (w->priv->tscrollbox));
+        g_object_unref (w->priv->iscrollbox);
+        g_object_unref (w->priv->tscrollbox);
 
         g_free (w->priv);
         w->priv = NULL;
@@ -280,7 +300,7 @@ static VIEWERDISPLAYMODE guess_display_mode(const unsigned char *data, int len)
 
     const char *mime = gnome_vfs_get_mime_type_for_data(data, len);
 
-    if (g_strncasecmp(mime, "image/", 6)==0)
+    if (g_ascii_strncasecmp (mime, "image/", 6)==0)
         return DISP_MODE_IMAGE;
 
     /* Hex File ?  */
@@ -328,7 +348,6 @@ void gviewer_auto_detect_display_mode(GViewer *obj)
 
 void gviewer_set_display_mode(GViewer *obj, VIEWERDISPLAYMODE mode)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
 
     if (mode==DISP_MODE_IMAGE && !obj->priv->img_initialized)
@@ -346,17 +365,17 @@ void gviewer_set_display_mode(GViewer *obj, VIEWERDISPLAYMODE mode)
     {
         case DISP_MODE_TEXT_FIXED:
             client = obj->priv->tscrollbox;
-            text_render_set_display_mode (obj->priv->textr, TR_DISP_MODE_TEXT);
+            text_render_set_display_mode (obj->priv->textr, TextRender::DISPLAYMODE_TEXT);
             break;
 
         case DISP_MODE_BINARY:
             client = obj->priv->tscrollbox;
-            text_render_set_display_mode (obj->priv->textr, TR_DISP_MODE_BINARY);
+            text_render_set_display_mode (obj->priv->textr, TextRender::DISPLAYMODE_BINARY);
             break;
 
         case DISP_MODE_HEXDUMP:
             client = obj->priv->tscrollbox;
-            text_render_set_display_mode (obj->priv->textr, TR_DISP_MODE_HEXDUMP);
+            text_render_set_display_mode (obj->priv->textr, TextRender::DISPLAYMODE_HEXDUMP);
             break;
 
         case DISP_MODE_IMAGE:
@@ -395,7 +414,6 @@ void gviewer_set_display_mode(GViewer *obj, VIEWERDISPLAYMODE mode)
 
 VIEWERDISPLAYMODE gviewer_get_display_mode(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, DISP_MODE_TEXT_FIXED);
     g_return_val_if_fail (IS_GVIEWER (obj), DISP_MODE_TEXT_FIXED);
 
     return obj->priv->dispmode;
@@ -404,7 +422,6 @@ VIEWERDISPLAYMODE gviewer_get_display_mode(GViewer *obj)
 
 void gviewer_load_filedesc(GViewer *obj, int fd)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (fd>2);
 
@@ -421,7 +438,6 @@ void gviewer_load_filedesc(GViewer *obj, int fd)
 
 void gviewer_load_file(GViewer *obj, const gchar*filename)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (filename);
 
@@ -440,7 +456,6 @@ void gviewer_load_file(GViewer *obj, const gchar*filename)
 
 const gchar *gviewer_get_filename(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, NULL);
     g_return_val_if_fail (IS_GVIEWER (obj), NULL);
     g_return_val_if_fail (obj->priv->filename, NULL);
 
@@ -450,7 +465,6 @@ const gchar *gviewer_get_filename(GViewer *obj)
 
 void gviewer_set_tab_size(GViewer *obj, int tab_size)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->textr);
 
@@ -460,7 +474,6 @@ void gviewer_set_tab_size(GViewer *obj, int tab_size)
 
 int gviewer_get_tab_size(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, 0);
     g_return_val_if_fail (IS_GVIEWER (obj), 0);
     g_return_val_if_fail (obj->priv->textr, 0);
 
@@ -470,7 +483,6 @@ int gviewer_get_tab_size(GViewer *obj)
 
 void gviewer_set_wrap_mode(GViewer *obj, gboolean ACTIVE)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->textr);
 
@@ -480,7 +492,6 @@ void gviewer_set_wrap_mode(GViewer *obj, gboolean ACTIVE)
 
 gboolean gviewer_get_wrap_mode(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, FALSE);
     g_return_val_if_fail (IS_GVIEWER (obj), FALSE);
     g_return_val_if_fail (obj->priv->textr, FALSE);
 
@@ -490,7 +501,6 @@ gboolean gviewer_get_wrap_mode(GViewer *obj)
 
 void gviewer_set_fixed_limit(GViewer *obj, int fixed_limit)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->textr);
 
@@ -500,7 +510,6 @@ void gviewer_set_fixed_limit(GViewer *obj, int fixed_limit)
 
 int gviewer_get_fixed_limit(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, 0);
     g_return_val_if_fail (IS_GVIEWER (obj), 0);
     g_return_val_if_fail (obj->priv->textr, 0);
 
@@ -510,7 +519,6 @@ int gviewer_get_fixed_limit(GViewer *obj)
 
 void gviewer_set_encoding(GViewer *obj, const char *encoding)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->textr);
 
@@ -520,7 +528,6 @@ void gviewer_set_encoding(GViewer *obj, const char *encoding)
 
 const gchar *gviewer_get_encoding(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, NULL);
     g_return_val_if_fail (IS_GVIEWER (obj), NULL);
     g_return_val_if_fail (obj->priv->textr, NULL);
 
@@ -530,7 +537,6 @@ const gchar *gviewer_get_encoding(GViewer *obj)
 
 void gviewer_set_font_size(GViewer *obj, int font_size)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->textr);
 
@@ -540,7 +546,6 @@ void gviewer_set_font_size(GViewer *obj, int font_size)
 
 int gviewer_get_font_size(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, 0);
     g_return_val_if_fail (IS_GVIEWER (obj), 0);
     g_return_val_if_fail (obj->priv->textr, 0);
 
@@ -550,7 +555,6 @@ int gviewer_get_font_size(GViewer *obj)
 
 void gviewer_set_hex_offset_display(GViewer *obj, gboolean HEX_OFFSET)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->textr);
 
@@ -560,7 +564,6 @@ void gviewer_set_hex_offset_display(GViewer *obj, gboolean HEX_OFFSET)
 
 gboolean gviewer_get_hex_offset_display(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, FALSE);
     g_return_val_if_fail (IS_GVIEWER (obj), FALSE);
     g_return_val_if_fail (obj->priv->textr, FALSE);
 
@@ -570,7 +573,6 @@ gboolean gviewer_get_hex_offset_display(GViewer *obj)
 
 void gviewer_set_best_fit(GViewer *obj, gboolean active)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->imgr);
 
@@ -580,7 +582,6 @@ void gviewer_set_best_fit(GViewer *obj, gboolean active)
 
 gboolean gviewer_get_best_fit(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, FALSE);
     g_return_val_if_fail (IS_GVIEWER (obj), FALSE);
     g_return_val_if_fail (obj->priv->textr, FALSE);
 
@@ -590,7 +591,6 @@ gboolean gviewer_get_best_fit(GViewer *obj)
 
 void gviewer_set_scale_factor(GViewer *obj, double scalefactor)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->imgr);
 
@@ -600,7 +600,6 @@ void gviewer_set_scale_factor(GViewer *obj, double scalefactor)
 
 double gviewer_get_scale_factor(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, 0);
     g_return_val_if_fail (IS_GVIEWER (obj), 0);
     g_return_val_if_fail (obj->priv->imgr, 0);
 
@@ -610,7 +609,6 @@ double gviewer_get_scale_factor(GViewer *obj)
 
 TextRender *gviewer_get_text_render(GViewer *obj)
 {
-    g_return_val_if_fail (obj!= NULL, 0);
     g_return_val_if_fail (IS_GVIEWER (obj), 0);
     g_return_val_if_fail (obj->priv->textr, 0);
 
@@ -618,9 +616,8 @@ TextRender *gviewer_get_text_render(GViewer *obj)
 }
 
 
-void gviewer_image_operation(GViewer *obj, IMAGEOPERATION op)
+void gviewer_image_operation(GViewer *obj, ImageRender::DISPLAYMODE op)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->imgr);
 
@@ -628,9 +625,8 @@ void gviewer_image_operation(GViewer *obj, IMAGEOPERATION op)
 }
 
 
-void gviewer_copy_selection(GViewer *obj)
+void gviewer_copy_selection(GtkMenuItem *item, GViewer *obj)
 {
-    g_return_if_fail (obj!= NULL);
     g_return_if_fail (IS_GVIEWER (obj));
     g_return_if_fail (obj->priv->textr);
 
