@@ -32,9 +32,9 @@
 #define GVIEWER_WINDOW(obj) \
     GTK_CHECK_CAST (obj, gviewer_window_get_type (), GViewerWindow)
 #define GVIEWER_WINDOW_CLASS(clss) \
-    GTK_CHECK_CLASS_CAST (clss, gviewer_window_get_type(), GViewerWindowClass)
+    GTK_CHECK_CLASS_CAST (clss, gviewer_window_get_type (), GViewerWindowClass)
 #define IS_GVIEWER_WINDOW(obj) \
-    GTK_CHECK_TYPE (obj, gviewer_window_get_type())
+    GTK_CHECK_TYPE (obj, gviewer_window_get_type ())
 
 
 struct GViewerWindowSettings
@@ -75,7 +75,7 @@ GtkType gviewer_window_get_type ();
 
 inline GtkWidget *gviewer_window_new ()
 {
-    return (GtkWidget *) gtk_type_new (gviewer_window_get_type ());
+    return (GtkWidget *) g_object_new (gviewer_window_get_type (), NULL);
 }
 
 void gviewer_window_load_file (GViewerWindow *obj, GnomeCmdFile *f);
