@@ -20,10 +20,12 @@
 */
 
 #include <config.h>
+#include <stdlib.h>
 
 #include "gnome-cmd-includes.h"
 #include "ls_colors.h"
 #include "gnome-cmd-file.h"
+#include "gnome-cmd-data.h"
 
 using namespace std;
 
@@ -34,16 +36,6 @@ using namespace std;
 static GHashTable *map;
 static LsColor *type_colors[8];
 
-static GdkColor black   = {0,0,0,0};
-static GdkColor red     = {0,0xffff,0,0};
-static GdkColor green   = {0,0,0xffff,0};
-static GdkColor yellow  = {0,0xffff,0xffff,0};
-static GdkColor blue    = {0,0,0,0xffff};
-static GdkColor magenta = {0,0xffff,0,0xffff};
-static GdkColor cyan    = {0,0,0xffff,0xffff};
-static GdkColor white   = {0,0xffff,0xffff,0xffff};
-
-
 
 /*
 # Attribute codes:
@@ -55,25 +47,27 @@ static GdkColor white   = {0,0xffff,0xffff,0xffff};
 */
 inline GdkColor *code2color (gint code)
 {
+    GnomeCmdLsColorsPalette &palette = gnome_cmd_data.options.ls_colors_palette;
+
     switch (code)
     {
-        case 30: return &black;
-        case 31: return &red;
-        case 32: return &green;
-        case 33: return &yellow;
-        case 34: return &blue;
-        case 35: return &magenta;
-        case 36: return &cyan;
-        case 37: return &white;
+        case 30: return palette.black_fg;
+        case 31: return palette.red_fg;
+        case 32: return palette.green_fg;
+        case 33: return palette.yellow_fg;
+        case 34: return palette.blue_fg;
+        case 35: return palette.magenta_fg;
+        case 36: return palette.cyan_fg;
+        case 37: return palette.white_fg;
 
-        case 40: return &black;
-        case 41: return &red;
-        case 42: return &green;
-        case 43: return &yellow;
-        case 44: return &blue;
-        case 45: return &magenta;
-        case 46: return &cyan;
-        case 47: return &white;
+        case 40: return palette.black_bg;
+        case 41: return palette.red_bg;
+        case 42: return palette.green_bg;
+        case 43: return palette.yellow_bg;
+        case 44: return palette.blue_bg;
+        case 45: return palette.magenta_bg;
+        case 46: return palette.cyan_bg;
+        case 47: return palette.white_bg;
     }
 
     return NULL;
@@ -114,10 +108,10 @@ static LsColor *ext_color (gchar *key, gchar *val)
 static LsColor *type_color (gchar *key, gchar *val)
 {
     int i, n[3];
-    LsColor *col = g_new (LsColor, 1);
-    col->ext = NULL;
-    col->fg = NULL;
-    col->bg = NULL;
+    LsColor *col = g_new0 (LsColor, 1);
+    // col->ext = NULL;
+    // col->fg = NULL;
+    // col->bg = NULL;
 
     if (strcmp (key, "fi") == 0)
         col->type = GNOME_VFS_FILE_TYPE_REGULAR;
@@ -185,7 +179,7 @@ static void init (gchar *ls_colors)
         if (col)
         {
             if (col->ext)
-                g_hash_table_insert (map, col->ext, col);
+                g_hash_table_insert (::map, col->ext, col);
             else
                 type_colors[col->type] = col;
         }
@@ -201,7 +195,7 @@ void ls_colors_init ()
     if (!s)
         s = DEFAULT_COLORS;
 
-    map = g_hash_table_new (g_str_hash, g_str_equal);
+    ::map = g_hash_table_new (g_str_hash, g_str_equal);
     init (s);
 }
 
@@ -212,10 +206,10 @@ LsColor *ls_colors_get (GnomeCmdFile *f)
         return type_colors[GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK];
 
     LsColor *col = NULL;
-    const gchar *ext = gnome_cmd_file_get_extension (f);
+    const gchar *ext = f->get_extension();
 
     if (ext)
-        col = (LsColor *) g_hash_table_lookup (map, ext);
+        col = (LsColor *) g_hash_table_lookup (::map, ext);
 
     if (!col)
         col = type_colors[f->info->type];
