@@ -51,7 +51,7 @@ class GnomeCmdOwner
         {
             ID id;
             char *name;
-            T  data;
+            T data;
         };
 
         Entry *lookup(ID id)                    {  return (Entry *) g_hash_table_lookup (id_table, &id);      }
@@ -130,6 +130,12 @@ inline GnomeCmdOwner::HashTable<T,ID>::~HashTable()
     g_hash_table_destroy (name_table);
     if (entries)
     {
+        for (GList *i = entries; i; i = g_list_next (i))
+        {
+            Entry *e = (Entry *) i->data;
+            g_free (e->name);
+        }
+
         g_list_foreach (entries, (GFunc) g_free, NULL);
         g_list_free (entries);
     }
@@ -206,7 +212,8 @@ inline GnomeCmdOwner::GnomeCmdGroups::Entry *GnomeCmdOwner::new_entry(const stru
 inline GnomeCmdOwner::~GnomeCmdOwner()
 {
     stop_thread = TRUE;
-    g_thread_join (thread);
+    if (thread)
+        g_thread_join (thread);
     g_free (buff);
     g_list_free (group_names);
 }
