@@ -124,10 +124,10 @@ static void activate_plugin (PluginData *data)
 
     data->active = TRUE;
 
-    GnomeCmdState *state = gnome_cmd_main_win_get_state (main_win);
+    GnomeCmdState *state = main_win->get_state();
     data->menu = gnome_cmd_plugin_create_main_menu (data->plugin, state);
     if (data->menu)
-        gnome_cmd_main_win_add_plugin_menu (main_win, data);
+        main_win->add_plugin_menu(data);
 }
 
 
@@ -149,11 +149,9 @@ static void scan_plugins_in_dir (const gchar *dpath)
     char *prev_dir;
     struct dirent *ent;
 
-    if (dir == NULL)
+    if (!dir)
     {
-        gchar *msg = g_strdup_printf ("Could not list files in %s: %s\n", dpath, strerror (errno));
-        warn_print (msg);
-        g_free (msg);
+        g_warning ("Could not list files in %s: %s", dpath, strerror (errno));
         return;
     }
 
@@ -164,17 +162,17 @@ static void scan_plugins_in_dir (const gchar *dpath)
     {
         struct stat buf;
 
-        if (strcmp (ent->d_name+strlen(ent->d_name)-3, ".so") != 0)
+        if (strcmp (ent->d_name+strlen(ent->d_name)-strlen("." G_MODULE_SUFFIX), "." G_MODULE_SUFFIX) != 0)
             continue;
 
         if (stat (ent->d_name, &buf) == 0)
         {
             if (buf.st_mode & S_IFREG)
             {
-                // the direntry has the .so extension and is a regular file, lets accept it
+                // the direntry has the correct extension and is a regular file, let's accept it
                 PluginData *data = g_new0 (PluginData, 1);
                 data->fname = g_strdup (ent->d_name);
-                data->fpath = g_build_path (G_DIR_SEPARATOR_S, dpath, ent->d_name, NULL);
+                data->fpath = g_build_filename (dpath, ent->d_name, NULL);
                 data->loaded = FALSE;
                 data->active = FALSE;
                 data->menu = NULL;
@@ -207,12 +205,12 @@ void plugin_manager_init ()
 {
     if (plugins)
     {
-        warn_print ("plugin_manager already initiated\n");
+        g_warning ("plugin_manager already initiated");
         return;
     }
 
     // find user plugins
-    gchar *user_dir = g_build_path (G_DIR_SEPARATOR_S, g_get_home_dir(), ".gnome-commander/plugins", NULL);
+    gchar *user_dir = g_build_filename (g_get_home_dir (), "." PACKAGE "/plugins", NULL);
     create_dir_if_needed (user_dir);
     scan_plugins_in_dir (user_dir);
     g_free (user_dir);
@@ -276,14 +274,14 @@ static void update_plugin_list (GtkCList *list, GtkWidget *dialog)
     gint row = 0;
     gboolean only_update = (list->rows > 0);
 
-    for (GList *tmp=plugins; tmp; tmp=tmp->next)
+    for (GList *i=plugins; i; i=i->next, ++row)
     {
-        PluginData *data = (PluginData *) tmp->data;
+        PluginData *data = (PluginData *) i->data;
         gchar *text[5];
 
         text[0] = NULL;
-        text[1] = data->info->name;
-        text[2] = data->info->version;
+        text[1] = (gchar *) data->info->name;
+        text[2] = (gchar *) data->info->version;
         text[3] = data->fname;
         text[4] = NULL;
 
@@ -298,8 +296,6 @@ static void update_plugin_list (GtkCList *list, GtkWidget *dialog)
             gtk_clist_set_pixmap (list, row, 0, blank_pixmap, blank_mask);
 
         gtk_clist_set_row_data (list, row, data);
-
-        row++;
     }
 
     gtk_clist_select_row (list, old_focus, 0);
@@ -322,9 +318,7 @@ inline void do_toggle (GtkWidget *dialog)
 }
 
 
-static void
-on_plugin_selected (GtkCList *list, gint row, gint column,
-                    GdkEventButton *event, GtkWidget *dialog)
+static void on_plugin_selected (GtkCList *list, gint row, gint column, GdkEventButton *event, GtkWidget *dialog)
 {
     GtkWidget *toggle_button = lookup_widget (dialog, "toggle_button");
     GtkWidget *conf_button = lookup_widget (dialog, "conf_button");
@@ -346,9 +340,7 @@ on_plugin_selected (GtkCList *list, gint row, gint column,
 }
 
 
-static void
-on_plugin_unselected (GtkCList *list, gint row, gint column,
-                      GdkEventButton *event, GtkWidget *dialog)
+static void on_plugin_unselected (GtkCList *list, gint row, gint column, GdkEventButton *event, GtkWidget *dialog)
 {
     GtkWidget *toggle_button = lookup_widget (dialog, "toggle_button");
     GtkWidget *conf_button = lookup_widget (dialog, "conf_button");
@@ -387,8 +379,8 @@ static void on_about (GtkButton *button, GtkWidget *dialog)
 
     GtkWidget *about = gnome_cmd_about_plugin_new (data->info);
 
-    gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (main_win));
-    gtk_widget_ref (about);
+    gtk_window_set_transient_for (GTK_WINDOW (about), *main_win);
+    g_object_ref (about);
     gtk_widget_show (about);
 }
 
@@ -405,7 +397,7 @@ void plugin_manager_show ()
     GtkWidget *avail_list;
 
     dialog = gnome_cmd_dialog_new (_("Available plugins"));
-    gtk_widget_ref (dialog);
+    g_object_ref (dialog);
 
     hbox = create_vbox (dialog, FALSE, 6);
     avail_list = create_clist (dialog, "avail_list", 4, 20, GTK_SIGNAL_FUNC (on_plugin_selected), NULL);
@@ -418,16 +410,16 @@ void plugin_manager_show ()
     gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_START);
 
     button = create_button (GTK_WIDGET (dialog), _("_Enable"), GTK_SIGNAL_FUNC (on_toggle));
-    gtk_object_set_data (GTK_OBJECT (dialog), "toggle_button", button);
+    g_object_set_data (G_OBJECT (dialog), "toggle_button", button);
     gtk_box_pack_start (GTK_BOX (bbox), button, TRUE, FALSE, 0);
 
     button = create_button (GTK_WIDGET (dialog), _("_Configure"), GTK_SIGNAL_FUNC (on_configure));
-    gtk_object_set_data (GTK_OBJECT (dialog), "conf_button", button);
+    g_object_set_data (G_OBJECT (dialog), "conf_button", button);
     gtk_widget_set_sensitive (button, FALSE);
     gtk_box_pack_start (GTK_BOX (bbox), button, TRUE, FALSE, 0);
 
     button = create_button (GTK_WIDGET (dialog), _("_About"), GTK_SIGNAL_FUNC (on_about));
-    gtk_object_set_data (GTK_OBJECT (dialog), "about_button", button);
+    g_object_set_data (G_OBJECT (dialog), "about_button", button);
     gtk_widget_set_sensitive (button, FALSE);
     gtk_box_pack_start (GTK_BOX (bbox), button, TRUE, FALSE, 0);
 
@@ -437,7 +429,7 @@ void plugin_manager_show ()
     gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), hbox);
 
     avail_list = lookup_widget (avail_list, "avail_list");
-    gtk_signal_connect (GTK_OBJECT (avail_list), "unselect-row", GTK_SIGNAL_FUNC (on_plugin_unselected), dialog);
+    g_signal_connect (avail_list, "unselect-row", G_CALLBACK (on_plugin_unselected), dialog);
 
     if (!exec_pixmap)
     {
@@ -454,9 +446,9 @@ void plugin_manager_show ()
     update_plugin_list (GTK_CLIST (avail_list), dialog);
 
     gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_SIGNAL_FUNC(on_close), dialog);
-    gnome_cmd_dialog_set_transient_for (GNOME_CMD_DIALOG (dialog), GTK_WINDOW (main_win));
+    gtk_window_set_transient_for (GTK_WINDOW (dialog), *main_win);
 
     gtk_widget_set_size_request (GTK_WIDGET (dialog), 500, 300);
-    gtk_window_set_resizable((GtkWindow *) GTK_WIDGET (dialog), TRUE);
+    gtk_window_set_resizable ((GtkWindow *) GTK_WIDGET (dialog), TRUE);
     gtk_widget_show_all (GTK_WIDGET (dialog));
 }
