@@ -43,9 +43,9 @@ void gcmd_tags_file_load_metadata(GnomeCmdFile *f)
 
     f->metadata->mark_as_accessed(TAG_FILE);
 
-    // if (!gnome_cmd_file_is_local(f))  return;
+    // if (!f->is_local())  return;
 
-    gchar *dpath = gnome_cmd_file_get_dirname(f);
+    gchar *dpath = f->get_dirname();
 
     static char buff[32];
 
@@ -54,7 +54,7 @@ void gcmd_tags_file_load_metadata(GnomeCmdFile *f)
 
     g_free (dpath);
 
-    gchar *uri_str = gnome_cmd_file_get_uri_str (f, GNOME_VFS_URI_HIDE_PASSWORD);
+    gchar *uri_str = f->get_uri_str(GNOME_VFS_URI_HIDE_PASSWORD);
     f->metadata->add(TAG_FILE_LINK, uri_str);
     g_free (uri_str);
 
