@@ -24,9 +24,6 @@
 
 #include "gnome-cmd-file.h"
 
-void gcmd_tags_poppler_init();
-void gcmd_tags_poppler_shutdown();
-
 void gcmd_tags_poppler_load_metadata(GnomeCmdFile *f);
 
 #endif // __GNOME_CMD_TAGS_POPPLER_H__
