@@ -25,12 +25,12 @@
 #include "libgcmd/libgcmd-deps.h"
 #include "gnome-cmd-combo.h"
 
-inline GtkWidget *create_clist_combo (GtkWidget *parent, gint num_cols, gint text_col, gchar **titles)
+inline GnomeCmdCombo *create_clist_combo (GtkWidget *parent, gint num_cols, gint text_col, gchar **titles)
 {
-    GtkWidget *combo = gnome_cmd_combo_new (num_cols, text_col, titles);
-    gtk_widget_ref (combo);
-    gtk_object_set_data_full (GTK_OBJECT (parent), "combo", combo, (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_show (combo);
+    GnomeCmdCombo *combo = new GnomeCmdCombo(num_cols, text_col, titles);
+    g_object_ref (combo);
+    g_object_set_data_full (G_OBJECT (parent), "combo", combo, (GDestroyNotify) g_object_unref);
+    gtk_widget_show (*combo);
 
     return combo;
 }
